# R code to create the shrub belt height and basal diameter datasets and the number of individuals datasets per species
# Notes:
# In places where we did not encounter a plant species on the shrub belt but had stoichiometry data from the foliage sampling we add these individuals (count of foliage samples) to their appropriate height class database
library("dplyr")

##### Load Entire Shrub Belt Dataset and Subset by Species #####
# Load shrub belt data
SB <- read.csv("Data/Quantity/ShrubBelt/ShrubBelt_DatabaseOriginal_2017Feb25.csv")

# Subset database for ABBA
SB.ABBA <- subset(SB, Species == "ABBA")
SB.ACRU <- subset(SB, Species == "ACRU")
SB.BEPA <- subset(SB, Species == "BEPA")
SB.VAAN <- subset(SB, Species == "VAAN")
SB.PIMA <- subset(SB, Species == "PIMA")

##### ABBA Create Shrub Height Basal Diameter Datasets #####
# Subset dataset for each height class A, B, C, and D
SB.ABBA.HeightBasalD.A <- subset(SB.ABBA, HeightCategory == "A") 
SB.ABBA.HeightBasalD.B <- subset(SB.ABBA, HeightCategory == "B") 
SB.ABBA.HeightBasalD.C <- subset(SB.ABBA, HeightCategory == "C") 
SB.ABBA.HeightBasalD.D <- subset(SB.ABBA, HeightCategory == "D") 
str(SB.ABBA.HeightBasalD.D)
# Subset dataset to only include variables of interest
SB.ABBA.HeightBasalD.A.sub <- subset(SB.ABBA.HeightBasalD.A, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.ABBA.HeightBasalD.B.sub <- subset(SB.ABBA.HeightBasalD.B, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.ABBA.HeightBasalD.C.sub <- subset(SB.ABBA.HeightBasalD.C, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.ABBA.HeightBasalD.D.sub <- subset(SB.ABBA.HeightBasalD.D, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 

# Write datasets
write.csv(SB.ABBA.HeightBasalD.A.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ABBA_A.csv")
write.csv(SB.ABBA.HeightBasalD.B.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ABBA_B.csv")
write.csv(SB.ABBA.HeightBasalD.C.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ABBA_C.csv")
write.csv(SB.ABBA.HeightBasalD.D.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ABBA_D.csv")

 ##### Create Number of Individuals Datasets #####
# Steps are repeated for each height class
# Create new field that is the count of individuals per height class along shrub belt transect
SB.ABBA.Count.A <- count(SB.ABBA.HeightBasalD.A.sub, PlotName,  name = "Num_A_Plot")
SB.ABBA.Count.B <- count(SB.ABBA.HeightBasalD.B.sub, PlotName,  name = "Num_B_Plot")
SB.ABBA.Count.C <- count(SB.ABBA.HeightBasalD.C.sub, PlotName,  name = "Num_C_Plot")
SB.ABBA.Count.D <- count(SB.ABBA.HeightBasalD.D.sub, PlotName,  name = "Num_D_Plot")

# Set count datasets as a data frame
SB.ABBA.Count.A.Data <- as.data.frame(SB.ABBA.Count.A)
SB.ABBA.Count.B.Data <- as.data.frame(SB.ABBA.Count.B)
SB.ABBA.Count.C.Data <- as.data.frame(SB.ABBA.Count.C)
SB.ABBA.Count.D.Data <- as.data.frame(SB.ABBA.Count.D)

# For each plot name select the max value from the distance from start field
SB.ABBA.MaxDist.A <- do.call(rbind, lapply(split(SB.ABBA.HeightBasalD.A.sub,SB.ABBA.HeightBasalD.A.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.ABBA.MaxDist.B <- do.call(rbind, lapply(split(SB.ABBA.HeightBasalD.B.sub,SB.ABBA.HeightBasalD.B.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.ABBA.MaxDist.C <- do.call(rbind, lapply(split(SB.ABBA.HeightBasalD.C.sub,SB.ABBA.HeightBasalD.C.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.ABBA.MaxDist.D <- do.call(rbind, lapply(split(SB.ABBA.HeightBasalD.D.sub,SB.ABBA.HeightBasalD.D.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))

# Merge count and max distance datasets together by the plot name field
SB.ABBA.CountMaxDist.A <- merge(SB.ABBA.Count.A.Data, SB.ABBA.MaxDist.A, by.x = "PlotName", by.y = "PlotName")
SB.ABBA.CountMaxDist.B <- merge(SB.ABBA.Count.B.Data, SB.ABBA.MaxDist.B, by.x = "PlotName", by.y = "PlotName")
SB.ABBA.CountMaxDist.C <- merge(SB.ABBA.Count.C.Data, SB.ABBA.MaxDist.C, by.x = "PlotName", by.y = "PlotName")
SB.ABBA.CountMaxDist.D <- merge(SB.ABBA.Count.D.Data, SB.ABBA.MaxDist.D, by.x = "PlotName", by.y = "PlotName")

# Subset the count max distance dataset to only contain fields of interest per each height class
SB.ABBA.CountMaxDist.A.sub <- subset(SB.ABBA.CountMaxDist.A, select=c("PlotName", "Species", "Num_A_Plot", "DistanceFromStart")) 
SB.ABBA.CountMaxDist.B.sub <- subset(SB.ABBA.CountMaxDist.B, select=c("PlotName", "Species", "Num_B_Plot", "DistanceFromStart")) 
SB.ABBA.CountMaxDist.C.sub <- subset(SB.ABBA.CountMaxDist.C, select=c("PlotName", "Species", "Num_C_Plot", "DistanceFromStart")) 
SB.ABBA.CountMaxDist.D.sub <- subset(SB.ABBA.CountMaxDist.D, select=c("PlotName", "Species", "Num_D_Plot", "DistanceFromStart")) 

# Change distance from start field name to be specific for the height class
names(SB.ABBA.CountMaxDist.A.sub)[names(SB.ABBA.CountMaxDist.A.sub) == "DistanceFromStart"] <- "A_DistFromStart"
names(SB.ABBA.CountMaxDist.B.sub)[names(SB.ABBA.CountMaxDist.B.sub) == "DistanceFromStart"] <- "B_DistFromStart"
names(SB.ABBA.CountMaxDist.C.sub)[names(SB.ABBA.CountMaxDist.C.sub) == "DistanceFromStart"] <- "C_DistFromStart"
names(SB.ABBA.CountMaxDist.D.sub)[names(SB.ABBA.CountMaxDist.D.sub) == "DistanceFromStart"] <- "D_DistFromStart"

# Create a individuals per meter by dividing the number of individuals per plot by the max distance for each height class
SB.ABBA.CountMaxDist.A.sub$A_mSquared <- SB.ABBA.CountMaxDist.A.sub$Num_A_Plot/SB.ABBA.CountMaxDist.A.sub$A_DistFromStart
SB.ABBA.CountMaxDist.B.sub$B_mSquared <- SB.ABBA.CountMaxDist.B.sub$Num_B_Plot/SB.ABBA.CountMaxDist.B.sub$B_DistFromStart
SB.ABBA.CountMaxDist.C.sub$C_mSquared <- SB.ABBA.CountMaxDist.C.sub$Num_C_Plot/SB.ABBA.CountMaxDist.C.sub$C_DistFromStart
SB.ABBA.CountMaxDist.D.sub$D_mSquared <- SB.ABBA.CountMaxDist.D.sub$Num_D_Plot/SB.ABBA.CountMaxDist.D.sub$D_DistFromStart

# Create a field for the plot level estimate of the number of individuals per meter squared for each height class
SB.ABBA.CountMaxDist.A.sub$A_PlotSquared_Ceiling <- ceiling(SB.ABBA.CountMaxDist.A.sub$A_mSquared * 401.15)
SB.ABBA.CountMaxDist.B.sub$B_PlotSquared_Ceiling <- ceiling(SB.ABBA.CountMaxDist.B.sub$B_mSquared * 401.15)
SB.ABBA.CountMaxDist.C.sub$C_PlotSquared_Ceiling <- ceiling(SB.ABBA.CountMaxDist.C.sub$C_mSquared * 401.15)
SB.ABBA.CountMaxDist.D.sub$D_PlotSquared_Ceiling <- ceiling(SB.ABBA.CountMaxDist.D.sub$D_mSquared * 401.15)

# Write datasets
write.csv(SB.ABBA.CountMaxDist.A.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ABBA_A_NumbInd.csv")
write.csv(SB.ABBA.CountMaxDist.B.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ABBA_B_NumbInd.csv")
write.csv(SB.ABBA.CountMaxDist.C.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ABBA_C_NumbInd.csv")
write.csv(SB.ABBA.CountMaxDist.D.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ABBA_D_NumbInd.csv")


##### ACRU Create Shrub Height Basal Diameter Datasets #####
# Subset dataset for each height class A, B, C, and D
SB.ACRU.HeightBasalD.A <- subset(SB.ACRU, HeightCategory == "A") 
SB.ACRU.HeightBasalD.B <- subset(SB.ACRU, HeightCategory == "B") 
SB.ACRU.HeightBasalD.C <- subset(SB.ACRU, HeightCategory == "C") 
SB.ACRU.HeightBasalD.D <- subset(SB.ACRU, HeightCategory == "D") 

# Subset dataset to only include variables of interest
SB.ACRU.HeightBasalD.A.sub <- subset(SB.ACRU.HeightBasalD.A, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.ACRU.HeightBasalD.B.sub <- subset(SB.ACRU.HeightBasalD.B, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.ACRU.HeightBasalD.C.sub <- subset(SB.ACRU.HeightBasalD.C, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.ACRU.HeightBasalD.D.sub <- subset(SB.ACRU.HeightBasalD.D, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 

# Write datasets
write.csv(SB.ACRU.HeightBasalD.A.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ACRU_A.csv")
write.csv(SB.ACRU.HeightBasalD.B.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ACRU_B.csv")
write.csv(SB.ACRU.HeightBasalD.C.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ACRU_C.csv")
write.csv(SB.ACRU.HeightBasalD.D.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ACRU_D.csv")

##### Create Number of Individuals Datasets #####
# Steps are repeated for each height class
# Create new field that is the count of individuals per height class along shrub belt transect
SB.ACRU.Count.A <- count(SB.ACRU.HeightBasalD.A.sub, PlotName,  name = "Num_A_Plot")
SB.ACRU.Count.B <- count(SB.ACRU.HeightBasalD.B.sub, PlotName,  name = "Num_B_Plot")
SB.ACRU.Count.C <- count(SB.ACRU.HeightBasalD.C.sub, PlotName,  name = "Num_C_Plot")
SB.ACRU.Count.D <- count(SB.ACRU.HeightBasalD.D.sub, PlotName,  name = "Num_D_Plot")

# Set count datasets as a data frame
SB.ACRU.Count.A.Data <- as.data.frame(SB.ACRU.Count.A)
SB.ACRU.Count.B.Data <- as.data.frame(SB.ACRU.Count.B)
SB.ACRU.Count.C.Data <- as.data.frame(SB.ACRU.Count.C)
SB.ACRU.Count.D.Data <- as.data.frame(SB.ACRU.Count.D)

# For each plot name select the max value from the distance from start field
SB.ACRU.MaxDist.A <- do.call(rbind, lapply(split(SB.ACRU.HeightBasalD.A.sub,SB.ACRU.HeightBasalD.A.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.ACRU.MaxDist.B <- do.call(rbind, lapply(split(SB.ACRU.HeightBasalD.B.sub,SB.ACRU.HeightBasalD.B.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.ACRU.MaxDist.C <- do.call(rbind, lapply(split(SB.ACRU.HeightBasalD.C.sub,SB.ACRU.HeightBasalD.C.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.ACRU.MaxDist.D <- do.call(rbind, lapply(split(SB.ACRU.HeightBasalD.D.sub,SB.ACRU.HeightBasalD.D.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))

# Merge count and max distance datasets together by the plot name field
SB.ACRU.CountMaxDist.A <- merge(SB.ACRU.Count.A.Data, SB.ACRU.MaxDist.A, by.x = "PlotName", by.y = "PlotName")
SB.ACRU.CountMaxDist.B <- merge(SB.ACRU.Count.B.Data, SB.ACRU.MaxDist.B, by.x = "PlotName", by.y = "PlotName")
SB.ACRU.CountMaxDist.C <- merge(SB.ACRU.Count.C.Data, SB.ACRU.MaxDist.C, by.x = "PlotName", by.y = "PlotName")
SB.ACRU.CountMaxDist.D <- merge(SB.ACRU.Count.D.Data, SB.ACRU.MaxDist.D, by.x = "PlotName", by.y = "PlotName")

# Subset the count max distance dataset to only contain fields of interest per each height class
SB.ACRU.CountMaxDist.A.sub <- subset(SB.ACRU.CountMaxDist.A, select=c("PlotName", "Species", "Num_A_Plot", "DistanceFromStart")) 
SB.ACRU.CountMaxDist.B.sub <- subset(SB.ACRU.CountMaxDist.B, select=c("PlotName", "Species", "Num_B_Plot", "DistanceFromStart")) 
SB.ACRU.CountMaxDist.C.sub <- subset(SB.ACRU.CountMaxDist.C, select=c("PlotName", "Species", "Num_C_Plot", "DistanceFromStart")) 
SB.ACRU.CountMaxDist.D.sub <- subset(SB.ACRU.CountMaxDist.D, select=c("PlotName", "Species", "Num_D_Plot", "DistanceFromStart")) 

# Change distance from start field name to be specific for the height class
names(SB.ACRU.CountMaxDist.A.sub)[names(SB.ACRU.CountMaxDist.A.sub) == "DistanceFromStart"] <- "A_DistFromStart"
names(SB.ACRU.CountMaxDist.B.sub)[names(SB.ACRU.CountMaxDist.B.sub) == "DistanceFromStart"] <- "B_DistFromStart"
names(SB.ACRU.CountMaxDist.C.sub)[names(SB.ACRU.CountMaxDist.C.sub) == "DistanceFromStart"] <- "C_DistFromStart"
names(SB.ACRU.CountMaxDist.D.sub)[names(SB.ACRU.CountMaxDist.D.sub) == "DistanceFromStart"] <- "D_DistFromStart"

# Create a individuals per meter by dividing the number of individuals per plot by the max distance for each height class
SB.ACRU.CountMaxDist.A.sub$A_mSquared <- SB.ACRU.CountMaxDist.A.sub$Num_A_Plot/SB.ACRU.CountMaxDist.A.sub$A_DistFromStart
SB.ACRU.CountMaxDist.B.sub$B_mSquared <- SB.ACRU.CountMaxDist.B.sub$Num_B_Plot/SB.ACRU.CountMaxDist.B.sub$B_DistFromStart
SB.ACRU.CountMaxDist.C.sub$C_mSquared <- SB.ACRU.CountMaxDist.C.sub$Num_C_Plot/SB.ACRU.CountMaxDist.C.sub$C_DistFromStart
SB.ACRU.CountMaxDist.D.sub$D_mSquared <- SB.ACRU.CountMaxDist.D.sub$Num_D_Plot/SB.ACRU.CountMaxDist.D.sub$D_DistFromStart

# Create a field for the plot level estimate of the number of individuals per meter squared for each height class
SB.ACRU.CountMaxDist.A.sub$A_PlotSquared_Ceiling <- ceiling(SB.ACRU.CountMaxDist.A.sub$A_mSquared * 401.15)
SB.ACRU.CountMaxDist.B.sub$B_PlotSquared_Ceiling <- ceiling(SB.ACRU.CountMaxDist.B.sub$B_mSquared * 401.15)
SB.ACRU.CountMaxDist.C.sub$C_PlotSquared_Ceiling <- ceiling(SB.ACRU.CountMaxDist.C.sub$C_mSquared * 401.15)
SB.ACRU.CountMaxDist.D.sub$D_PlotSquared_Ceiling <- ceiling(SB.ACRU.CountMaxDist.D.sub$D_mSquared * 401.15)

# Write datasets
write.csv(SB.ACRU.CountMaxDist.A.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ACRU_A_NumbInd.csv")
write.csv(SB.ACRU.CountMaxDist.B.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ACRU_B_NumbInd.csv")
write.csv(SB.ACRU.CountMaxDist.C.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ACRU_C_NumbInd.csv")
write.csv(SB.ACRU.CountMaxDist.D.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ACRU_D_NumbInd.csv")


##### BEPA Create Shrub Height Basal Diameter Datasets #####
# Subset dataset for each height class A, B, C, and D
SB.BEPA.HeightBasalD.A <- subset(SB.BEPA, HeightCategory == "A") 
SB.BEPA.HeightBasalD.B <- subset(SB.BEPA, HeightCategory == "B") 
SB.BEPA.HeightBasalD.C <- subset(SB.BEPA, HeightCategory == "C") 
SB.BEPA.HeightBasalD.D <- subset(SB.BEPA, HeightCategory == "D") 

# Subset dataset to only include variables of interest
SB.BEPA.HeightBasalD.A.sub <- subset(SB.BEPA.HeightBasalD.A, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.BEPA.HeightBasalD.B.sub <- subset(SB.BEPA.HeightBasalD.B, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.BEPA.HeightBasalD.C.sub <- subset(SB.BEPA.HeightBasalD.C, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.BEPA.HeightBasalD.D.sub <- subset(SB.BEPA.HeightBasalD.D, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 

# Write datasets
write.csv(SB.BEPA.HeightBasalD.A.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_BEPA_A.csv")
write.csv(SB.BEPA.HeightBasalD.B.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_BEPA_B.csv")
write.csv(SB.BEPA.HeightBasalD.C.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_BEPA_C.csv")
write.csv(SB.BEPA.HeightBasalD.D.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_BEPA_D.csv")

##### Create Number of Individuals Datasets #####
# Steps are repeated for each height class
# Create new field that is the count of individuals per height class along shrub belt transect
SB.BEPA.Count.A <- count(SB.BEPA.HeightBasalD.A.sub, PlotName,  name = "Num_A_Plot")
SB.BEPA.Count.B <- count(SB.BEPA.HeightBasalD.B.sub, PlotName,  name = "Num_B_Plot")
SB.BEPA.Count.C <- count(SB.BEPA.HeightBasalD.C.sub, PlotName,  name = "Num_C_Plot")
SB.BEPA.Count.D <- count(SB.BEPA.HeightBasalD.D.sub, PlotName,  name = "Num_D_Plot")

# Set count datasets as a data frame
SB.BEPA.Count.A.Data <- as.data.frame(SB.BEPA.Count.A)
SB.BEPA.Count.B.Data <- as.data.frame(SB.BEPA.Count.B)
SB.BEPA.Count.C.Data <- as.data.frame(SB.BEPA.Count.C)
SB.BEPA.Count.D.Data <- as.data.frame(SB.BEPA.Count.D)

# For each plot name select the max value from the distance from start field
SB.BEPA.MaxDist.A <- do.call(rbind, lapply(split(SB.BEPA.HeightBasalD.A.sub,SB.BEPA.HeightBasalD.A.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.BEPA.MaxDist.B <- do.call(rbind, lapply(split(SB.BEPA.HeightBasalD.B.sub,SB.BEPA.HeightBasalD.B.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.BEPA.MaxDist.C <- do.call(rbind, lapply(split(SB.BEPA.HeightBasalD.C.sub,SB.BEPA.HeightBasalD.C.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.BEPA.MaxDist.D <- do.call(rbind, lapply(split(SB.BEPA.HeightBasalD.D.sub,SB.BEPA.HeightBasalD.D.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))

# Merge count and max distance datasets together by the plot name field
SB.BEPA.CountMaxDist.A <- merge(SB.BEPA.Count.A.Data, SB.BEPA.MaxDist.A, by.x = "PlotName", by.y = "PlotName")
SB.BEPA.CountMaxDist.B <- merge(SB.BEPA.Count.B.Data, SB.BEPA.MaxDist.B, by.x = "PlotName", by.y = "PlotName")
SB.BEPA.CountMaxDist.C <- merge(SB.BEPA.Count.C.Data, SB.BEPA.MaxDist.C, by.x = "PlotName", by.y = "PlotName")
SB.BEPA.CountMaxDist.D <- merge(SB.BEPA.Count.D.Data, SB.BEPA.MaxDist.D, by.x = "PlotName", by.y = "PlotName")

# Subset the count max distance dataset to only contain fields of interest per each height class
SB.BEPA.CountMaxDist.A.sub <- subset(SB.BEPA.CountMaxDist.A, select=c("PlotName", "Species", "Num_A_Plot", "DistanceFromStart")) 
SB.BEPA.CountMaxDist.B.sub <- subset(SB.BEPA.CountMaxDist.B, select=c("PlotName", "Species", "Num_B_Plot", "DistanceFromStart")) 
SB.BEPA.CountMaxDist.C.sub <- subset(SB.BEPA.CountMaxDist.C, select=c("PlotName", "Species", "Num_C_Plot", "DistanceFromStart")) 
SB.BEPA.CountMaxDist.D.sub <- subset(SB.BEPA.CountMaxDist.D, select=c("PlotName", "Species", "Num_D_Plot", "DistanceFromStart")) 

# Change distance from start field name to be specific for the height class
names(SB.BEPA.CountMaxDist.A.sub)[names(SB.BEPA.CountMaxDist.A.sub) == "DistanceFromStart"] <- "A_DistFromStart"
names(SB.BEPA.CountMaxDist.B.sub)[names(SB.BEPA.CountMaxDist.B.sub) == "DistanceFromStart"] <- "B_DistFromStart"
names(SB.BEPA.CountMaxDist.C.sub)[names(SB.BEPA.CountMaxDist.C.sub) == "DistanceFromStart"] <- "C_DistFromStart"
names(SB.BEPA.CountMaxDist.D.sub)[names(SB.BEPA.CountMaxDist.D.sub) == "DistanceFromStart"] <- "D_DistFromStart"

# Create a individuals per meter by dividing the number of individuals per plot by the max distance for each height class
SB.BEPA.CountMaxDist.A.sub$A_mSquared <- SB.BEPA.CountMaxDist.A.sub$Num_A_Plot/SB.BEPA.CountMaxDist.A.sub$A_DistFromStart
SB.BEPA.CountMaxDist.B.sub$B_mSquared <- SB.BEPA.CountMaxDist.B.sub$Num_B_Plot/SB.BEPA.CountMaxDist.B.sub$B_DistFromStart
SB.BEPA.CountMaxDist.C.sub$C_mSquared <- SB.BEPA.CountMaxDist.C.sub$Num_C_Plot/SB.BEPA.CountMaxDist.C.sub$C_DistFromStart
SB.BEPA.CountMaxDist.D.sub$D_mSquared <- SB.BEPA.CountMaxDist.D.sub$Num_D_Plot/SB.BEPA.CountMaxDist.D.sub$D_DistFromStart

# Create a field for the plot level estimate of the number of individuals per meter squared for each height class
SB.BEPA.CountMaxDist.A.sub$A_PlotSquared_Ceiling <- ceiling(SB.BEPA.CountMaxDist.A.sub$A_mSquared * 401.15)
SB.BEPA.CountMaxDist.B.sub$B_PlotSquared_Ceiling <- ceiling(SB.BEPA.CountMaxDist.B.sub$B_mSquared * 401.15)
SB.BEPA.CountMaxDist.C.sub$C_PlotSquared_Ceiling <- ceiling(SB.BEPA.CountMaxDist.C.sub$C_mSquared * 401.15)
SB.BEPA.CountMaxDist.D.sub$D_PlotSquared_Ceiling <- ceiling(SB.BEPA.CountMaxDist.D.sub$D_mSquared * 401.15)

# Write datasets
write.csv(SB.BEPA.CountMaxDist.A.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/BEPA_A_NumbInd.csv")
write.csv(SB.BEPA.CountMaxDist.B.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/BEPA_B_NumbInd.csv")
write.csv(SB.BEPA.CountMaxDist.C.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/BEPA_C_NumbInd.csv")
write.csv(SB.BEPA.CountMaxDist.D.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/BEPA_D_NumbInd.csv")


##### VAAN Create Shrub Height Basal Diameter Datasets #####
# Subset dataset for each height class A, B, C, and D
SB.VAAN.HeightBasalD.A <- subset(SB.VAAN, HeightCategory == "A") 
SB.VAAN.HeightBasalD.B <- subset(SB.VAAN, HeightCategory == "B") 
SB.VAAN.HeightBasalD.C <- subset(SB.VAAN, HeightCategory == "C") 

# Subset dataset to only include variables of interest
SB.VAAN.HeightBasalD.A.sub <- subset(SB.VAAN.HeightBasalD.A, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.VAAN.HeightBasalD.B.sub <- subset(SB.VAAN.HeightBasalD.B, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.VAAN.HeightBasalD.C.sub <- subset(SB.VAAN.HeightBasalD.C, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 

# Write datasets
write.csv(SB.VAAN.HeightBasalD.A.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_VAAN_A.csv")
write.csv(SB.VAAN.HeightBasalD.B.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_VAAN_B.csv")
write.csv(SB.VAAN.HeightBasalD.C.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_VAAN_C.csv")

##### Create Number of Individuals Datasets #####
# Steps are repeated for each height class
# Create new field that is the count of individuals per height class along shrub belt transect
SB.VAAN.Count.A <- count(SB.VAAN.HeightBasalD.A.sub, PlotName,  name = "Num_A_Plot")
SB.VAAN.Count.B <- count(SB.VAAN.HeightBasalD.B.sub, PlotName,  name = "Num_B_Plot")
SB.VAAN.Count.C <- count(SB.VAAN.HeightBasalD.C.sub, PlotName,  name = "Num_C_Plot")

# Set count datasets as a data frame
SB.VAAN.Count.A.Data <- as.data.frame(SB.VAAN.Count.A)
SB.VAAN.Count.B.Data <- as.data.frame(SB.VAAN.Count.B)
SB.VAAN.Count.C.Data <- as.data.frame(SB.VAAN.Count.C)

# For each plot name select the max value from the distance from start field
SB.VAAN.MaxDist.A <- do.call(rbind, lapply(split(SB.VAAN.HeightBasalD.A.sub,SB.VAAN.HeightBasalD.A.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.VAAN.MaxDist.B <- do.call(rbind, lapply(split(SB.VAAN.HeightBasalD.B.sub,SB.VAAN.HeightBasalD.B.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.VAAN.MaxDist.C <- do.call(rbind, lapply(split(SB.VAAN.HeightBasalD.C.sub,SB.VAAN.HeightBasalD.C.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))

# Merge count and max distance datasets together by the plot name field
SB.VAAN.CountMaxDist.A <- merge(SB.VAAN.Count.A.Data, SB.VAAN.MaxDist.A, by.x = "PlotName", by.y = "PlotName")
SB.VAAN.CountMaxDist.B <- merge(SB.VAAN.Count.B.Data, SB.VAAN.MaxDist.B, by.x = "PlotName", by.y = "PlotName")
SB.VAAN.CountMaxDist.C <- merge(SB.VAAN.Count.C.Data, SB.VAAN.MaxDist.C, by.x = "PlotName", by.y = "PlotName")

# Subset the count max distance dataset to only contain fields of interest per each height class
SB.VAAN.CountMaxDist.A.sub <- subset(SB.VAAN.CountMaxDist.A, select=c("PlotName", "Species", "Num_A_Plot", "DistanceFromStart")) 
SB.VAAN.CountMaxDist.B.sub <- subset(SB.VAAN.CountMaxDist.B, select=c("PlotName", "Species", "Num_B_Plot", "DistanceFromStart")) 
SB.VAAN.CountMaxDist.C.sub <- subset(SB.VAAN.CountMaxDist.C, select=c("PlotName", "Species", "Num_C_Plot", "DistanceFromStart")) 

# Change distance from start field name to be specific for the height class
names(SB.VAAN.CountMaxDist.A.sub)[names(SB.VAAN.CountMaxDist.A.sub) == "DistanceFromStart"] <- "A_DistFromStart"
names(SB.VAAN.CountMaxDist.B.sub)[names(SB.VAAN.CountMaxDist.B.sub) == "DistanceFromStart"] <- "B_DistFromStart"
names(SB.VAAN.CountMaxDist.C.sub)[names(SB.VAAN.CountMaxDist.C.sub) == "DistanceFromStart"] <- "C_DistFromStart"

# Create a individuals per meter by dividing the number of individuals per plot by the max distance for each height class
SB.VAAN.CountMaxDist.A.sub$A_mSquared <- SB.VAAN.CountMaxDist.A.sub$Num_A_Plot/SB.VAAN.CountMaxDist.A.sub$A_DistFromStart
SB.VAAN.CountMaxDist.B.sub$B_mSquared <- SB.VAAN.CountMaxDist.B.sub$Num_B_Plot/SB.VAAN.CountMaxDist.B.sub$B_DistFromStart
SB.VAAN.CountMaxDist.C.sub$C_mSquared <- SB.VAAN.CountMaxDist.C.sub$Num_C_Plot/SB.VAAN.CountMaxDist.C.sub$C_DistFromStart

# Create a field for the plot level estimate of the number of individuals per meter squared for each height class
SB.VAAN.CountMaxDist.A.sub$A_PlotSquared_Ceiling <- ceiling(SB.VAAN.CountMaxDist.A.sub$A_mSquared * 401.15)
SB.VAAN.CountMaxDist.B.sub$B_PlotSquared_Ceiling <- ceiling(SB.VAAN.CountMaxDist.B.sub$B_mSquared * 401.15)
SB.VAAN.CountMaxDist.C.sub$C_PlotSquared_Ceiling <- ceiling(SB.VAAN.CountMaxDist.C.sub$C_mSquared * 401.15)

# Write datasets
write.csv(SB.VAAN.CountMaxDist.A.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/VAAN_A_NumbInd.csv")
write.csv(SB.VAAN.CountMaxDist.B.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/VAAN_B_NumbInd.csv")
write.csv(SB.VAAN.CountMaxDist.C.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/VAAN_C_NumbInd.csv")

##### PIMA Create Shrub Height Basal Diameter Datasets #####
# Subset dataset for each height class A, B, C, and D
SB.PIMA.HeightBasalD.A <- subset(SB.PIMA, HeightCategory == "A") 
SB.PIMA.HeightBasalD.B <- subset(SB.PIMA, HeightCategory == "B") 
SB.PIMA.HeightBasalD.C <- subset(SB.PIMA, HeightCategory == "C") 
SB.PIMA.HeightBasalD.D <- subset(SB.PIMA, HeightCategory == "D") 

# Subset dataset to only include variables of interest
SB.PIMA.HeightBasalD.A.sub <- subset(SB.PIMA.HeightBasalD.A, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.PIMA.HeightBasalD.B.sub <- subset(SB.PIMA.HeightBasalD.B, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.PIMA.HeightBasalD.C.sub <- subset(SB.PIMA.HeightBasalD.C, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 
SB.PIMA.HeightBasalD.D.sub <- subset(SB.PIMA.HeightBasalD.D, select=c("PlotName", "Species", "Height", "BasalDiameter", "DistanceFromStart", "HeightCategory")) 

# Write datasets
write.csv(SB.PIMA.HeightBasalD.A.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_PIMA_A.csv")
write.csv(SB.PIMA.HeightBasalD.B.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_PIMA_B.csv")
write.csv(SB.PIMA.HeightBasalD.C.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_PIMA_C.csv")
write.csv(SB.PIMA.HeightBasalD.D.sub, "Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_PIMA_D.csv")

##### Create Number of Individuals Datasets #####
# Steps are repeated for each height class
# Create new field that is the count of individuals per height class along shrub belt transect
SB.PIMA.Count.A <- count(SB.PIMA.HeightBasalD.A.sub, PlotName,  name = "Num_A_Plot")
SB.PIMA.Count.B <- count(SB.PIMA.HeightBasalD.B.sub, PlotName,  name = "Num_B_Plot")
SB.PIMA.Count.C <- count(SB.PIMA.HeightBasalD.C.sub, PlotName,  name = "Num_C_Plot")
SB.PIMA.Count.D <- count(SB.PIMA.HeightBasalD.D.sub, PlotName,  name = "Num_D_Plot")

# Set count datasets as a data frame
SB.PIMA.Count.A.Data <- as.data.frame(SB.PIMA.Count.A)
SB.PIMA.Count.B.Data <- as.data.frame(SB.PIMA.Count.B)
SB.PIMA.Count.C.Data <- as.data.frame(SB.PIMA.Count.C)
SB.PIMA.Count.D.Data <- as.data.frame(SB.PIMA.Count.D)

# For each plot name select the max value from the distance from start field
SB.PIMA.MaxDist.A <- do.call(rbind, lapply(split(SB.PIMA.HeightBasalD.A.sub,SB.PIMA.HeightBasalD.A.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.PIMA.MaxDist.B <- do.call(rbind, lapply(split(SB.PIMA.HeightBasalD.B.sub,SB.PIMA.HeightBasalD.B.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.PIMA.MaxDist.C <- do.call(rbind, lapply(split(SB.PIMA.HeightBasalD.C.sub,SB.PIMA.HeightBasalD.C.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))
SB.PIMA.MaxDist.D <- do.call(rbind, lapply(split(SB.PIMA.HeightBasalD.D.sub,SB.PIMA.HeightBasalD.D.sub$PlotName), function(x) {return(x[which.max(x$DistanceFromStart),])}))

# Merge count and max distance datasets together by the plot name field
SB.PIMA.CountMaxDist.A <- merge(SB.PIMA.Count.A.Data, SB.PIMA.MaxDist.A, by.x = "PlotName", by.y = "PlotName")
SB.PIMA.CountMaxDist.B <- merge(SB.PIMA.Count.B.Data, SB.PIMA.MaxDist.B, by.x = "PlotName", by.y = "PlotName")
SB.PIMA.CountMaxDist.C <- merge(SB.PIMA.Count.C.Data, SB.PIMA.MaxDist.C, by.x = "PlotName", by.y = "PlotName")
SB.PIMA.CountMaxDist.D <- merge(SB.PIMA.Count.D.Data, SB.PIMA.MaxDist.D, by.x = "PlotName", by.y = "PlotName")

# Subset the count max distance dataset to only contain fields of interest per each height class
SB.PIMA.CountMaxDist.A.sub <- subset(SB.PIMA.CountMaxDist.A, select=c("PlotName", "Species", "Num_A_Plot", "DistanceFromStart")) 
SB.PIMA.CountMaxDist.B.sub <- subset(SB.PIMA.CountMaxDist.B, select=c("PlotName", "Species", "Num_B_Plot", "DistanceFromStart")) 
SB.PIMA.CountMaxDist.C.sub <- subset(SB.PIMA.CountMaxDist.C, select=c("PlotName", "Species", "Num_C_Plot", "DistanceFromStart")) 
SB.PIMA.CountMaxDist.D.sub <- subset(SB.PIMA.CountMaxDist.D, select=c("PlotName", "Species", "Num_D_Plot", "DistanceFromStart")) 

# Change distance from start field name to be specific for the height class
names(SB.PIMA.CountMaxDist.A.sub)[names(SB.PIMA.CountMaxDist.A.sub) == "DistanceFromStart"] <- "A_DistFromStart"
names(SB.PIMA.CountMaxDist.B.sub)[names(SB.PIMA.CountMaxDist.B.sub) == "DistanceFromStart"] <- "B_DistFromStart"
names(SB.PIMA.CountMaxDist.C.sub)[names(SB.PIMA.CountMaxDist.C.sub) == "DistanceFromStart"] <- "C_DistFromStart"
names(SB.PIMA.CountMaxDist.D.sub)[names(SB.PIMA.CountMaxDist.D.sub) == "DistanceFromStart"] <- "D_DistFromStart"

# Create a individuals per meter by dividing the number of individuals per plot by the max distance for each height class
SB.PIMA.CountMaxDist.A.sub$A_mSquared <- SB.PIMA.CountMaxDist.A.sub$Num_A_Plot/SB.PIMA.CountMaxDist.A.sub$A_DistFromStart
SB.PIMA.CountMaxDist.B.sub$B_mSquared <- SB.PIMA.CountMaxDist.B.sub$Num_B_Plot/SB.PIMA.CountMaxDist.B.sub$B_DistFromStart
SB.PIMA.CountMaxDist.C.sub$C_mSquared <- SB.PIMA.CountMaxDist.C.sub$Num_C_Plot/SB.PIMA.CountMaxDist.C.sub$C_DistFromStart
SB.PIMA.CountMaxDist.D.sub$D_mSquared <- SB.PIMA.CountMaxDist.D.sub$Num_D_Plot/SB.PIMA.CountMaxDist.D.sub$D_DistFromStart

# Create a field for the plot level estimate of the number of individuals per meter squared for each height class
SB.PIMA.CountMaxDist.A.sub$A_PlotSquared_Ceiling <- ceiling(SB.PIMA.CountMaxDist.A.sub$A_mSquared * 401.15)
SB.PIMA.CountMaxDist.B.sub$B_PlotSquared_Ceiling <- ceiling(SB.PIMA.CountMaxDist.B.sub$B_mSquared * 401.15)
SB.PIMA.CountMaxDist.C.sub$C_PlotSquared_Ceiling <- ceiling(SB.PIMA.CountMaxDist.C.sub$C_mSquared * 401.15)
SB.PIMA.CountMaxDist.D.sub$D_PlotSquared_Ceiling <- ceiling(SB.PIMA.CountMaxDist.D.sub$D_mSquared * 401.15)

# Write datasets
write.csv(SB.PIMA.CountMaxDist.A.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/PIMA_A_NumbInd.csv")
write.csv(SB.PIMA.CountMaxDist.B.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/PIMA_B_NumbInd.csv")
write.csv(SB.PIMA.CountMaxDist.C.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/PIMA_C_NumbInd.csv")
write.csv(SB.PIMA.CountMaxDist.D.sub, "Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/PIMA_D_NumbInd.csv")


