# Date of last change: 8/March/2019

# Notes:
# Processing of shrub belt density estimates for our Spp of Interest
# Fit biomass to basal diameter, height - predicted biomass estimates for each height class
# Calculate molar mass from biomass and compute stoich ratios on a molar mass basis
# There are occurrences where we sampled a plant species foliage within a given plot but did not encounter these species on the shrub belt; thus ending up with NA values in the dataset for ratio stoichiometry and quantity estimates. To remedy this situation, we pulled information from the foliar stoichiometry sample dataset; using the sampled species height and basal diameter and added this to the appropriate height class dataset (i.e., if we had a ABBA sample with a height of 43 cm we added that one individual as a single count to the SB_ABBA_A dataset). Furthermore, we set the distance to start value to the last possible value; on the shrub belt transect (i.e., 22.6m).
# Old Ratio datasets with these missing values are saved in the Ratio folder as Species_Ratio_OldDatasetwNAs.csv

options(scipen = 999)

# Set working directory
setwd("~/Dropbox (HeckfordT)/PhD_Thesis/Chapter_PlantTraitLandscapes/")

#Clear all previous data
rm(list=ls())

# Install/load the following packages
#install.packages("easypackages")
library(easypackages)
libraries("ggplot2", "ggpubr")

# Load stoichiometry data from the lab
Stoi <- read.csv("Data/Original/2016_Lab_FoliarStoichiometry/StoichFromLabAnalysis_Clean_2019May19.csv")
str(Stoi) # Total stoichiometry records are 574
# Subset foliage chemistry data by species
# Subset the data by species --> we will construct models based on species foliage chemistry.
Stoi.ABBA <- subset(Stoi, Species == "ABBA")
Stoi.ACRU <- subset(Stoi, Species == "ACRU")
Stoi.BEPA <- subset(Stoi, Species == "BEPA")
Stoi.PIMA <- subset(Stoi, Species == "PIMA")
Stoi.VAAN <- subset (Stoi, Species == "VAAN")
str(Stoi.ABBA)
str(Stoi.ACRU)
str(Stoi.BEPA)
str(Stoi.PIMA)
str(Stoi.VAAN)

# Format data for Qty models and fit Qty and elemental ratio models
# Load Shrub Belt data for each species by height class (A, B, C, D)
# ABBA
ABBA_A <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ABBA_A.csv")
ABBA_B <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ABBA_B.csv")
ABBA_C <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ABBA_C.csv")
ABBA_D <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ABBA_D.csv")
str(ABBA_A)
str(ABBA_B)
str(ABBA_C)
str(ABBA_D)

# ACRU
ACRU_A <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ACRU_A.csv")
ACRU_B <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ACRU_B.csv")
ACRU_C <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ACRU_C.csv")
ACRU_D <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_ACRU_D.csv")
str(ACRU_A)
str(ACRU_B)
str(ACRU_C)
str(ACRU_D)

# BEPA
BEPA_A <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_BEPA_A.csv")
BEPA_B <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_BEPA_B.csv")
BEPA_C <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_BEPA_C.csv")
BEPA_D <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_BEPA_D.csv")
str(BEPA_A)
str(BEPA_B)
str(BEPA_C)
str(BEPA_D)

# PIMA
PIMA_A <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_PIMA_A.csv")
PIMA_B <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_PIMA_B.csv")
PIMA_C <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_PIMA_C.csv")
PIMA_D <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_PIMA_D.csv")
str(PIMA_A)
str(PIMA_B)
str(PIMA_C)
str(PIMA_D)

# VAAN
VAAN_A <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_VAAN_A.csv")
VAAN_B <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_VAAN_B.csv")
VAAN_C <- read.csv("Data/Quantity/ShrubBelt/Shrub_HeightBasalData/SB_VAAN_C.csv")
str(VAAN_A)
str(VAAN_B)
str(VAAN_C)

# Get mean of each height class/species of small (A = 0-50cm), medium (B = >50 - 100cm), large (C = >100 - 150 cm), and x-large (D = >150 -200cm)
# ABBA
ABBA_A_H <- tapply(ABBA_A$Height, ABBA_A$PlotName, mean)
ABBA_B_H <- tapply(ABBA_B$Height, ABBA_B$PlotName, mean)
ABBA_C_H <- tapply(ABBA_C$Height, ABBA_C$PlotName, mean)
ABBA_D_H <- tapply(ABBA_D$Height, ABBA_D$PlotName, mean)
str(ABBA_A_H)
str(ABBA_B_H)
str(ABBA_C_H)
str(ABBA_D_H)

# ACRU
ACRU_A_H <- tapply(ACRU_A$Height, ACRU_A$PlotName, mean)
ACRU_B_H <- tapply(ACRU_B$Height, ACRU_B$PlotName, mean)
ACRU_C_H <- tapply(ACRU_C$Height, ACRU_C$PlotName, mean)
ACRU_D_H <- tapply(ACRU_D$Height, ACRU_D$PlotName, mean)
str(ACRU_A_H)
str(ACRU_B_H)
str(ACRU_C_H)
str(ACRU_D_H)

# BEPA
BEPA_A_H <- tapply(BEPA_A$Height, BEPA_A$PlotName, mean)
BEPA_B_H <- tapply(BEPA_B$Height, BEPA_B$PlotName, mean)
BEPA_C_H <- tapply(BEPA_C$Height, BEPA_C$PlotName, mean)
BEPA_D_H <- tapply(BEPA_D$Height, BEPA_D$PlotName, mean)
str(BEPA_A_H)
str(BEPA_B_H)
str(BEPA_C_H)
str(BEPA_D_H)

# PIMA
PIMA_A_H <- tapply(PIMA_A$Height, PIMA_A$PlotName, mean)
PIMA_B_H <- tapply(PIMA_B$Height, PIMA_B$PlotName, mean)
PIMA_C_H <- tapply(PIMA_C$Height, PIMA_C$PlotName, mean)
PIMA_D_H <- tapply(PIMA_D$Height, PIMA_D$PlotName, mean)
str(PIMA_A_H)
str(PIMA_B_H)
str(PIMA_C_H)
str(PIMA_D_H)

# VAAN
VAAN_A_H <- tapply(VAAN_A$Height, VAAN_A$PlotName, mean)
VAAN_B_H <- tapply(VAAN_B$Height, VAAN_B$PlotName, mean)
VAAN_C_H <- tapply(VAAN_C$Height, VAAN_C$PlotName, mean)
str(VAAN_A_H)
str(VAAN_B_H)
str(VAAN_C_H)

# Make table of mean height of small, medium, large, and x-large
# ABBA
ABBA_A_MeanH <- data.frame(PlotName=names(ABBA_A_H), value=ABBA_A_H)
ABBA_B_MeanH <- data.frame(PlotName=names(ABBA_B_H), value=ABBA_B_H)
ABBA_C_MeanH <- data.frame(PlotName=names(ABBA_C_H), value=ABBA_C_H)
ABBA_D_MeanH <- data.frame(PlotName=names(ABBA_D_H), value=ABBA_D_H)
str(ABBA_A_MeanH)
str(ABBA_B_MeanH)
str(ABBA_C_MeanH)
str(ABBA_D_MeanH)

# ACRU
ACRU_A_MeanH <- data.frame(PlotName=names(ACRU_A_H), value=ACRU_A_H)
ACRU_B_MeanH <- data.frame(PlotName=names(ACRU_B_H), value=ACRU_B_H)
ACRU_C_MeanH <- data.frame(PlotName=names(ACRU_C_H), value=ACRU_C_H)
ACRU_D_MeanH <- data.frame(PlotName=names(ACRU_D_H), value=ACRU_D_H)
str(ACRU_A_MeanH)
str(ACRU_B_MeanH)
str(ACRU_C_MeanH)
str(ACRU_D_MeanH)

# BEPA
BEPA_A_MeanH <- data.frame(PlotName=names(BEPA_A_H), value=BEPA_A_H)
BEPA_B_MeanH <- data.frame(PlotName=names(BEPA_B_H), value=BEPA_B_H)
BEPA_C_MeanH <- data.frame(PlotName=names(BEPA_C_H), value=BEPA_C_H)
BEPA_D_MeanH <- data.frame(PlotName=names(BEPA_D_H), value=BEPA_D_H)
str(BEPA_A_MeanH)
str(BEPA_B_MeanH)
str(BEPA_C_MeanH)
str(BEPA_D_MeanH)

# PIMA
PIMA_A_MeanH <- data.frame(PlotName=names(PIMA_A_H), value=PIMA_A_H)
PIMA_B_MeanH <- data.frame(PlotName=names(PIMA_B_H), value=PIMA_B_H)
PIMA_C_MeanH <- data.frame(PlotName=names(PIMA_C_H), value=PIMA_C_H)
PIMA_D_MeanH <- data.frame(PlotName=names(PIMA_D_H), value=PIMA_D_H)
str(PIMA_A_MeanH)
str(PIMA_B_MeanH)
str(PIMA_C_MeanH)
str(PIMA_D_MeanH)

# VAAN
VAAN_A_MeanH <- data.frame(PlotName=names(VAAN_A_H), value=VAAN_A_H)
VAAN_B_MeanH <- data.frame(PlotName=names(VAAN_B_H), value=VAAN_B_H)
VAAN_C_MeanH <- data.frame(PlotName=names(VAAN_C_H), value=VAAN_C_H)
str(VAAN_A_MeanH)
str(VAAN_B_MeanH)
str(VAAN_C_MeanH)


# Get mean basal diameter of small, medium, large, and x-large
# ABBA
ABBA_A_BD <- tapply(ABBA_A$BasalDiameter, ABBA_A$PlotName, mean)
ABBA_B_BD <- tapply(ABBA_B$BasalDiameter, ABBA_B$PlotName, mean)
ABBA_C_BD <- tapply(ABBA_C$BasalDiameter, ABBA_C$PlotName, mean)
ABBA_D_BD <- tapply(ABBA_D$BasalDiameter, ABBA_D$PlotName, mean)
str(ABBA_A_BD)
str(ABBA_B_BD)
str(ABBA_C_BD)
str(ABBA_D_BD)

# ACRU
ACRU_A_BD <- tapply(ACRU_A$BasalDiameter, ACRU_A$PlotName, mean)
ACRU_B_BD <- tapply(ACRU_B$BasalDiameter, ACRU_B$PlotName, mean)
ACRU_C_BD <- tapply(ACRU_C$BasalDiameter, ACRU_C$PlotName, mean)
ACRU_D_BD <- tapply(ACRU_D$BasalDiameter, ACRU_D$PlotName, mean)
str(ACRU_A_BD)
str(ACRU_B_BD)
str(ACRU_C_BD)
str(ACRU_D_BD)

# BEPA
BEPA_A_BD <- tapply(BEPA_A$BasalDiameter, BEPA_A$PlotName, mean)
BEPA_B_BD <- tapply(BEPA_B$BasalDiameter, BEPA_B$PlotName, mean)
BEPA_C_BD <- tapply(BEPA_C$BasalDiameter, BEPA_C$PlotName, mean)
BEPA_D_BD <- tapply(BEPA_D$BasalDiameter, BEPA_D$PlotName, mean)
str(BEPA_A_BD)
str(BEPA_B_BD)
str(BEPA_C_BD)
str(BEPA_D_BD)

# PIMA
PIMA_A_BD <- tapply(PIMA_A$BasalDiameter, PIMA_A$PlotName, mean)
PIMA_B_BD <- tapply(PIMA_B$BasalDiameter, PIMA_B$PlotName, mean)
PIMA_C_BD <- tapply(PIMA_C$BasalDiameter, PIMA_C$PlotName, mean)
PIMA_D_BD <- tapply(PIMA_D$BasalDiameter, PIMA_D$PlotName, mean)
str(PIMA_A_BD)
str(PIMA_B_BD)
str(PIMA_C_BD)
str(PIMA_D_BD)

# VAAN
VAAN_A_BD <- tapply(VAAN_A$BasalDiameter, VAAN_A$PlotName, mean)
VAAN_B_BD <- tapply(VAAN_B$BasalDiameter, VAAN_B$PlotName, mean)
VAAN_C_BD <- tapply(VAAN_C$BasalDiameter, VAAN_C$PlotName, mean)
str(VAAN_A_BD)
str(VAAN_B_BD)
str(VAAN_C_BD)

# Make table of mean basal diameter for ABBA, ACRU, BEPA, and VAAN, per plotname ####
# ABBA
ABBA_A_MeanBD <- data.frame(PlotName=names(ABBA_A_BD), value=ABBA_A_BD)
ABBA_B_MeanBD <- data.frame(PlotName=names(ABBA_B_BD), value=ABBA_B_BD)
ABBA_C_MeanBD <- data.frame(PlotName=names(ABBA_C_BD), value=ABBA_C_BD)
ABBA_D_MeanBD <- data.frame(PlotName=names(ABBA_D_BD), value=ABBA_D_BD)
str(ABBA_A_MeanBD)
str(ABBA_B_MeanBD)
str(ABBA_C_MeanBD)
str(ABBA_D_MeanBD)

# ACRU
ACRU_A_MeanBD <- data.frame(PlotName=names(ACRU_A_BD), value=ACRU_A_BD)
ACRU_B_MeanBD <- data.frame(PlotName=names(ACRU_B_BD), value=ACRU_B_BD)
ACRU_C_MeanBD <- data.frame(PlotName=names(ACRU_C_BD), value=ACRU_C_BD)
ACRU_D_MeanBD <- data.frame(PlotName=names(ACRU_D_BD), value=ACRU_D_BD)
str(ACRU_A_MeanBD)
str(ACRU_B_MeanBD)
str(ACRU_C_MeanBD)
str(ACRU_D_MeanBD)

# BEPA
BEPA_A_MeanBD <- data.frame(PlotName=names(BEPA_A_BD), value=BEPA_A_BD)
BEPA_B_MeanBD <- data.frame(PlotName=names(BEPA_B_BD), value=BEPA_B_BD)
BEPA_C_MeanBD <- data.frame(PlotName=names(BEPA_C_BD), value=BEPA_C_BD)
BEPA_D_MeanBD <- data.frame(PlotName=names(BEPA_D_BD), value=BEPA_D_BD)
str(BEPA_A_MeanBD)
str(BEPA_B_MeanBD)
str(BEPA_C_MeanBD)
str(BEPA_D_MeanBD)

# PIMA
PIMA_A_MeanBD <- data.frame(PlotName=names(PIMA_A_BD), value=PIMA_A_BD)
PIMA_B_MeanBD <- data.frame(PlotName=names(PIMA_B_BD), value=PIMA_B_BD)
PIMA_C_MeanBD <- data.frame(PlotName=names(PIMA_C_BD), value=PIMA_C_BD)
PIMA_D_MeanBD <- data.frame(PlotName=names(PIMA_D_BD), value=PIMA_D_BD)
str(PIMA_A_MeanBD)
str(PIMA_B_MeanBD)
str(PIMA_C_MeanBD)
str(PIMA_D_MeanBD)

# VAAN
VAAN_A_MeanBD <- data.frame(PlotName=names(VAAN_A_BD), value=VAAN_A_BD)
VAAN_B_MeanBD <- data.frame(PlotName=names(VAAN_B_BD), value=VAAN_B_BD)
VAAN_C_MeanBD <- data.frame(PlotName=names(VAAN_C_BD), value=VAAN_C_BD)
str(VAAN_A_MeanBD)
str(VAAN_B_MeanBD)
str(VAAN_C_MeanBD)

# Fit model to predict browsable foliar biomass as a function of hieght and basal diameter
# Load data for ABBA, ACRU, BEPA, VAAN
ABBA_BioM <- read.csv("Data/Quantity/Biomass/BioM_ABBA.csv")
ACRU_BioM <- read.csv("Data/Quantity/Biomass/BioM_ACRU.csv")
BEPA_BioM <- read.csv("Data/Quantity/Biomass/BioM_BEPA.csv")
PIMA_BioM <- read.csv("Data/Quantity/Biomass/BioM_PIMA.csv")
VAAN_BioM <- read.csv("Data/Quantity/Biomass/BioM_VAAN.csv")
str(ABBA_BioM)
str(ACRU_BioM)
str(BEPA_BioM)
str(PIMA_BioM)
str(VAAN_BioM)

# Construct and compare biomass models

# ABBA
ABBA_DBH.1 <- lm(log(ABBA_BioM$Dry_Weight) ~ log(ABBA_BioM$Height*10), data=ABBA_BioM)
ABBA_DBH.2 <- lm(log(ABBA_BioM$Dry_Weight) ~ log(ABBA_BioM$BasalDiameter), data=ABBA_BioM)
ABBA_DBH.3 <- lm(log(ABBA_BioM$Dry_Weight) ~ log(ABBA_BioM$BasalDiameter) + log(ABBA_BioM$Height*10), data=ABBA_BioM)
summary(ABBA_DBH.1)
summary(ABBA_DBH.2)
summary(ABBA_DBH.3)
ABBA_Allo <- ggplot(ABBA_BioM, aes(x=log((BasalDiameter)+log(Height*10)), y=log(Dry_Weight))) + geom_point() + geom_smooth(method="lm", formula=y~x, se=F, linetype=1, fullrange=TRUE)+ theme(legend.position="none") + theme_classic() + theme(axis.title.y = element_blank()) + theme(axis.title.x = element_blank(), axis.text.x = element_text(size=12), axis.text.y = element_text(size=12)) + ggtitle("(a)") + ylim(0, 5)


# ACRU
ACRU_DBH.1 <- lm(log(ACRU_BioM$Dry_Weight) ~ log(ACRU_BioM$Height*10), data=ACRU_BioM)
ACRU_DBH.2 <- lm(log(ACRU_BioM$Dry_Weight) ~ log(ACRU_BioM$BasalDiameter), data=ACRU_BioM)
ACRU_DBH.3 <- lm(log(ACRU_BioM$Dry_Weight) ~ log(ACRU_BioM$BasalDiameter) + log(ACRU_BioM$Height*10), data=ACRU_BioM)
summary(ACRU_DBH.1)
summary(ACRU_DBH.2)
summary(ACRU_DBH.3)
ACRU_Allo <- ggplot(ACRU_BioM,  aes(x=log((BasalDiameter)+log(Height*10)), y=log(Dry_Weight))) + geom_point() + geom_smooth(method="lm", formula=y~x, se=F, linetype=1, fullrange=TRUE) + theme(legend.position="none") + theme_classic() + theme(axis.title.y = element_blank()) + theme(axis.title.x = element_blank(), axis.text.x = element_text(size=12), axis.text.y = element_text(size=12)) + ggtitle("(b)") + ylim(0, 5) + scale_x_continuous(breaks=c(1.7, 1.9, 2.1, 2.3, 2.5, 2.7))

# BEPA
BEPA_DBH.1 <- lm(log(BEPA_BioM$Dry_Weight) ~ log(BEPA_BioM$Height*10), data=BEPA_BioM)
BEPA_DBH.2 <- lm(log(BEPA_BioM$Dry_Weight) ~ log(BEPA_BioM$BasalDiameter), data=BEPA_BioM)
BEPA_DBH.3 <- lm(log(BEPA_BioM$Dry_Weight) ~ log(BEPA_BioM$BasalDiameter) + log(BEPA_BioM$Height*10), data=BEPA_BioM)
summary(BEPA_DBH.1)
summary(BEPA_DBH.2)
summary(BEPA_DBH.3)
BEPA_Allo <- ggplot(BEPA_BioM, aes(x=log((BasalDiameter)+log(Height*10)), y=log(Dry_Weight))) + geom_point() + geom_smooth(method="lm", formula=y~x, se=F, linetype=1, fullrange=TRUE) + theme(legend.position="none") + theme_classic() + theme(axis.title.y = element_blank()) + theme(axis.title.x = element_blank(), axis.text.x = element_text(size=12), axis.text.y = element_text(size=12)) + ggtitle("(c)") + ylim(0, 5) + scale_x_continuous(breaks=c(1.9, 2.1, 2.3, 2.5, 2.7)) + xlim(1.9, 2.8)

# PIMA
PIMA_DBH.1 <- lm(log(PIMA_BioM$Dry_Weight) ~ log(PIMA_BioM$Height*10), data=PIMA_BioM)
PIMA_DBH.2 <- lm(log(PIMA_BioM$Dry_Weight) ~ log(PIMA_BioM$BasalDiameter), data=PIMA_BioM)
PIMA_DBH.3 <- lm(log(PIMA_BioM$Dry_Weight) ~ log(PIMA_BioM$BasalDiameter) + log(PIMA_BioM$Height*10), data=PIMA_BioM)
summary(PIMA_DBH.1)
summary(PIMA_DBH.2)
summary(PIMA_DBH.3)
PIMA_Allo <- ggplot(PIMA_BioM, aes(x=log((BasalDiameter)+log(Height*10)), y=log(Dry_Weight))) + geom_point() + geom_smooth(method="lm", formula=y~x, se=F, linetype=1, fullrange=TRUE) + theme(legend.position="none") + theme_classic() + theme(axis.title.y = element_blank()) + theme(axis.title.x = element_blank(), axis.text.x = element_text(size=12), axis.text.y = element_text(size=12)) + ggtitle("(d)") + ylim(0, 5) + scale_x_continuous(breaks=c(1.9, 2.1, 2.3, 2.5, 2.7))

# VAAN
VAAN_DBH.1 <- lm(log(VAAN_BioM$Dry_Weight) ~ log(VAAN_BioM$Height*10), data=VAAN_BioM)
VAAN_DBH.2 <- lm(log(VAAN_BioM$Dry_Weight) ~ log(VAAN_BioM$BasalDiameter), data=VAAN_BioM)
VAAN_DBH.3 <- lm(log(VAAN_BioM$Dry_Weight) ~ log(VAAN_BioM$BasalDiameter) + log(VAAN_BioM$Height*10), data=VAAN_BioM)
summary(VAAN_DBH.1)
summary(VAAN_DBH.2)
summary(VAAN_DBH.3)
VAAN_Allo <- ggplot(VAAN_BioM, aes(x=log((BasalDiameter)+log(Height*10)), y=log(Dry_Weight))) + geom_point() + geom_smooth(method="lm", formula=y~x, se=F, linetype=1, fullrange=TRUE) + theme(legend.position="none") + theme_classic() + theme(axis.title.y = element_blank()) + theme(axis.title.x = element_blank(), axis.text.x = element_text(size=12), axis.text.y = element_text(size=12)) + ggtitle("(e)") + ylim(0, 3)


# Export high res graph of all allometry model plots
png("Deliverables/Allometry/Allometric_v2.png", width = 10, height = 5, units = "in", res = 600)
Allo.Figure <- ggarrange(ABBA_Allo, ACRU_Allo, BEPA_Allo, PIMA_Allo, VAAN_Allo, ncol=5, nrow=1) 
annotate_figure(Allo.Figure, bottom = text_grob("Log Basal Diameter + Height (cm)", size=13), left = text_grob("Log Biomass (g)", size=13, rot=90))
dev.off()


# Fit biomass models to the above transect data and get mean biomass of a small, medium, large, and x-large
# (a) Use coefficients from the model with the highest R^2
# ABBA model # 3
ABBA_A_MeanH$lnBiomass <- -5.5008 + 1.2729*log(ABBA_A_MeanBD$value) + 1.1143*log(ABBA_A_MeanH$value*10)
ABBA_B_MeanH$lnBiomass <- -5.5008 + 1.2729*log(ABBA_B_MeanBD$value) + 1.1143*log(ABBA_B_MeanH$value*10)
ABBA_C_MeanH$lnBiomass <- -5.5008 + 1.2729*log(ABBA_C_MeanBD$value) + 1.1143*log(ABBA_C_MeanH$value*10)
ABBA_D_MeanH$lnBiomass <- -5.5008 + 1.2729*log(ABBA_D_MeanBD$value) + 1.1143*log(ABBA_D_MeanH$value*10)
# ACRU model # 3
ACRU_A_MeanH$lnBiomass <- -7.5894 + 0.5742*log(ACRU_A_MeanBD$value) + 1.4072*log(ACRU_A_MeanH$value*10)
ACRU_B_MeanH$lnBiomass <- -7.5894 + 0.5742*log(ACRU_B_MeanBD$value) + 1.4072*log(ACRU_B_MeanH$value*10)
ACRU_C_MeanH$lnBiomass <- -7.5894 + 0.5742*log(ACRU_C_MeanBD$value) + 1.4072*log(ACRU_C_MeanH$value*10)
ACRU_D_MeanH$lnBiomass <- -7.5894 + 0.5742*log(ACRU_D_MeanBD$value) + 1.4072*log(ACRU_D_MeanH$value*10)
# BEPA model # 3
BEPA_A_MeanH$lnBiomass <- -8.1074 + 0.7263*log(BEPA_A_MeanBD$value) + 1.4036*log(BEPA_A_MeanH$value*10) 
BEPA_B_MeanH$lnBiomass <- -8.1074 + 0.7263*log(BEPA_B_MeanBD$value) + 1.4036*log(BEPA_B_MeanH$value*10)
BEPA_C_MeanH$lnBiomass <- -8.1074 + 0.7263*log(BEPA_C_MeanBD$value) + 1.4036*log(BEPA_C_MeanH$value*10)
BEPA_D_MeanH$lnBiomass <- -8.1074 + 0.7263*log(BEPA_D_MeanBD$value) + 1.4036*log(BEPA_D_MeanH$value*10)
# PIMA model # 3
PIMA_A_MeanH$lnBiomass <- -3.1187 + 1.5262*log(PIMA_A_MeanBD$value) + 0.6563*log(PIMA_A_MeanH$value*10)
PIMA_B_MeanH$lnBiomass <- -3.1187 + 1.5262*log(PIMA_B_MeanBD$value) + 0.6563*log(PIMA_B_MeanH$value*10)
PIMA_C_MeanH$lnBiomass <- -3.1187 + 1.5262*log(PIMA_C_MeanBD$value) + 0.6563*log(PIMA_C_MeanH$value*10)
PIMA_D_MeanH$lnBiomass <- -3.1187 + 1.5262*log(PIMA_D_MeanBD$value) + 0.6563*log(PIMA_D_MeanH$value*10)
# VAAN model # 3
VAAN_A_MeanH$lnBiomass <- -4.3215 + 0.7914*log(VAAN_A_MeanBD$value) + 0.9343*log(VAAN_A_MeanH$value*10)
VAAN_B_MeanH$lnBiomass <- -4.3215 + 0.7914*log(VAAN_B_MeanBD$value) + 0.9343*log(VAAN_B_MeanH$value*10)
VAAN_C_MeanH$lnBiomass <- -4.3215 + 0.7914*log(VAAN_C_MeanBD$value) + 0.9343*log(VAAN_C_MeanH$value*10)

# Get rid of ln - take exp of lnBiomass
# ABBA
ABBA_A_MeanH$Biomass <- exp(ABBA_A_MeanH$lnBiomass)
ABBA_B_MeanH$Biomass <- exp(ABBA_B_MeanH$lnBiomass)
ABBA_C_MeanH$Biomass <- exp(ABBA_C_MeanH$lnBiomass)
ABBA_D_MeanH$Biomass <- exp(ABBA_D_MeanH$lnBiomass)
# ACRU
ACRU_A_MeanH$Biomass <- exp(ACRU_A_MeanH$lnBiomass)
ACRU_B_MeanH$Biomass <- exp(ACRU_B_MeanH$lnBiomass)
ACRU_C_MeanH$Biomass <- exp(ACRU_C_MeanH$lnBiomass)
ACRU_D_MeanH$Biomass <- exp(ACRU_D_MeanH$lnBiomass)
# BEPA
BEPA_A_MeanH$Biomass <- exp(BEPA_A_MeanH$lnBiomass)
BEPA_B_MeanH$Biomass <- exp(BEPA_B_MeanH$lnBiomass)
BEPA_C_MeanH$Biomass <- exp(BEPA_C_MeanH$lnBiomass)
BEPA_D_MeanH$Biomass <- exp(BEPA_D_MeanH$lnBiomass)
# PIMA
PIMA_A_MeanH$Biomass <- exp(PIMA_A_MeanH$lnBiomass)
PIMA_B_MeanH$Biomass <- exp(PIMA_B_MeanH$lnBiomass)
PIMA_C_MeanH$Biomass <- exp(PIMA_C_MeanH$lnBiomass)
PIMA_D_MeanH$Biomass <- exp(PIMA_D_MeanH$lnBiomass)
# VAAN
VAAN_A_MeanH$Biomass <- exp(VAAN_A_MeanH$lnBiomass)
VAAN_B_MeanH$Biomass <- exp(VAAN_B_MeanH$lnBiomass)
VAAN_C_MeanH$Biomass <- exp(VAAN_C_MeanH$lnBiomass)


# Get biomass of A/B/C/D for a plot-level biomass estimate
# For the number of individual database we perform following calculations:
# Plot squared = num_plot (the number of individuals on the shrub belt encounter)/distance from start (furthest distance from the start)
# Plot squared ceiling = Ceiling(401.15*plot squared, 1) --> calculated

# Get total biomass of sm, md, lg individuals per plot. 
# Multiply average small, medium, large biomass by # of individuals to get qty of sm, md, lg per plot
# Then sum across size classes to get plot-level biomass estimate.
# First construct database with all height classes per species, using a series of merges
# Import PlotName csv
PlotName <- read.csv("Data/Quantity/ShrubBelt/PlotName.csv")
str(PlotName)
# Import transect summary data - number of individuals
# Note the ceiling estimate provided was calculated as follows:
# Plot Squared = (number species in a plot/distant from start @ the last individual measured (furtherest point on shrub belt transect)) * plot ceiling = 401.15m^2
# the plot squared values was then rounding using the Ceiling function = (#, 1) in Excel (conservative estimate)
# ABBA
ABBA_A_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ABBA_A_NumbInd.csv")
ABBA_B_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ABBA_B_NumbInd.csv")
ABBA_C_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ABBA_C_NumbInd.csv")
ABBA_D_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ABBA_D_NumbInd.csv")
str(ABBA_A_NI)
str(ABBA_B_NI)
str(ABBA_C_NI)
str(ABBA_D_NI)
# ACRU
ACRU_A_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ACRU_A_NumbInd.csv")
ACRU_B_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ACRU_B_NumbInd.csv")
ACRU_C_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ACRU_C_NumbInd.csv")
ACRU_D_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/ACRU_D_NumbInd.csv")
str(ACRU_A_NI)
str(ACRU_B_NI)
str(ACRU_C_NI)
str(ACRU_D_NI)
# BEPA
BEPA_A_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/BEPA_A_NumbInd.csv")
BEPA_B_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/BEPA_B_NumbInd.csv")
BEPA_C_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/BEPA_C_NumbInd.csv")
BEPA_D_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/BEPA_D_NumbInd.csv")
str(BEPA_A_NI)
str(BEPA_B_NI)
str(BEPA_C_NI)
str(BEPA_D_NI)
# PIMA
PIMA_A_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/PIMA_A_NumbInd.csv")
PIMA_B_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/PIMA_B_NumbInd.csv")
PIMA_C_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/PIMA_C_NumbInd.csv")
PIMA_D_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/PIMA_D_NumbInd.csv")
str(PIMA_A_NI)
str(PIMA_B_NI)
str(PIMA_C_NI)
str(PIMA_D_NI)
# VAAN
VAAN_A_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/VAAN_A_NumbInd.csv")
VAAN_B_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/VAAN_B_NumbInd.csv")
VAAN_C_NI <- read.csv("Data/Quantity/ShrubBelt/Shrub_Numb_Individuals/VAAN_C_NumbInd.csv")
str(VAAN_A_NI)
str(VAAN_B_NI)
str(VAAN_C_NI)

# Construct ABBA height class (density) database; join to plot name dataset which contains all the plotnames for our sample locations (n = 200)
PN_ABBA_A <- merge(PlotName, ABBA_A_NI, by="PlotName", all.x=T)
PN_ABBA_B <- merge(PlotName, ABBA_B_NI, by="PlotName", all.x=T)
PN_ABBA_C <- merge(PlotName, ABBA_C_NI, by="PlotName", all.x=T)
PN_ABBA_D <- merge(PlotName, ABBA_D_NI, by="PlotName", all.x=T)
ABBA_AB <- merge(PN_ABBA_A, PN_ABBA_B, by="PlotName", all = T)
ABBA_CD <- merge(PN_ABBA_C, PN_ABBA_D, by="PlotName", all = T)
ABBA_Density <- merge(ABBA_AB, ABBA_CD, by="PlotName", all=T)
str(PN_ABBA_A)
str(PN_ABBA_B)
str(PN_ABBA_C)
str(PN_ABBA_D)
str(ABBA_AB)
str(ABBA_CD)
str(ABBA_Density)
# Construct ACRU height class (density) database
PN_ACRU_A <- merge(PlotName, ACRU_A_NI, by="PlotName", all.x=T)
PN_ACRU_B <- merge(PlotName, ACRU_B_NI, by="PlotName", all.x=T)
PN_ACRU_C <- merge(PlotName, ACRU_C_NI, by="PlotName", all.x=T)
PN_ACRU_D <- merge(PlotName, ACRU_D_NI, by="PlotName", all.x=T)
ACRU_AB <- merge(PN_ACRU_A, PN_ACRU_B, by="PlotName", all = T)
ACRU_CD <- merge (PN_ACRU_C, PN_ACRU_D, by="PlotName", all = T)
ACRU_Density <- merge(ACRU_AB, ACRU_CD, by="PlotName", all=T)
str(PN_ACRU_A)
str(PN_ACRU_B)
str(PN_ACRU_C)
str(PN_ACRU_D)
str(ACRU_AB)
str(ACRU_CD)
str(ACRU_Density)
# Construct BEPA height class (density) database
PN_BEPA_A <- merge(PlotName, BEPA_A_NI, by="PlotName", all.x=T)
PN_BEPA_B <- merge(PlotName, BEPA_B_NI, by="PlotName", all.x=T)
PN_BEPA_C <- merge(PlotName, BEPA_C_NI, by="PlotName", all.x=T)
PN_BEPA_D <- merge(PlotName, BEPA_D_NI, by="PlotName", all.x=T)
BEPA_AB <- merge(PN_BEPA_A, PN_BEPA_B, by="PlotName", all = T)
BEPA_CD <- merge (PN_BEPA_C, PN_BEPA_D, by="PlotName", all = T)
BEPA_Density <- merge(BEPA_AB, BEPA_CD, by="PlotName", all=T)
str(PN_BEPA_A)
str(PN_BEPA_B)
str(PN_BEPA_C)
str(PN_BEPA_D)
str(BEPA_AB)
str(BEPA_CD)
str(BEPA_Density)
# Construct PIMA height class (density) database; join to plot name dataset which contains all the plotnames for our sample locations (n = 200)
PN_PIMA_A <- merge(PlotName, PIMA_A_NI, by="PlotName", all.x=T)
PN_PIMA_B <- merge(PlotName, PIMA_B_NI, by="PlotName", all.x=T)
PN_PIMA_C <- merge(PlotName, PIMA_C_NI, by="PlotName", all.x=T)
PN_PIMA_D <- merge(PlotName, PIMA_D_NI, by="PlotName", all.x=T)
PIMA_AB <- merge(PN_PIMA_A, PN_PIMA_B, by="PlotName", all = T)
PIMA_CD <- merge(PN_PIMA_C, PN_PIMA_D, by="PlotName", all = T)
PIMA_Density <- merge(PIMA_AB, PIMA_CD, by="PlotName", all=T)
str(PN_PIMA_A)
str(PN_PIMA_B)
str(PN_PIMA_C)
str(PN_PIMA_D)
str(PIMA_AB)
str(PIMA_CD)
str(PIMA_Density)
# Construct VAAN height class (density) database
PN_VAAN_A <- merge(PlotName, VAAN_A_NI, by="PlotName", all.x=T)
PN_VAAN_B <- merge(PlotName, VAAN_B_NI, by="PlotName", all.x=T)
PN_VAAN_C <- merge(PlotName, VAAN_C_NI, by="PlotName", all.x=T)
VAAN_AB <- merge(PN_VAAN_A, PN_VAAN_B, by="PlotName", all = T)
VAAN_Density <- merge(VAAN_AB, PN_VAAN_C, by="PlotName", all=T)
str(PN_VAAN_A)
str(PN_VAAN_B)
str(PN_VAAN_C)
str(VAAN_AB)
str(VAAN_Density)

# Merge data sets so we have same number of plots for analysis
# Number will be dictated by presence or absence of a species in plot (TransectFull data)
# ABBA
QtyMergeABBA_A <- merge(ABBA_A_MeanH, ABBA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeABBA_B <- merge(ABBA_B_MeanH, ABBA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeABBA_C <- merge(ABBA_C_MeanH, ABBA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeABBA_D <- merge(ABBA_D_MeanH, ABBA_Density, by.x = "PlotName", by.y = "PlotName")
str(ABBA_A_MeanH)
str(QtyMergeABBA_A)
View(QtyMergeABBA_A)
str(ABBA_B_MeanH)
str(QtyMergeABBA_B)
str(ABBA_C_MeanH)
str(QtyMergeABBA_C)
str(ABBA_D_MeanH)
str(QtyMergeABBA_D)
View(QtyMergeABBA_D)
View(QtyMergeABBA_B)
# ACRU
QtyMergeACRU_A <- merge(ACRU_A_MeanH, ACRU_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeACRU_B <- merge(ACRU_B_MeanH, ACRU_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeACRU_C <- merge(ACRU_C_MeanH, ACRU_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeACRU_D <- merge(ACRU_D_MeanH, ACRU_Density, by.x = "PlotName", by.y = "PlotName")
str(QtyMergeACRU_A)
str(QtyMergeACRU_B)
str(QtyMergeACRU_C)
str(QtyMergeACRU_D)

# BEPA
QtyMergeBEPA_A <- merge(BEPA_A_MeanH, BEPA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeBEPA_B <- merge(BEPA_B_MeanH, BEPA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeBEPA_C <- merge(BEPA_C_MeanH, BEPA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeBEPA_D <- merge(BEPA_D_MeanH, BEPA_Density, by.x = "PlotName", by.y = "PlotName")
str(BEPA_A_MeanH)
str(QtyMergeBEPA_A)
str(QtyMergeBEPA_B)
str(QtyMergeBEPA_C)
str(QtyMergeBEPA_D)

# PIMA
QtyMergePIMA_A <- merge(PIMA_A_MeanH, PIMA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergePIMA_B <- merge(PIMA_B_MeanH, PIMA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergePIMA_C <- merge(PIMA_C_MeanH, PIMA_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergePIMA_D <- merge(PIMA_D_MeanH, PIMA_Density, by.x = "PlotName", by.y = "PlotName")
str(PIMA_A_MeanH)
str(QtyMergePIMA_A)
#View(QtyMergePIMA_A)
str(PIMA_B_MeanH)
str(QtyMergePIMA_B)
str(PIMA_C_MeanH)
str(QtyMergePIMA_C)
str(PIMA_D_MeanH)
str(QtyMergePIMA_D)
View(QtyMergePIMA_D)
View(QtyMergePIMA_B)

# VAAN
QtyMergeVAAN_A <- merge(VAAN_A_MeanH, VAAN_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeVAAN_B <- merge(VAAN_B_MeanH, VAAN_Density, by.x = "PlotName", by.y = "PlotName")
QtyMergeVAAN_C <- merge(VAAN_C_MeanH, VAAN_Density, by.x = "PlotName", by.y = "PlotName")
str(QtyMergeVAAN_A)
str(QtyMergeVAAN_B)
str(QtyMergeVAAN_C)

# Multiply A, B, C, and D biomass by # of individuals per plot
# ABBA
QtyMergeABBA_A$BiomassSm <- QtyMergeABBA_A$Biomass*QtyMergeABBA_A$A_PlotSquared_Ceiling
QtyMergeABBA_B$BiomassMd <- QtyMergeABBA_B$Biomass*QtyMergeABBA_B$B_PlotSquared_Ceiling
QtyMergeABBA_C$BiomassLg <- QtyMergeABBA_C$Biomass*QtyMergeABBA_C$C_PlotSquared_Ceiling
QtyMergeABBA_D$BiomassXL <- QtyMergeABBA_D$Biomass*QtyMergeABBA_D$D_PlotSquared_Ceiling

# ACRU
QtyMergeACRU_A$BiomassSm <- QtyMergeACRU_A$Biomass*QtyMergeACRU_A$A_PlotSquared_Ceiling
QtyMergeACRU_B$BiomassMd <- QtyMergeACRU_B$Biomass*QtyMergeACRU_B$B_PlotSquared_Ceiling
QtyMergeACRU_C$BiomassLg <- QtyMergeACRU_C$Biomass*QtyMergeACRU_C$C_PlotSquared_Ceiling
QtyMergeACRU_D$BiomassXL <- QtyMergeACRU_D$Biomass*QtyMergeACRU_D$D_PlotSquared_Ceiling

# BEPA
QtyMergeBEPA_A$BiomassSm <- QtyMergeBEPA_A$Biomass*QtyMergeBEPA_A$A_PlotSquared_Ceiling
QtyMergeBEPA_B$BiomassMd <- QtyMergeBEPA_B$Biomass*QtyMergeBEPA_B$B_PlotSquared_Ceiling
QtyMergeBEPA_C$BiomassLg <- QtyMergeBEPA_C$Biomass*QtyMergeBEPA_C$C_PlotSquared_Ceiling
QtyMergeBEPA_D$BiomassXL <- QtyMergeBEPA_D$Biomass*QtyMergeBEPA_D$D_PlotSquared_Ceiling

# PIMA
QtyMergePIMA_A$BiomassSm <- QtyMergePIMA_A$Biomass*QtyMergePIMA_A$A_PlotSquared_Ceiling
QtyMergePIMA_B$BiomassMd <- QtyMergePIMA_B$Biomass*QtyMergePIMA_B$B_PlotSquared_Ceiling
QtyMergePIMA_C$BiomassLg <- QtyMergePIMA_C$Biomass*QtyMergePIMA_C$C_PlotSquared_Ceiling
QtyMergePIMA_D$BiomassXL <- QtyMergePIMA_D$Biomass*QtyMergePIMA_D$D_PlotSquared_Ceiling

# VAAN
QtyMergeVAAN_A$BiomassSm <- QtyMergeVAAN_A$Biomass*QtyMergeVAAN_A$A_PlotSquared_Ceiling
QtyMergeVAAN_B$BiomassMd <- QtyMergeVAAN_B$Biomass*QtyMergeVAAN_B$B_PlotSquared_Ceiling
QtyMergeVAAN_C$BiomassLg <- QtyMergeVAAN_C$Biomass*QtyMergeVAAN_C$C_PlotSquared_Ceiling

# Create data frame to calculate biomass sums by plot and divide by plot area to get g per m^2
# Merge all data first with all.x and all.y = TRUE so all plot ids are included
# ABBA
BM_ABBA1 <- merge(QtyMergeABBA_A, QtyMergeABBA_B, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_ABBA2 <- merge(BM_ABBA1, QtyMergeABBA_C, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_ABBA3 <- merge(BM_ABBA2, QtyMergeABBA_D, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
str(BM_ABBA1)
str(BM_ABBA2)
str(BM_ABBA3)
View(BM_ABBA1)

# ACRU
BM_ACRU1 <- merge(QtyMergeACRU_A, QtyMergeACRU_B, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_ACRU2 <- merge(BM_ACRU1, QtyMergeACRU_C, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_ACRU3 <- merge(BM_ACRU2, QtyMergeACRU_D, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
str(BM_ACRU1)
str(BM_ACRU2)
str(BM_ACRU3)

# BEPA
BM_BEPA1 <- merge(QtyMergeBEPA_A, QtyMergeBEPA_B, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_BEPA2 <- merge(BM_BEPA1, QtyMergeBEPA_C, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_BEPA3 <- merge(BM_BEPA2, QtyMergeBEPA_D, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
str(BM_BEPA1)
str(BM_BEPA2)
str(BM_BEPA3)

# PIMA
BM_PIMA1 <- merge(QtyMergePIMA_A, QtyMergePIMA_B, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_PIMA2 <- merge(BM_PIMA1, QtyMergePIMA_C, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_PIMA3 <- merge(BM_PIMA2, QtyMergePIMA_D, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
str(BM_PIMA1)
str(BM_PIMA2)
str(BM_PIMA3)
View(BM_PIMA1)

# VAAN
BM_VAAN1 <- merge(QtyMergeVAAN_A, QtyMergeVAAN_B, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
BM_VAAN2 <- merge(BM_VAAN1, QtyMergeVAAN_C, by.x = "PlotName", by.y = "PlotName", all.x = TRUE, all.y = TRUE)
str(BM_VAAN1)
str(BM_VAAN2)

# Set NA's to "0" for biomass sum
# ABBA
BM_ABBA3[is.na(BM_ABBA3)] <- 0
BiomassSum_ABBA <- data.frame(PlotName=BM_ABBA3$PlotName, BiomassSum=BM_ABBA3$BiomassSm + BM_ABBA3$BiomassMd +BM_ABBA3$BiomassLg +BM_ABBA3$BiomassXL)
View(BM_ABBA3)
# ACRU
BM_ACRU3[is.na(BM_ACRU3)] <- 0
BiomassSum_ACRU <- data.frame(PlotName=BM_ACRU3$PlotName, BiomassSum=BM_ACRU3$BiomassSm + BM_ACRU3$BiomassMd +BM_ACRU3$BiomassLg + BM_ACRU3$BiomassXL)

# BEPA
BM_BEPA3[is.na(BM_BEPA3)] <- 0
BiomassSum_BEPA <- data.frame(PlotName=BM_BEPA3$PlotName, BiomassSum=BM_BEPA3$BiomassSm + BM_BEPA3$BiomassMd +BM_BEPA3$BiomassLg + BM_BEPA3$BiomassXL) 

# PIMA
BM_PIMA3[is.na(BM_PIMA3)] <- 0
BiomassSum_PIMA <- data.frame(PlotName=BM_PIMA3$PlotName, BiomassSum=BM_PIMA3$BiomassSm + BM_PIMA3$BiomassMd +BM_PIMA3$BiomassLg +BM_PIMA3$BiomassXL)
View(BM_PIMA3)

# VAAN
BM_VAAN2[is.na(BM_VAAN2)] <- 0
BiomassSum_VAAN <- data.frame(PlotName=BM_VAAN2$PlotName, BiomassSum=BM_VAAN2$BiomassSm + BM_VAAN2$BiomassMd +BM_VAAN2$BiomassLg)
str(BiomassSum_ABBA)
str(BiomassSum_ACRU)
str(BiomassSum_BEPA)
str(BiomassSum_PIMA)
str(BiomassSum_VAAN)

# Remove 0 from the dataset to leave only plots with biomass data
BiomassSum_ABBA_No0 <- BiomassSum_ABBA[apply(BiomassSum_ABBA[,-1],1, function(x) !any(x==0)),]
BiomassSum_ACRU_No0 <- BiomassSum_ACRU[apply(BiomassSum_ACRU[,-1],1, function(x) !any(x==0)),]
BiomassSum_BEPA_No0 <- BiomassSum_BEPA[apply(BiomassSum_BEPA[,-1],1, function(x) !any(x==0)),]
BiomassSum_PIMA_No0 <- BiomassSum_PIMA[apply(BiomassSum_PIMA[,-1],1, function(x) !any(x==0)),]
BiomassSum_VAAN_No0 <- BiomassSum_VAAN[apply(BiomassSum_VAAN[,-1],1, function(x) !any(x==0)),]
str(BiomassSum_ABBA_No0)
str(BiomassSum_ACRU_No0)
str(BiomassSum_BEPA_No0)
str(BiomassSum_PIMA_No0)
str(BiomassSum_VAAN_No0)
# Export biomass data for phytochemical use (ABBA only) after this point biomass is further reduced for only locations with stoichiometry
write.csv(BiomassSum_ABBA_No0, "Data/Phytochemical/ABBA_BiomassForPhytochemistry.csv")
# Export biomass data for phytochemical use (PIMA only)
write.csv(BiomassSum_PIMA_No0, "Data/Phytochemical/PIMA_BiomassForPhytochemistry.csv")

# Make Qty of C, N, P per plot data files. Qty here is in g per m^2
Qty_ABBA <- merge(BiomassSum_ABBA_No0, Stoi.ABBA, by.x="PlotName",  by.y= "PlotName", all.y=T)
Qty_ACRU <- merge(BiomassSum_ACRU_No0, Stoi.ACRU, by.x= "PlotName", by.y="PlotName", all.y=T)
Qty_BEPA <- merge(BiomassSum_BEPA_No0, Stoi.BEPA, by.x= "PlotName", by.y="PlotName", all.y=T)
Qty_PIMA <- merge(BiomassSum_PIMA_No0, Stoi.PIMA, by.x="PlotName",  by.y= "PlotName", all.y=T)
Qty_VAAN <- merge(BiomassSum_VAAN_No0, Stoi.VAAN, by.x= "PlotName", by.y="PlotName", all.y=T)
str(Qty_ABBA)
str(Qty_ACRU)
str(Qty_BEPA)
str(Qty_PIMA)
str(Qty_VAAN)
# Calcualte the "Qty of C" at the plot level
# Divide BiomassSum (g m2 (biomass g * plot ceiling m2)) by 401.15m^2 (11.3 m radius plot) to get g per plot 
# Divide element concentation by 100 to get proportion
# ABBA
Qty_ABBA$Qty_C <- (Qty_ABBA$BiomassSum/401.15)*(Stoi.ABBA$C/100)
Qty_ABBA$Qty_N <- (Qty_ABBA$BiomassSum/401.15)*(Stoi.ABBA$N/100)
Qty_ABBA$Qty_P <- (Qty_ABBA$BiomassSum/401.15)*(Stoi.ABBA$P/100)
# ACRU
Qty_ACRU$Qty_C <- (Qty_ACRU$BiomassSum/401.15)*(Stoi.ACRU$C/100)
Qty_ACRU$Qty_N <- (Qty_ACRU$BiomassSum/401.15)*(Stoi.ACRU$N/100)
Qty_ACRU$Qty_P <- (Qty_ACRU$BiomassSum/401.15)*(Stoi.ACRU$P/100)
# BEPA
Qty_BEPA$Qty_C <- (Qty_BEPA$BiomassSum/401.15)*(Stoi.BEPA$C/100)
Qty_BEPA$Qty_N <- (Qty_BEPA$BiomassSum/401.15)*(Stoi.BEPA$N/100)
Qty_BEPA$Qty_P <- (Qty_BEPA$BiomassSum/401.15)*(Stoi.BEPA$P/100)
# PIMA
Qty_PIMA$Qty_C <- (Qty_PIMA$BiomassSum/401.15)*(Stoi.PIMA$C/100)
Qty_PIMA$Qty_N <- (Qty_PIMA$BiomassSum/401.15)*(Stoi.PIMA$N/100)
Qty_PIMA$Qty_P <- (Qty_PIMA$BiomassSum/401.15)*(Stoi.PIMA$P/100)
# VAAN
Qty_VAAN$Qty_C <- (Qty_VAAN$BiomassSum/401.15)*(Stoi.VAAN$C/100)
Qty_VAAN$Qty_N <- (Qty_VAAN$BiomassSum/401.15)*(Stoi.VAAN$N/100)
Qty_VAAN$Qty_P <- (Qty_VAAN$BiomassSum/401.15)*(Stoi.VAAN$P/100)

# Estimate molar mass to create C:N, C:P, and N:P molar ratios
# To get molar mass divide mass by molar mass of N (14.0067), P (30.973762), C (12.0107) respectively.
# ABBA
Qty_ABBA$Molar_C <- Qty_ABBA$Qty_C/12.0107
Qty_ABBA$Molar_N <- Qty_ABBA$Qty_N/14.0067
Qty_ABBA$Molar_P <- Qty_ABBA$Qty_P/30.973762
# ACRU
Qty_ACRU$Molar_C <- Qty_ACRU$Qty_C/12.0107
Qty_ACRU$Molar_N <- Qty_ACRU$Qty_N/14.0067
Qty_ACRU$Molar_P <- Qty_ACRU$Qty_P/30.973762
# BEPA
Qty_BEPA$Molar_C <- Qty_BEPA$Qty_C/12.0107
Qty_BEPA$Molar_N <- Qty_BEPA$Qty_N/14.0067
Qty_BEPA$Molar_P <- Qty_BEPA$Qty_P/30.973762
# PIMA
Qty_PIMA$Molar_C <- Qty_PIMA$Qty_C/12.0107
Qty_PIMA$Molar_N <- Qty_PIMA$Qty_N/14.0067
Qty_PIMA$Molar_P <- Qty_PIMA$Qty_P/30.973762
# VAAN
Qty_VAAN$Molar_C <- Qty_VAAN$Qty_C/12.0107
Qty_VAAN$Molar_N <- Qty_VAAN$Qty_N/14.0067
Qty_VAAN$Molar_P <- Qty_VAAN$Qty_P/30.973762

# Add molar C:N, C:P, and N:P ratios to the Qty data frame
# ABBA
Qty_ABBA$CNRatio <- Qty_ABBA$Molar_C / Qty_ABBA$Molar_N
Qty_ABBA$CPRatio <- Qty_ABBA$Molar_C / Qty_ABBA$Molar_P
Qty_ABBA$NPRatio <- Qty_ABBA$Molar_N / Qty_ABBA$Molar_P
# ACRU
Qty_ACRU$CNRatio <- Qty_ACRU$Molar_C / Qty_ACRU$Molar_N
Qty_ACRU$CPRatio <- Qty_ACRU$Molar_C / Qty_ACRU$Molar_P
Qty_ACRU$NPRatio <- Qty_ACRU$Molar_N / Qty_ACRU$Molar_P
# BEPA
Qty_BEPA$CNRatio <- Qty_BEPA$Molar_C / Qty_BEPA$Molar_N
Qty_BEPA$CPRatio <- Qty_BEPA$Molar_C / Qty_BEPA$Molar_P
Qty_BEPA$NPRatio <- Qty_BEPA$Molar_N / Qty_BEPA$Molar_P
# PIMA
Qty_PIMA$CNRatio <- Qty_PIMA$Molar_C / Qty_PIMA$Molar_N
Qty_PIMA$CPRatio <- Qty_PIMA$Molar_C / Qty_PIMA$Molar_P
Qty_PIMA$NPRatio <- Qty_PIMA$Molar_N / Qty_PIMA$Molar_P
# VAAN
Qty_VAAN$CNRatio <- Qty_VAAN$Molar_C / Qty_VAAN$Molar_N
Qty_VAAN$CPRatio <- Qty_VAAN$Molar_C / Qty_VAAN$Molar_P
Qty_VAAN$NPRatio <- Qty_VAAN$Molar_N / Qty_VAAN$Molar_P

#write.csv(Qty_ABBA, "Data/Tabular/Ratio/ABBA_Stoich.csv")
#write.csv(Qty_ACRU, "Data/Tabular/Ratio/ACRU_Stoich.csv")
#write.csv(Qty_BEPA, "Data/Tabular/Ratio/BEPA_Stoich.csv")
#write.csv(Qty_PIMA, "Data/PIMA_Stoich.csv")
#write.csv(Qty_VAAN, "Data/Tabular/Ratio/VAAN_Stoich.csv")

#str(Qty_ABBA)
#str(Qty_ACRU)
#str(Qty_BEPA)
#str(Qty_VAAN)
AllSpp_BiomassRatio <- rbind(Qty_ABBA, Qty_ACRU, Qty_BEPA, Qty_VAAN, Qty_PIMA)
#str(AllSpp_Stoich)
write.csv(AllSpp_BiomassRatio, "Data/Outputs/BiomassRatio/BiomassRatioEstimates.csv")

