# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#
#
#
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Set working directory
setwd("~/Dropbox (HeckfordT)/PhD_Thesis/Chapter_PlantTraitLandscapes/")

# Clear all previous data
rm(list=ls())

# Install/load the following packages
install.packages("easypackages")
library(easypackages)
libraries("MuMIn", "AICcmodavg", "stargazer", "raster", "memisc")


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Load and join datasets for analysis #####
# Load phytochemistry data for balsam fir
ABBA.Phyto <- read.csv("Data/Phytochemical/ABBA_Phytochemistry.csv")
str(ABBA.Phyto)
# Load landscape covariates
LC.Covariates <- read.csv("Data/Outputs/Covariates/SampPts_CoVariates_Cleaned.csv")
str(LC.Covariates)

# Join ABBA phytochemistry to the landscape covariates
Phyto.LandscapeCoVar <- merge(ABBA.Phyto, LC.Covariates, by.x="PlotName", by.y="PlotName", all.x=T)
str(Phyto.LandscapeCoVar)
#View(Phyto.LandscapeCoVar)
# Load biomass quantity C/N/P and stoichiometric ratios
BM.Stoich <- read.csv("Data/Phytochemical/ABBA_BiomassForPhytochemistry.csv")
str(BM.Stoich)

# Join the phytochemistry + landscape co-variates dataset with the plot level biomass, quantity, and stoichiometric ratios
bF.Phyto <- merge(Phyto.LandscapeCoVar, BM.Stoich, by.x="PlotName", by.y="PlotName", all.x=T)
str(bF.Phyto)
View(bF.Phyto)
###### Run Phytochemical Models putting the variables on a biomass basis ######
# (mg/g * gm^2) / 401.15m^2 = mg/m^2
# Returns a mg unit value for phytochemical amount
# Do this for all phytochemicals and groups (total terpene, total monoterpene... etc.)
bF.Phyto$Total.Terpene.BM <- (bF.Phyto$Total.Terpene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Bornyl.acetate..Monoterpenic.ester.BM <- (bF.Phyto$Bornyl.acetate..Monoterpenic.ester. * bF.Phyto$BiomassSum)/401.15
bF.Phyto$beta.Pinene..main....Sabinene.BM <- (bF.Phyto$beta.Pinene..main....Sabinene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Maltol.BM <- (bF.Phyto$Maltol * bF.Phyto$BiomassSum)/401.15
bF.Phyto$alpha.Pinene.BM <- (bF.Phyto$alpha.Pinene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Camphene.BM <- (bF.Phyto$Camphene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Limonene..main....beta.Phellandrene.BM <- (bF.Phyto$Limonene..main....beta.Phellandrene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$delta.Carene.BM <- (bF.Phyto$delta.Carene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$beta.Caryophyllene.BM <- (bF.Phyto$beta.Caryophyllene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$beta.Bisabolene.BM <- (bF.Phyto$beta.Bisabolene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Borneol.BM <- (bF.Phyto$Borneol * bF.Phyto$BiomassSum)/401.15
bF.Phyto$alpha.Humulene.BM <- (bF.Phyto$alpha.Humulene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Tricyclene.BM <- (bF.Phyto$Tricyclene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Myrcene.BM <- (bF.Phyto$Myrcene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Terpinolene.BM <- (bF.Phyto$Terpinolene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Longifolene.BM <- (bF.Phyto$Longifolene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Unknown.sesquiterpene.BM <- (bF.Phyto$Unknown.sesquiterpene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Camphene.hydrate.BM <- (bF.Phyto$Camphene.hydrate * bF.Phyto$BiomassSum)/401.15
bF.Phyto$E.alpha.Bisabolene.BM <- (bF.Phyto$E.alpha.Bisabolene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$E.beta.Farnesene.BM <- (bF.Phyto$E.beta.Farnesene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Z.alpha.Bisabolene.BM <- (bF.Phyto$Z.alpha.Bisabolene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Linalool.BM <- (bF.Phyto$Linalool * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Caryophyllene.oxide..Sesquiterpenic.ether.BM <- (bF.Phyto$Caryophyllene.oxide..Sesquiterpenic.ether. * bF.Phyto$BiomassSum)/401.15
bF.Phyto$alpha.Muurolene.BM <- (bF.Phyto$alpha.Muurolene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$alpha.Terpineol.BM <- (bF.Phyto$alpha.Terpineol * bF.Phyto$BiomassSum)/401.15
bF.Phyto$gamma.Terpinene.BM <- (bF.Phyto$gamma.Terpinene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Piperitone..Monoterpenic.ketone.BM <- (bF.Phyto$Piperitone..Monoterpenic.ketone. * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Thymol.BM <- (bF.Phyto$Thymol * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Total.Monoterpene.BM <- (bF.Phyto$Total.Monoterpene * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Total.Monoterpenic.Alcohol.BM <- (bF.Phyto$Total.Monoterpenic.Alcohol * bF.Phyto$BiomassSum)/401.15
bF.Phyto$Total.Sesquiterpene.BM <- (bF.Phyto$Total.Sesquiterpene * bF.Phyto$BiomassSum)/401.15

# Export this entire set of data for correlation plots between response variables where we have ecvidence for spatial drivers
write.csv(bF.Phyto, "Data/Phytochemical/ABBA_ElementalPhyto_RawBiomass_ForCorr.csv")


# Subset dataset for just the biomass fields
str(bF.Phyto)
bF.Phyto.BM <- bF.Phyto
str(bF.Phyto.BM)
bF.Phyto.BM <- select(bF.Phyto.BM, -c(2:43))

# Rename field, i.e., remove the BM
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Total.Terpene.BM"] <- "Total.Terpene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Bornyl.acetate..Monoterpenic.ester.BM"] <- "Bornyl.acetate..Monoterpenic.ester."
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "beta.Pinene..main....Sabinene.BM"] <- "beta.Pinene..main....Sabinene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Maltol.BM"] <- "Maltol"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "alpha.Pinene.BM"] <- "alpha.Pinene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Camphene.BM"] <- "Camphene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Limonene..main....beta.Phellandrene.BM"] <- "Limonene..main....beta.Phellandrene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "delta.Carene.BM"] <- "delta.Carene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "beta.Caryophyllene.BM"] <- "beta.Caryophyllene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "beta.Bisabolene.BM"] <- "beta.Bisabolene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Borneol.BM"] <- "Borneol"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "alpha.Humulene.BM"] <- "alpha.Humulene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Tricyclene.BM"] <- "Tricyclene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Myrcene.BM"] <- "Myrcene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Terpinolene.BM"] <- "Terpinolene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Longifolene.BM"] <- "Longifolene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Unknown.sesquiterpene.BM"] <- "Unknown.sesquiterpene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Camphene.hydrate.BM"] <- "Camphene.hydrate"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "E.alpha.Bisabolene.BM"] <- "E.alpha.Bisabolene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "E.beta.Farnesene.BM"] <- "E.beta.Farnesene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Z.alpha.Bisabolene.BM"] <- "Z.alpha.Bisabolene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Linalool.BM"] <- "Linalool"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Caryophyllene.oxide..Sesquiterpenic.ether.BM"] <- "Caryophyllene.oxide..Sesquiterpenic.ether."
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "alpha.Muurolene.BM"] <- "alpha.Muurolene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "alpha.Terpineol.BM"] <- "alpha.Terpineol"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "gamma.Terpinene.BM"] <- "gamma.Terpinene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Piperitone..Monoterpenic.ketone.BM"] <- "Piperitone..Monoterpenic.ketone."
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Thymol.BM"] <- "Thymol"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Total.Monoterpene.BM"] <- "Total.Monoterpene"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Total.Monoterpenic.Alcohol.BM"] <- "Total.Monoterpenic.Alcohol"
names(bF.Phyto.BM)[names(bF.Phyto.BM) == "Total.Sesquiterpene.BM"] <- "Total.Sesquiterpene"

str(bF.Phyto.BM)

write.csv(bF.Phyto.BM, "Data/Phytochemical/ABBA_BiomassBasis_Phytochemistry.csv")
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 




#### Load and join datasets for analysis #####
# Load phytochemistry data for black spruce
PIMA.Phyto <- read.csv("Data/Phytochemical/PIMA_Phytochemistry.csv")
str(PIMA.Phyto)
# Load landscape covariates
LC.Covariates <- read.csv("Data/Outputs/CoVariates/SampPts_CoVariates_Cleaned.csv")
str(LC.Covariates)
View(LC.Covariates)
# Join PIMA phytochemistry to the landscape covariates
Phyto.LandscapeCoVar <- merge(PIMA.Phyto, LC.Covariates, by.x="PlotName", by.y="PlotName", all.x=T)
str(Phyto.LandscapeCoVar)

# Load biomass quantity C/N/P and stoichiometric ratios
BM.Stoich <- read.csv("Data/Phytochemical/PIMA_BiomassForPhytochemistry.csv")
str(BM.Stoich)

# Join the phytochemistry + landscape co-variates dataset with the plot level biomass, quantity, and stoichiometric ratios
bS.Phyto <- merge(Phyto.LandscapeCoVar, BM.Stoich, by.x="PlotName", by.y="PlotName", all.x=T)
str(bS.Phyto)
# Export dataset
#write.csv(bS.Phyto, "Data/Phytochemical/PIMA_Phyto_w_CoVar.csv")

# Create a biomass basis dataset augmented to the raw phytochemical database for data-space comparison of these variables
bS.Phyto$Tricyclene.BM <- (bS.Phyto$Tricyclene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$alpha.Pinene.BM <- (bS.Phyto$alpha.Pinene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Camphene.BM <- (bS.Phyto$Camphene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$beta.Pinene.main.Sabinene.BM <- (bS.Phyto$beta.Pinene.main.Sabinene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Myrcene.BM <- (bS.Phyto$Myrcene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$alpha.Phellandrene.BM <- (bS.Phyto$alpha.Phellandrene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$delta.Carene.BM <- (bS.Phyto$delta.Carene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Limonene.main.1.8.cineole.BM <- (bS.Phyto$Limonene.main.1.8.cineole * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Terpinolene.BM <- (bS.Phyto$Terpinolene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Linalool.BM <- (bS.Phyto$Linalool * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Camphene.hydrate.BM <- (bS.Phyto$Camphene.hydrate * bS.Phyto$BiomassSum)/401.15
bS.Phyto$alpha.Terpineol.BM <- (bS.Phyto$alpha.Terpineol * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Citronellol.BM <- (bS.Phyto$Citronellol * bS.Phyto$BiomassSum)/401.15
bS.Phyto$alpha.Campholenal.BM <- (bS.Phyto$alpha.Campholenal * bS.Phyto$BiomassSum)/401.15
bS.Phyto$endo.Fenchyl.acetate.BM <- (bS.Phyto$endo.Fenchyl.acetate * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Bornyl.acetate.main.Isobornyl.acetate.BM <- (bS.Phyto$Bornyl.acetate.main.Isobornyl.acetate * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Unknown.PIMA.6.BM <- (bS.Phyto$Unknown.PIMA.6 * bS.Phyto$BiomassSum)/401.15
bS.Phyto$trans.Pinocarvyl.acetate.BM <- (bS.Phyto$trans.Pinocarvyl.acetate * bS.Phyto$BiomassSum)/401.15
bS.Phyto$cis.Piperityl.acettae.BM <- (bS.Phyto$cis.Piperityl.acettae * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Geranyl.acetate.BM <- (bS.Phyto$Geranyl.acetate * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Oxygenated.sesquiterpene.Unk18.BM <- (bS.Phyto$Oxygenated.sesquiterpene.Unk18 * bS.Phyto$BiomassSum)/401.15
bS.Phyto$beta.Elemene.BM <- (bS.Phyto$beta.Elemene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$beta.Caryophyllene.BM <- (bS.Phyto$beta.Caryophyllene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$alpha.Humulene.BM <- (bS.Phyto$alpha.Humulene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Germacrene.D.BM <- (bS.Phyto$Germacrene.D * bS.Phyto$BiomassSum)/401.15
bS.Phyto$alpha.Muurolene.BM <- (bS.Phyto$alpha.Muurolene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$gamma.Cadinene.main.Cubebol.BM <- (bS.Phyto$gamma.Cadinene.main.Cubebol * bS.Phyto$BiomassSum)/401.15
bS.Phyto$sigma.Cadinene.BM <- (bS.Phyto$sigma.Cadinene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Unknown.sesquiterpene.BM <- (bS.Phyto$Unknown.sesquiterpene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$E.alpha.Bisabolene.BM <- (bS.Phyto$E.alpha.Bisabolene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Germacrene.D.4.ol.BM <- (bS.Phyto$Germacrene.D.4.ol * bS.Phyto$BiomassSum)/401.15
bS.Phyto$tau.Cadinol.tau.Muurolol.BM <- (bS.Phyto$tau.Cadinol.tau.Muurolol * bS.Phyto$BiomassSum)/401.15
bS.Phyto$alpha.Cadinol.BM <- (bS.Phyto$alpha.Cadinol * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Oplopanone.BM <- (bS.Phyto$Oplopanone * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Unknown.PIMA.9.BM <- (bS.Phyto$Unknown.PIMA.9 * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Total.terpene.BM <- (bS.Phyto$Total.terpene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Total.monoterpene.BM <- (bS.Phyto$Total.monoterpene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Total.monoterpenic.alcohol.BM <- (bS.Phyto$Total.monoterpenic.alcohol * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Total.monoterpenic.ester.BM <- (bS.Phyto$Total.monoterpenic.ester * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Total.sesquiterpene.BM <- (bS.Phyto$Total.sesquiterpene * bS.Phyto$BiomassSum)/401.15
bS.Phyto$Total.sesquiterpenic.alcohol.BM <- (bS.Phyto$Total.sesquiterpenic.alcohol * bS.Phyto$BiomassSum)/401.15
str(bS.Phyto)
# Export this entire set of data for correlation plots between response variables where we have ecvidence for spatial drivers
write.csv(bS.Phyto, "Data/Phytochemical/PIMA_ElementalPhyto_RawBiomass_ForCorr.csv")


# Create a biomass basis dataset to use the sample modeling script below used in the raw phytochemical modelling
# Swap bS.Phyto with bS.BM.Phyto
str(bS.BM.Phyto)
bS.BM.Phyto <- bS.Phyto[1]
bS.BM.Phyto$Tricyclene <- (bS.Phyto$Tricyclene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$alpha.Pinene <- (bS.Phyto$alpha.Pinene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Camphene <- (bS.Phyto$Camphene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$beta.Pinene.main.Sabinene <- (bS.Phyto$beta.Pinene.main.Sabinene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Myrcene <- (bS.Phyto$Myrcene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$alpha.Phellandrene <- (bS.Phyto$alpha.Phellandrene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$delta.Carene <- (bS.Phyto$delta.Carene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Limonene.main.1.8.cineole <- (bS.Phyto$Limonene.main.1.8.cineole * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Terpinolene <- (bS.Phyto$Terpinolene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Linalool <- (bS.Phyto$Linalool * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Camphene.hydrate <- (bS.Phyto$Camphene.hydrate * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$alpha.Terpineol <- (bS.Phyto$alpha.Terpineol * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Citronellol <- (bS.Phyto$Citronellol * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$alpha.Campholenal <- (bS.Phyto$alpha.Campholenal * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$endo.Fenchyl.acetate <- (bS.Phyto$endo.Fenchyl.acetate * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Bornyl.acetate.main.Isobornyl.acetate <- (bS.Phyto$Bornyl.acetate.main.Isobornyl.acetate * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Unknown.PIMA.6 <- (bS.Phyto$Unknown.PIMA.6 * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$trans.Pinocarvyl.acetate <- (bS.Phyto$trans.Pinocarvyl.acetate * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$cis.Piperityl.acettae <- (bS.Phyto$cis.Piperityl.acettae * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Geranyl.acetate <- (bS.Phyto$Geranyl.acetate * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Oxygenated.sesquiterpene.Unk18 <- (bS.Phyto$Oxygenated.sesquiterpene.Unk18 * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$beta.Elemene <- (bS.Phyto$beta.Elemene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$beta.Caryophyllene <- (bS.Phyto$beta.Caryophyllene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$alpha.Humulene <- (bS.Phyto$alpha.Humulene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Germacrene.D <- (bS.Phyto$Germacrene.D * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$alpha.Muurolene <- (bS.Phyto$alpha.Muurolene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$gamma.Cadinene.main.Cubebol <- (bS.Phyto$gamma.Cadinene.main.Cubebol * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$sigma.Cadinene <- (bS.Phyto$sigma.Cadinene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Unknown.sesquiterpene <- (bS.Phyto$Unknown.sesquiterpene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$E.alpha.Bisabolene <- (bS.Phyto$E.alpha.Bisabolene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Germacrene.D.4.ol <- (bS.Phyto$Germacrene.D.4.ol * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$tau.Cadinol.tau.Muurolol <- (bS.Phyto$tau.Cadinol.tau.Muurolol * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$alpha.Cadinol <- (bS.Phyto$alpha.Cadinol * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Oplopanone <- (bS.Phyto$Oplopanone * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Unknown.PIMA.9 <- (bS.Phyto$Unknown.PIMA.9 * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Total.terpene <- (bS.Phyto$Total.terpene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Total.monoterpene <- (bS.Phyto$Total.monoterpene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Total.monoterpenic.alcohol <- (bS.Phyto$Total.monoterpenic.alcohol * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Total.monoterpenic.ester <- (bS.Phyto$Total.monoterpenic.ester * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Total.sesquiterpene <- (bS.Phyto$Total.sesquiterpene * bS.Phyto$BiomassSum)/401.15
bS.BM.Phyto$Total.sesquiterpenic.alcohol <- (bS.Phyto$Total.sesquiterpenic.alcohol * bS.Phyto$BiomassSum)/401.15

str(bS.BM.Phyto)

bS.BM.Phyto.CoVar <- merge(bS.BM.Phyto, LC.Covariates, by.x="PlotName", by.y="PlotName", all.x=T)
str(bS.BM.Phyto.CoVar)

# Export this entire set of data for correlation plots between response variables where we have ecvidence for spatial drivers
write.csv(bS.BM.Phyto.CoVar, "Data/Phytochemical/PIMA_BiomassBasis_Phytochemistry.csv")


