# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Set working directory
setwd("~/Dropbox (HeckfordT)/PhD_Thesis/Chapter_PlantTraitLandscapes/")

library(easypackages)
libraries("ggplot2", "psych", "reshape2", "tidyr", "dplyr", "tidyverse", "RColorBrewer", "corrplot", "data.table", "wesanderson", "raster", "sdmpredictors", "rasterVis", "vegan")
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 

# Set color scheme for all correlation plots
#col <- wes_palette("FantasticFox1", n=10, type = "continuous")
col <- gray.colors(10)



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Data space #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Load and manipulate data space variables of foliar data, ABBA and PIMA phytochemical raw and biomass ####
# Load ES data
FoliageStoich <- read.csv("Data/Outputs/FoliarData/FoliarData.csv")
# Subset for individuals species
Stoi.ABBA <- subset(FoliageStoich, Species == "ABBA")
Stoi.ACRU <- subset(FoliageStoich, Species == "ACRU")
Stoi.BEPA <- subset(FoliageStoich, Species == "BEPA")
Stoi.PIMA <- subset(FoliageStoich, Species == "PIMA")
Stoi.VAAN <- subset(FoliageStoich, Species == "VAAN")


# Subset each dataframe for just the plot field and for only variables in which we have a spatial model

bF.elemental <- subset(Stoi.ABBA, select = c("PlotName", "C", "N", "P", "Qty_C", "Qty_N", "Qty_P", "CNRatio", "CPRatio"))
colnames(bF.elemental)[colnames(bF.elemental)=="C"] <- "ABBA C"
colnames(bF.elemental)[colnames(bF.elemental)=="N"] <- "ABBA N"
colnames(bF.elemental)[colnames(bF.elemental)=="P"] <- "ABBA P"
colnames(bF.elemental)[colnames(bF.elemental)=="Qty_C"] <- "ABBA QtyC"
colnames(bF.elemental)[colnames(bF.elemental)=="Qty_N"] <- "ABBA QtyN"
colnames(bF.elemental)[colnames(bF.elemental)=="Qty_P"] <- "ABBA QtyP"
colnames(bF.elemental)[colnames(bF.elemental)=="CNRatio"] <- "ABBA CN"
colnames(bF.elemental)[colnames(bF.elemental)=="CPRatio"] <- "ABBA CP"
str(bF.elemental)

str(Stoi.ACRU)
rM.elemental <- subset(Stoi.ACRU, select = c("PlotName", "C", "N", "P", "CNRatio", "NPRatio"))
colnames(rM.elemental)[colnames(rM.elemental)=="C"] <- "ACRU C"
colnames(rM.elemental)[colnames(rM.elemental)=="N"] <- "ACRU N"
colnames(rM.elemental)[colnames(rM.elemental)=="P"] <- "ACRU P"
colnames(rM.elemental)[colnames(rM.elemental)=="CNRatio"] <- "ACRU CN"
colnames(rM.elemental)[colnames(rM.elemental)=="NPRatio"] <- "ACRU NP"
str(rM.elemental)

str(Stoi.BEPA)
wB.elemental <- subset(Stoi.BEPA, select = c("PlotName", "C"))
colnames(wB.elemental)[colnames(wB.elemental)=="C"] <- "BEPA C"
str(wB.elemental)

str(Stoi.PIMA)
bS.elemental <- subset(Stoi.PIMA, select = c("PlotName", "C", "N", "P", "CNRatio", "CPRatio", "NPRatio"))
colnames(bS.elemental)[colnames(bS.elemental)=="C"] <- "PIMA C"
colnames(bS.elemental)[colnames(bS.elemental)=="N"] <- "PIMA N"
colnames(bS.elemental)[colnames(bS.elemental)=="P"] <- "PIMA P"
colnames(bS.elemental)[colnames(bS.elemental)=="CNRatio"] <- "PIMA CN"
colnames(bS.elemental)[colnames(bS.elemental)=="CPRatio"] <- "PIMA CP"
colnames(bS.elemental)[colnames(bS.elemental)=="NPRatio"] <- "PIMA NP"

str(bS.elemental)

str(Stoi.VAAN)
bB.elemental <- subset(Stoi.VAAN, select = c("PlotName", "C", "N", "P", "Qty_C", "Qty_N", "Qty_P", "CNRatio", "CPRatio", "NPRatio"))
colnames(bB.elemental)[colnames(bB.elemental)=="C"] <- "VAAN C"
colnames(bB.elemental)[colnames(bB.elemental)=="N"] <- "VAAN N"
colnames(bB.elemental)[colnames(bB.elemental)=="P"] <- "VAAN P"
colnames(bB.elemental)[colnames(bB.elemental)=="Qty_C"] <- "VAAN QtyC"
colnames(bB.elemental)[colnames(bB.elemental)=="Qty_N"] <- "VAAN QtyN"
colnames(bB.elemental)[colnames(bB.elemental)=="Qty_P"] <- "VAAN QtyP"
colnames(bB.elemental)[colnames(bB.elemental)=="CNRatio"] <- "VAAN CN"
colnames(bB.elemental)[colnames(bB.elemental)=="CPRatio"] <- "VAAN CP"
colnames(bB.elemental)[colnames(bB.elemental)=="NPRatio"] <- "VAAN NP"
str(bB.elemental)

# Rinse and repeat with phytochemical data
# ABBA Raw
ABBA.PhytoRaw <- read.csv("Data/Outputs/Phytochemical/ABBA_Phytochemistry.csv")
str(ABBA.PhytoRaw)
bF_phyto_Raw <- subset(ABBA.PhytoRaw, select = c(PlotName, Total.Terpene, Total.Monoterpene, Total.Sesquiterpene))
colnames(bF_phyto_Raw)[colnames(bF_phyto_Raw)=="Total.Terpene"] <- "ABBA Terpene (raw)"
colnames(bF_phyto_Raw)[colnames(bF_phyto_Raw)=="Total.Monoterpene"] <- "ABBA Monoterpene (raw)"
colnames(bF_phyto_Raw)[colnames(bF_phyto_Raw)=="Total.Sesquiterpene"] <- "ABBA Sesquiterpene (raw)"


# ABBA Biomass
ABBA.PhytoBM <- read.csv("Data/Outputs/Phytochemical/ABBA_BiomassBasis_Phytochemistry.csv")
# Subset data
bF_Phyto_BM <- subset(ABBA.PhytoBM, select = c(PlotName, Total.Terpene, Total.Monoterpene, Bornyl.acetate..Monoterpenic.ester.))
colnames(bF_Phyto_BM)[colnames(bF_Phyto_BM)=="Total.Terpene"] <- "ABBA Terpene (bm)"
colnames(bF_Phyto_BM)[colnames(bF_Phyto_BM)=="Total.Monoterpene"] <- "ABBA Monoterpene (bm)"
colnames(bF_Phyto_BM)[colnames(bF_Phyto_BM)=="Bornyl.acetate..Monoterpenic.ester."] <- "ABBA Monoterpenic ester (bm)"


# PIMA Raw
PIMA.PhytoRaw <- read.csv("Data/Outputs/Phytochemical/PIMA_Phytochemistry.csv")
# Calculate diversity
PIMA.PhytoRaw$Diversity <- diversity(PIMA.PhytoRaw[2:36], index="shannon")
# Subset data
bS_Phyto_Raw <- subset(PIMA.PhytoRaw, select = c(PlotName, Total.terpene, Total.monoterpene, Total.monoterpenic.alcohol, Total.monoterpenic.ester, Total.sesquiterpene, Diversity))
colnames(bS_Phyto_Raw)[colnames(bS_Phyto_Raw)=="Total.terpene"] <- "PIMA Terpene (raw)"
colnames(bS_Phyto_Raw)[colnames(bS_Phyto_Raw)=="Total.monoterpene"] <- "PIMA Monoterpene (raw)"
colnames(bS_Phyto_Raw)[colnames(bS_Phyto_Raw)=="Total.monoterpenic.alcohol"] <- "PIMA Monoterpenic alcohol (raw)"
colnames(bS_Phyto_Raw)[colnames(bS_Phyto_Raw)=="Total.monoterpenic.ester"] <- "PIMA Monoterpenic ester (raw)"
colnames(bS_Phyto_Raw)[colnames(bS_Phyto_Raw)=="Total.sesquiterpene"] <- "PIMA Sesquiterpene (raw)"
colnames(bS_Phyto_Raw)[colnames(bS_Phyto_Raw)=="Diversity"] <- "PIMA Phytochemical diversity (raw)"

# Cascading merge - keep all data
bf.rM <- merge(bF.elemental, rM.elemental, by.x ="PlotName", by.y="PlotName", all.x=T, all.y=T)
bf.rm.wB <- merge(bf.rM, wB.elemental, by.x ="PlotName", by.y="PlotName", all.x=T, all.y=T)
bf.rm.wB.bS <- merge(bf.rm.wB, bS.elemental, by.x ="PlotName", by.y="PlotName", all.x=T, all.y=T)
bf.rm.wB.bS.bB <- merge(bf.rm.wB.bS, bB.elemental, by.x ="PlotName", by.y="PlotName", all.x=T, all.y=T)
ES_bF_phytoRaw <- merge(bf.rm.wB.bS.bB, bF_phyto_Raw, by.x ="PlotName", by.y="PlotName", all.x=T, all.y=T)
ES_bF_PhyoRaw_PhytoBM <- merge(ES_bF_phytoRaw, bF_Phyto_BM, by.x ="PlotName", by.y="PlotName", all.x=T, all.y=T)
ESP_dataJoin <- merge(ES_bF_PhyoRaw_PhytoBM, bS_Phyto_Raw, by.x ="PlotName", by.y="PlotName", all.x=T, all.y=T)
str(bf.rm.wB.bS.bB)
# Now remove NA - to only get rows where the species co-occurr
ESP_dataJoin_final <- na.omit(ESP_dataJoin)
str(ESP_dataJoin_final)

# drop first column for correlation matrix
ESP_dataJoin_finalCor <- ESP_dataJoin_final[,-1]
str(ESP_dataJoin_finalCor)
# Subset to set order of corr plot by trait then species (Can remove and the plot will be order by species than trait)
ESP_sub <- subset(ESP_dataJoin_finalCor, select = c("ABBA C", "ACRU C", "BEPA C", "PIMA C", "VAAN C", "ABBA N", "ACRU N", "PIMA N", "VAAN N", "ABBA P", "ACRU P", "PIMA P", "VAAN P", "ABBA QtyC", "VAAN QtyC", "ABBA QtyN", "VAAN QtyN", "ABBA QtyP", "VAAN QtyP", "ABBA CN", "ACRU CN", "PIMA CN", "VAAN CN", "ABBA CP", "PIMA CP", "VAAN CP", "ACRU NP", "PIMA NP", "VAAN NP", "ABBA Terpene (raw)", "PIMA Terpene (raw)", "ABBA Terpene (bm)", "ABBA Monoterpene (raw)", "PIMA Monoterpene (raw)", "ABBA Monoterpene (bm)", "PIMA Monoterpenic alcohol (raw)", "PIMA Monoterpenic ester (raw)", "ABBA Monoterpenic ester (bm)", "ABBA Sesquiterpene (raw)", "PIMA Sesquiterpene (raw)", "PIMA Phytochemical diversity (raw)"))
str(ESP_sub)
# Create correlation plot
ESP_corMatrix <- round(cor(ESP_sub),2)

# Export graph
png("Figures/CorrPlots/DataSpace_CorrPlot.png", width = 9, height = 8, units = "in", res = 600)
corrplot(ESP_corMatrix, diag=F, method = "color", col = col, type="lower", tl.cex = 0.9, tl.col="black", tl.srt = 45)
dev.off()


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
##### Spatial data  #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Load rasters
ESP_Raster_list <- list.files("Data/Outputs/RasterOutput/All/",full.names = T, pattern = '.tif$')
# Stack rasters
ESP_RS <- stack(ESP_Raster_list)

# Get layer stack order
names(ESP_RasterStack)

# Re order names so that it follows the layout from the dat space comparison
ESP <- stack(ESP_RS[[4]], ESP_RS[[15]], ESP_RS[[20]], ESP_RS[[21]], ESP_RS[[33]], # Carbon
             ESP_RS[[7]], ESP_RS[[17]], ESP_RS[[25]], ESP_RS[[36]], # Nitrogen
             ESP_RS[[8]], ESP_RS[[19]], ESP_RS[[27]], ESP_RS[[38]], # Phosphorpus
             ESP_RS[[9]], ESP_RS[[39]], ESP_RS[[10]], ESP_RS[[40]], ESP_RS[[11]], ESP_RS[[41]], # Qty C, N, P
             ESP_RS[[5]], ESP_RS[[16]], ESP_RS[[22]], ESP_RS[[34]], # CN
             ESP_RS[[6]], ESP_RS[[23]], ESP_RS[[35]], # CP
             ESP_RS[[18]], ESP_RS[[26]], ESP_RS[[37]], # NP
             ESP_RS[[14]], ESP_RS[[28]], ESP_RS[[3]], ESP_RS[[12]], ESP_RS[[29]], ESP_RS[[2]], # Terpene + Monoterpene
             ESP_RS[[30]], ESP_RS[[31]], ESP_RS[[1]], ESP_RS[[13]], ESP_RS[[32]], ESP_RS[[24]]) # all the rest
# Check names
names(ESP)

# Calculator pearson correlation matrix for the spatial layers
ESP_Spatial_CorrMatrix <- pearson_correlation_matrix(ESP)

# Change variable names to match the data space ones above + more descriptive
colnames(ESP_Spatial_CorrMatrix) <- c("ABBA C", "ACRU C", "BEPA C", "PIMA C", "VAAN C", "ABBA N", "ACRU N", "PIMA N", "VAAN N", "ABBA P", "ACRU P", "PIMA P", "VAAN P", "ABBA QtyC", "VAAN QtyC", "ABBA QtyN", "VAAN QtyN", "ABBA QtyP", "VAAN QtyP", "ABBA CN", "ACRU CN", "PIMA CN", "VAAN CN", "ABBA CP", "PIMA CP", "VAAN CP", "ACRU NP", "PIMA NP", "VAAN NP", "ABBA Terpene (raw)", "PIMA Terpene (raw)", "ABBA Terpene (bm)", "ABBA Monoterpene (raw)", "PIMA Monoterpene (raw)", "ABBA Monoterpene (bm)", "PIMA Monoterpenic alcohol (raw)", "PIMA Monoterpenic ester (raw)", "ABBA Monoterpenic ester (bm)", "ABBA Sesquiterpene (raw)", "PIMA Sesquiterpene (raw)", "PIMA Phytochemical diversity (raw)")

rownames(ESP_Spatial_CorrMatrix) <- c("ABBA C", "ACRU C", "BEPA C", "PIMA C", "VAAN C", "ABBA N", "ACRU N", "PIMA N", "VAAN N", "ABBA P", "ACRU P", "PIMA P", "VAAN P", "ABBA QtyC", "VAAN QtyC", "ABBA QtyN", "VAAN QtyN", "ABBA QtyP", "VAAN QtyP", "ABBA CN", "ACRU CN", "PIMA CN", "VAAN CN", "ABBA CP", "PIMA CP", "VAAN CP", "ACRU NP", "PIMA NP", "VAAN NP", "ABBA Terpene (raw)", "PIMA Terpene (raw)", "ABBA Terpene (bm)", "ABBA Monoterpene (raw)", "PIMA Monoterpene (raw)", "ABBA Monoterpene (bm)", "PIMA Monoterpenic alcohol (raw)", "PIMA Monoterpenic ester (raw)", "ABBA Monoterpenic ester (bm)", "ABBA Sesquiterpene (raw)", "PIMA Sesquiterpene (raw)", "PIMA Phytochemical diversity (raw)")

# Export graph
png("Figures/CorrPlots/SpatialSpace_CorrPlot.png", width = 9, height = 8, units = "in", res = 600)
corrplot(ESP_Spatial_CorrMatrix, diag=T, method = "color", col = col, type="lower", tl.cex = 0.9, tl.srt = 45, tl.col="black")
dev.off()



# Combine the two plots
png("Figures/CorrPlots/Combined_CorrPlots_v3.png", width = 20, height = 7, units = "in", res = 600)
par(mfrow=c(1,2))
corrplot(ESP_corMatrix, diag=F, method = "color", col = col, type="lower", tl.cex = 1, tl.col="black", tl.srt = 45)
corrplot(ESP_Spatial_CorrMatrix, diag=F, method = "color", col = col, type="lower", tl.cex = 1, tl.srt = 45, tl.col="black")
dev.off()



