# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Title: Plant trait landscapes
# Author: Travis Robert Heckford
#
#
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Set working directory
setwd("~/Dropbox (HeckfordT)/PhD_Thesis/Chapter_PlantTraitLandscapes/")

# Install/load the following packages
library(easypackages)
libraries("MuMIn", "tidyverse", "raster", "ggplot2", "piecewiseSEM", "vegan", "AICcmodavg", "rcompanion", "ggpubr", "JLutils")

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Load the stoichiometry data with biomass, qty, and ratios
FoliarData <- read.csv("Data/Outputs/FoliarData/FoliarData.csv")
# Load Landscape Covariates
Covariates <- read.csv("Data/Outputs/Covariates/SampPts_CoVariates_Cleaned.csv")
# Join foliar stoichiometry with landscape covariate data
FoliarCovar <- merge(FoliarData, Covariates, by.x="PlotName", by.y="PlotName")

# Set biotic/land cover fields to factors
FoliarCovar$AgeClss <- as.factor(FoliarCovar$AgeClss)
FoliarCovar$HghtCls <- as.factor(FoliarCovar$HghtCls)
FoliarCovar$CrwnDns <- as.factor(FoliarCovar$CrwnDns)
FoliarCovar$LandCover <- as.factor(FoliarCovar$LandCover)


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Subset data by species and scale EVI, Elevation, Aspect, and Slope
ABBA <- subset(FoliarCovar, Species == "ABBA")
ABBA$EVI <- c(scale(ABBA$EVI.ns))
ABBA$Elevation <- c(scale(ABBA$Elevation.ns))
ABBA$Aspect <- c(scale(ABBA$Aspect.ns))
ABBA$Slope <- c(scale(ABBA$Slope.ns))

ACRU <- subset(FoliarCovar, Species == "ACRU")
ACRU$EVI <- c(scale(ACRU$EVI.ns))
ACRU$Elevation <- c(scale(ACRU$Elevation.ns))
ACRU$Aspect <- c(scale(ACRU$Aspect.ns))
ACRU$Slope <- c(scale(ACRU$Slope.ns))

BEPA <- subset(FoliarCovar, Species == "BEPA")
BEPA$EVI <- c(scale(BEPA$EVI.ns))
BEPA$Elevation <- c(scale(BEPA$Elevation.ns))
BEPA$Aspect <- c(scale(BEPA$Aspect.ns))
BEPA$Slope <- c(scale(BEPA$Slope.ns))

PIMA <- subset(FoliarCovar, Species == "PIMA")
PIMA$EVI <- c(scale(PIMA$EVI.ns))
PIMA$Elevation <- c(scale(PIMA$Elevation.ns))
PIMA$Aspect <- c(scale(PIMA$Aspect.ns))
PIMA$Slope <- c(scale(PIMA$Slope.ns))

VAAN <- subset(FoliarCovar, Species == "VAAN")
VAAN$EVI <- c(scale(VAAN$EVI.ns))
VAAN$Elevation <- c(scale(VAAN$Elevation.ns))
VAAN$Aspect <- c(scale(VAAN$Aspect.ns))
VAAN$Slope <- c(scale(VAAN$Slope.ns))






# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Percent Elemental Models #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ABBA C Models #### 
ABBA_C1 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_C2 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_C3 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_C4 <- glm(C ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_C5 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_C6 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_C7 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_C8 <- glm(C ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_C9 <- glm(C ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_C10 <- glm(C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_C11 <- glm(C ~ LandCover + EVI, data = ABBA)
ABBA_C12 <- glm(C ~ LandCover, data = ABBA)
ABBA_C13 <- glm(C ~ EVI, data = ABBA)
ABBA_C14 <- glm(C ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_C15 <- glm(C ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_C16 <- glm(C ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_C <- list("ABBA_C_1" = ABBA_C1, "ABBA_C_2" = ABBA_C2, "ABBA_C_3" = ABBA_C3, "ABBA_C_4" = ABBA_C4, "ABBA_C_5" = ABBA_C5, "ABBA_C_6" = ABBA_C6, "ABBA_C_7" = ABBA_C7, "ABBA_C_8" =  ABBA_C8, "ABBA_C_9" = ABBA_C9, "ABBA_C_10" = ABBA_C10, "ABBA_C_11" = ABBA_C11, "ABBA_C_12" = ABBA_C12, "ABBA_C_13" = ABBA_C13, "ABBA_C_14" = ABBA_C14, "ABBA_C_15" = ABBA_C15, "ABBA_C_16" = ABBA_C16)
# Create AICc table
ABBA_C <- as.data.frame(aictab(Cand_models_ABBA_C)) # EVI pretending so just model 15
# Split string
ABBA_C_sep <- separate(ABBA_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_C)))
# Merge AICc and R2 tables together
ABBA_C_results <- merge(ABBA_C_sep, ABBA_C_R2, by.x="ModNumber", by.y = "rowname")


summary(ABBA_C15)



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ABBA N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_N1 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_N2 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_N3 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_N4 <- glm(N ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_N5 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_N6 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_N7 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_N8 <- glm(N ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_N9 <- glm(N ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_N10 <- glm(N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_N11 <- glm(N ~ LandCover + EVI, data = ABBA)
ABBA_N12 <- glm(N ~ LandCover, data = ABBA)
ABBA_N13 <- glm(N ~ EVI, data = ABBA)
ABBA_N14 <- glm(N ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_N15 <- glm(N ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_N16 <- glm(N ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_N <- list("ABBA_N_1" = ABBA_N1, "ABBA_N_2" = ABBA_N2, "ABBA_N_3" = ABBA_N3, "ABBA_N_4" = ABBA_N4, "ABBA_N_5" = ABBA_N5, "ABBA_N_6" = ABBA_N6, "ABBA_N_7" = ABBA_N7, "ABBA_N_8" =  ABBA_N8, "ABBA_N_9" = ABBA_N9, "ABBA_N_10" = ABBA_N10, "ABBA_N_11" = ABBA_N11, "ABBA_N_12" = ABBA_N12, "ABBA_N_13" = ABBA_N13, "ABBA_N_14" = ABBA_N14, "ABBA_N_15" = ABBA_N15, "ABBA_N_16" = ABBA_N16)
# Create AICc table
ABBA_N <- as.data.frame(aictab(Cand_models_ABBA_N)) # EVI pretending so just model 15
# Split string
ABBA_N_sep <- separate(ABBA_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_N)))
# Merge AICc and R2 tables together
ABBA_N_results <- merge(ABBA_N_sep, ABBA_N_R2, by.x="ModNumber", by.y = "rowname")






# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ABBA P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_P1 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_P2 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_P3 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_P4 <- glm(P ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_P5 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_P6 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_P7 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_P8 <- glm(P ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_P9 <- glm(P ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_P10 <- glm(P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_P11 <- glm(P ~ LandCover + EVI, data = ABBA)
ABBA_P12 <- glm(P ~ LandCover, data = ABBA)
ABBA_P13 <- glm(P ~ EVI, data = ABBA)
ABBA_P14 <- glm(P ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_P15 <- glm(P ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_P16 <- glm(P ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_P <- list("ABBA_P_1" = ABBA_P1, "ABBA_P_2" = ABBA_P2, "ABBA_P_3" = ABBA_P3, "ABBA_P_4" = ABBA_P4, "ABBA_P_5" = ABBA_P5, "ABBA_P_6" = ABBA_P6, "ABBA_P_7" = ABBA_P7, "ABBA_P_8" =  ABBA_P8, "ABBA_P_9" = ABBA_P9, "ABBA_P_10" = ABBA_P10, "ABBA_P_11" = ABBA_P11, "ABBA_P_12" = ABBA_P12, "ABBA_P_13" = ABBA_P13, "ABBA_P_14" = ABBA_P14, "ABBA_P_15" = ABBA_P15, "ABBA_P_16" = ABBA_P16)
ABBA_P <- as.data.frame(aictab(cand.set = Cand_models_ABBA_P))
# Split string
ABBA_P_sep <- separate(ABBA_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_P)))
# Merge AICc and R2 tables together
ABBA_P_results <- merge(ABBA_P_sep, ABBA_P_R2, by.x="ModNumber", by.y = "rowname")











# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU C Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_C1 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_C2 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_C3 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_C4 <- glm(C ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_C5 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_C6 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_C7 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_C8 <- glm(C ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_C9 <- glm(C ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_C10 <- glm(C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_C11 <- glm(C ~ LandCover + EVI, data = ACRU)
ACRU_C12 <- glm(C ~ LandCover, data = ACRU)
ACRU_C13 <- glm(C ~ EVI, data = ACRU)
ACRU_C14 <- glm(C ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_C15 <- glm(C ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_C16 <- glm(C ~ 1, data =  ACRU)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_C <- list("ACRU_C_1" = ACRU_C1, "ACRU_C_2" = ACRU_C2, "ACRU_C_3" = ACRU_C3, "ACRU_C_4" = ACRU_C4, "ACRU_C_5" = ACRU_C5, "ACRU_C_6" = ACRU_C6, "ACRU_C_7" = ACRU_C7, "ACRU_C_8" =  ACRU_C8, "ACRU_C_9" = ACRU_C9, "ACRU_C_10" = ACRU_C10, "ACRU_C_11" = ACRU_C11, "ACRU_C_12" = ACRU_C12, "ACRU_C_13" = ACRU_C13, "ACRU_C_14" = ACRU_C14, "ACRU_C_15" = ACRU_C15, "ACRU_C_16" = ACRU_C16)
ACRU_C <- as.data.frame(aictab(cand.set = Cand_models_ACRU_C)) # EVI pretending so just model 15
# Split string
ACRU_C_sep <- separate(ACRU_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_C)))
# Merge AICc and R2 tables together
ACRU_C_results <- merge(ACRU_C_sep, ACRU_C_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_N1 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_N2 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_N3 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_N4 <- glm(N ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_N5 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_N6 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_N7 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_N8 <- glm(N ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_N9 <- glm(N ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_N10 <- glm(N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_N11 <- glm(N ~ LandCover + EVI, data = ACRU)
ACRU_N12 <- glm(N ~ LandCover, data = ACRU)
ACRU_N13 <- glm(N ~ EVI, data = ACRU)
ACRU_N14 <- glm(N ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_N15 <- glm(N ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_N16 <- glm(N ~ 1, data =  ACRU)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_N <- list("ACRU_N_1" = ACRU_N1, "ACRU_N_2" = ACRU_N2, "ACRU_N_3" = ACRU_N3, "ACRU_N_4" = ACRU_N4, "ACRU_N_5" = ACRU_N5, "ACRU_N_6" = ACRU_N6, "ACRU_N_7" = ACRU_N7, "ACRU_N_8" =  ACRU_N8, "ACRU_N_9" = ACRU_N9, "ACRU_N_10" = ACRU_N10, "ACRU_N_11" = ACRU_N11, "ACRU_N_12" = ACRU_N12, "ACRU_N_13" = ACRU_N13, "ACRU_N_14" = ACRU_N14, "ACRU_N_15" = ACRU_N15, "ACRU_N_16" = ACRU_N16)
ACRU_N <- as.data.frame(aictab(cand.set = Cand_models_ACRU_N)) # EVI pretending
# Split string
ACRU_N_sep <- separate(ACRU_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_N)))
# Merge AICc and R2 tables together
ACRU_N_results <- merge(ACRU_N_sep, ACRU_N_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_P1 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_P2 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_P3 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_P4 <- glm(P ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_P5 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_P6 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_P7 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_P8 <- glm(P ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_P9 <- glm(P ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_P10 <- glm(P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_P11 <- glm(P ~ LandCover + EVI, data = ACRU)
ACRU_P12 <- glm(P ~ LandCover, data = ACRU)
ACRU_P13 <- glm(P ~ EVI, data = ACRU)
ACRU_P14 <- glm(P ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_P15 <- glm(P ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_P16 <- glm(P ~ 1, data =  ACRU)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_P <- list("ACRU_P_1" = ACRU_P1, "ACRU_P_2" = ACRU_P2, "ACRU_P_3" = ACRU_P3, "ACRU_P_4" = ACRU_P4, "ACRU_P_5" = ACRU_P5, "ACRU_P_6" = ACRU_P6, "ACRU_P_7" = ACRU_P7, "ACRU_P_8" =  ACRU_P8, "ACRU_P_9" = ACRU_P9, "ACRU_P_10" = ACRU_P10, "ACRU_P_11" = ACRU_P11, "ACRU_P_12" = ACRU_P12, "ACRU_P_13" = ACRU_P13, "ACRU_P_14" = ACRU_P14, "ACRU_P_15" = ACRU_P15, "ACRU_P_16" = ACRU_P16)
ACRU_P <- as.data.frame(aictab(cand.set = Cand_models_ACRU_P))
# Split string
ACRU_P_sep <- separate(ACRU_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_P)))
# Merge AICc and R2 tables together
ACRU_P_results <- merge(ACRU_P_sep, ACRU_P_R2, by.x="ModNumber", by.y = "rowname")






# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA C Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_C1 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_C2 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_C3 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_C4 <- glm(C ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_C5 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_C6 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_C7 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_C8 <- glm(C ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_C9 <- glm(C ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_C10 <- glm(C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_C11 <- glm(C ~ LandCover + EVI, data = BEPA)
BEPA_C12 <- glm(C ~ LandCover, data = BEPA)
BEPA_C13 <- glm(C ~ EVI, data = BEPA)
BEPA_C14 <- glm(C ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_C15 <- glm(C ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_C16 <- glm(C ~ 1, data =  BEPA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_C <- list("BEPA_C_1" = BEPA_C1, "BEPA_C_2" = BEPA_C2, "BEPA_C_3" = BEPA_C3, "BEPA_C_4" = BEPA_C4, "BEPA_C_5" = BEPA_C5, "BEPA_C_6" = BEPA_C6, "BEPA_C_7" = BEPA_C7, "BEPA_C_8" =  BEPA_C8, "BEPA_C_9" = BEPA_C9, "BEPA_C_10" = BEPA_C10, "BEPA_C_11" = BEPA_C11, "BEPA_C_12" = BEPA_C12, "BEPA_C_13" = BEPA_C13, "BEPA_C_14" = BEPA_C14, "BEPA_C_15" = BEPA_C15, "BEPA_C_16" = BEPA_C16)
BEPA_C <- as.data.frame(aictab(cand.set = Cand_models_BEPA_C))
# Split string
BEPA_C_sep <- separate(BEPA_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_C)))
# Merge AICc and R2 tables together
BEPA_C_results <- merge(BEPA_C_sep, BEPA_C_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_N1 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_N2 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_N3 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_N4 <- glm(N ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_N5 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_N6 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_N7 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_N8 <- glm(N ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_N9 <- glm(N ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_N10 <- glm(N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_N11 <- glm(N ~ LandCover + EVI, data = BEPA)
BEPA_N12 <- glm(N ~ LandCover, data = BEPA)
BEPA_N13 <- glm(N ~ EVI, data = BEPA)
BEPA_N14 <- glm(N ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_N15 <- glm(N ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_N16 <- glm(N ~ 1, data =  BEPA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_N <- list("BEPA_N_1" = BEPA_N1, "BEPA_N_2" = BEPA_N2, "BEPA_N_3" = BEPA_N3, "BEPA_N_4" = BEPA_N4, "BEPA_N_5" = BEPA_N5, "BEPA_N_6" = BEPA_N6, "BEPA_N_7" = BEPA_N7, "BEPA_N_8" =  BEPA_N8, "BEPA_N_9" = BEPA_N9, "BEPA_N_10" = BEPA_N10, "BEPA_N_11" = BEPA_N11, "BEPA_N_12" = BEPA_N12, "BEPA_N_13" = BEPA_N13, "BEPA_N_14" = BEPA_N14, "BEPA_N_15" = BEPA_N15, "BEPA_N_16" = BEPA_N16)
BEPA_N <- as.data.frame(aictab(cand.set = Cand_models_BEPA_N))
# Split string
BEPA_N_sep <- separate(BEPA_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_N)))
# Merge AICc and R2 tables together
BEPA_N_results <- merge(BEPA_N_sep, BEPA_N_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_P1 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_P2 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_P3 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_P4 <- glm(P ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_P5 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_P6 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_P7 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_P8 <- glm(P ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_P9 <- glm(P ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_P10 <- glm(P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_P11 <- glm(P ~ LandCover + EVI, data = BEPA)
BEPA_P12 <- glm(P ~ LandCover, data = BEPA)
BEPA_P13 <- glm(P ~ EVI, data = BEPA)
BEPA_P14 <- glm(P ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_P15 <- glm(P ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_P16 <- glm(P ~ 1, data =  BEPA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_P <- list("BEPA_P_1" = BEPA_P1, "BEPA_P_2" = BEPA_P2, "BEPA_P_3" = BEPA_P3, "BEPA_P_4" = BEPA_P4, "BEPA_P_5" = BEPA_P5, "BEPA_P_6" = BEPA_P6, "BEPA_P_7" = BEPA_P7, "BEPA_P_8" =  BEPA_P8, "BEPA_P_9" = BEPA_P9, "BEPA_P_10" = BEPA_P10, "BEPA_P_11" = BEPA_P11, "BEPA_P_12" = BEPA_P12, "BEPA_P_13" = BEPA_P13, "BEPA_P_14" = BEPA_P14, "BEPA_P_15" = BEPA_P15, "BEPA_P_16" = BEPA_P16)
BEPA_P <- as.data.frame(aictab(cand.set = Cand_models_BEPA_P))
# Split string
BEPA_P_sep <- separate(BEPA_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_P)))
# Merge AICc and R2 tables together
BEPA_P_results <- merge(BEPA_P_sep, BEPA_P_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA C Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_C1 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_C2 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_C3 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_C4 <- glm(C ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_C5 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_C6 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_C7 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_C8 <- glm(C ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_C9 <- glm(C ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_C10 <- glm(C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_C11 <- glm(C ~ LandCover + EVI, data = PIMA)
PIMA_C12 <- glm(C ~ LandCover, data = PIMA)
PIMA_C13 <- glm(C ~ EVI, data = PIMA)
PIMA_C14 <- glm(C ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_C15 <- glm(C ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_C16 <- glm(C ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_C <- list("PIMA_C_1" = PIMA_C1, "PIMA_C_2" = PIMA_C2, "PIMA_C_3" = PIMA_C3, "PIMA_C_4" = PIMA_C4, "PIMA_C_5" = PIMA_C5, "PIMA_C_6" = PIMA_C6, "PIMA_C_7" = PIMA_C7, "PIMA_C_8" =  PIMA_C8, "PIMA_C_9" = PIMA_C9, "PIMA_C_10" = PIMA_C10, "PIMA_C_11" = PIMA_C11, "PIMA_C_12" = PIMA_C12, "PIMA_C_13" = PIMA_C13, "PIMA_C_14" = PIMA_C14, "PIMA_C_15" = PIMA_C15, "PIMA_C_16" = PIMA_C16)
PIMA_C <- as.data.frame(aictab(cand.set = Cand_models_PIMA_C))
# Split string
PIMA_C_sep <- separate(PIMA_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_C)))
# Merge AICc and R2 tables together
PIMA_C_results <- merge(PIMA_C_sep, PIMA_C_R2, by.x="ModNumber", by.y = "rowname")










# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_N1 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_N2 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_N3 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_N4 <- glm(N ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_N5 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_N6 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_N7 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_N8 <- glm(N ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_N9 <- glm(N ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_N10 <- glm(N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_N11 <- glm(N ~ LandCover + EVI, data = PIMA)
PIMA_N12 <- glm(N ~ LandCover, data = PIMA)
PIMA_N13 <- glm(N ~ EVI, data = PIMA)
PIMA_N14 <- glm(N ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_N15 <- glm(N ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_N16 <- glm(N ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_N <- list("PIMA_N_1" = PIMA_N1, "PIMA_N_2" = PIMA_N2, "PIMA_N_3" = PIMA_N3, "PIMA_N_4" = PIMA_N4, "PIMA_N_5" = PIMA_N5, "PIMA_N_6" = PIMA_N6, "PIMA_N_7" = PIMA_N7, "PIMA_N_8" =  PIMA_N8, "PIMA_N_9" = PIMA_N9, "PIMA_N_10" = PIMA_N10, "PIMA_N_11" = PIMA_N11, "PIMA_N_12" = PIMA_N12, "PIMA_N_13" = PIMA_N13, "PIMA_N_14" = PIMA_N14, "PIMA_N_15" = PIMA_N15, "PIMA_N_16" = PIMA_N16)
PIMA_N <- as.data.frame(aictab(cand.set = Cand_models_PIMA_N))
# Split string
PIMA_N_sep <- separate(PIMA_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_N)))
# Merge AICc and R2 tables together
PIMA_N_results <- merge(PIMA_N_sep, PIMA_N_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_P1 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_P2 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_P3 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_P4 <- glm(P ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_P5 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_P6 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_P7 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_P8 <- glm(P ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_P9 <- glm(P ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_P10 <- glm(P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_P11 <- glm(P ~ LandCover + EVI, data = PIMA)
PIMA_P12 <- glm(P ~ LandCover, data = PIMA)
PIMA_P13 <- glm(P ~ EVI, data = PIMA)
PIMA_P14 <- glm(P ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_P15 <- glm(P ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_P16 <- glm(P ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_P <- list("PIMA_P_1" = PIMA_P1, "PIMA_P_2" = PIMA_P2, "PIMA_P_3" = PIMA_P3, "PIMA_P_4" = PIMA_P4, "PIMA_P_5" = PIMA_P5, "PIMA_P_6" = PIMA_P6, "PIMA_P_7" = PIMA_P7, "PIMA_P_8" =  PIMA_P8, "PIMA_P_9" = PIMA_P9, "PIMA_P_10" = PIMA_P10, "PIMA_P_11" = PIMA_P11, "PIMA_P_12" = PIMA_P12, "PIMA_P_13" = PIMA_P13, "PIMA_P_14" = PIMA_P14, "PIMA_P_15" = PIMA_P15, "PIMA_P_16" = PIMA_P16)
PIMA_P <- as.data.frame(aictab(cand.set = Cand_models_PIMA_P))
# Split string
PIMA_P_sep <- separate(PIMA_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_P)))
# Merge AICc and R2 tables together
PIMA_P_results <- merge(PIMA_P_sep, PIMA_P_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN C Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_C1 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_C2 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_C3 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_C4 <- glm(C ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_C5 <- glm(C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_C6 <- glm(C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_C7 <- glm(C ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_C8 <- glm(C ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_C9 <- glm(C ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_C10 <- glm(C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_C11 <- glm(C ~ LandCover + EVI, data = VAAN)
VAAN_C12 <- glm(C ~ LandCover, data = VAAN)
VAAN_C13 <- glm(C ~ EVI, data = VAAN)
VAAN_C14 <- glm(C ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_C15 <- glm(C ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_C16 <- glm(C ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_C <- list("VAAN_C_1" = VAAN_C1, "VAAN_C_2" = VAAN_C2, "VAAN_C_3" = VAAN_C3, "VAAN_C_4" = VAAN_C4, "VAAN_C_5" = VAAN_C5, "VAAN_C_6" = VAAN_C6, "VAAN_C_7" = VAAN_C7, "VAAN_C_8" =  VAAN_C8, "VAAN_C_9" = VAAN_C9, "VAAN_C_10" = VAAN_C10, "VAAN_C_11" = VAAN_C11, "VAAN_C_12" = VAAN_C12, "VAAN_C_13" = VAAN_C13, "VAAN_C_14" = VAAN_C14, "VAAN_C_15" = VAAN_C15, "VAAN_C_16" = VAAN_C16)
VAAN_C <- as.data.frame(aictab(cand.set = Cand_models_VAAN_C))
# Split string
VAAN_C_sep <- separate(VAAN_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_C)))
# Merge AICc and R2 tables together
VAAN_C_results <- merge(VAAN_C_sep, VAAN_C_R2, by.x="ModNumber", by.y = "rowname")






# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_N1 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_N2 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_N3 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_N4 <- glm(N ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_N5 <- glm(N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_N6 <- glm(N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_N7 <- glm(N ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_N8 <- glm(N ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_N9 <- glm(N ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_N10 <- glm(N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_N11 <- glm(N ~ LandCover + EVI, data = VAAN)
VAAN_N12 <- glm(N ~ LandCover, data = VAAN)
VAAN_N13 <- glm(N ~ EVI, data = VAAN)
VAAN_N14 <- glm(N ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_N15 <- glm(N ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_N16 <- glm(N ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_N <- list("VAAN_N_1" = VAAN_N1, "VAAN_N_2" = VAAN_N2, "VAAN_N_3" = VAAN_N3, "VAAN_N_4" = VAAN_N4, "VAAN_N_5" = VAAN_N5, "VAAN_N_6" = VAAN_N6, "VAAN_N_7" = VAAN_N7, "VAAN_N_8" =  VAAN_N8, "VAAN_N_9" = VAAN_N9, "VAAN_N_10" = VAAN_N10, "VAAN_N_11" = VAAN_N11, "VAAN_N_12" = VAAN_N12, "VAAN_N_13" = VAAN_N13, "VAAN_N_14" = VAAN_N14, "VAAN_N_15" = VAAN_N15, "VAAN_N_16" = VAAN_N16)
VAAN_N <- as.data.frame(aictab(cand.set = Cand_models_VAAN_N))
# Split string
VAAN_N_sep <- separate(VAAN_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_N)))
# Merge AICc and R2 tables together
VAAN_N_results <- merge(VAAN_N_sep, VAAN_N_R2, by.x="ModNumber", by.y = "rowname")










# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_P1 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_P2 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_P3 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_P4 <- glm(P ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_P5 <- glm(P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_P6 <- glm(P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_P7 <- glm(P ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_P8 <- glm(P ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_P9 <- glm(P ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_P10 <- glm(P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_P11 <- glm(P ~ LandCover + EVI, data = VAAN)
VAAN_P12 <- glm(P ~ LandCover, data = VAAN)
VAAN_P13 <- glm(P ~ EVI, data = VAAN)
VAAN_P14 <- glm(P ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_P15 <- glm(P ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_P16 <- glm(P ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_P <- list("VAAN_P_1" = VAAN_P1, "VAAN_P_2" = VAAN_P2, "VAAN_P_3" = VAAN_P3, "VAAN_P_4" = VAAN_P4, "VAAN_P_5" = VAAN_P5, "VAAN_P_6" = VAAN_P6, "VAAN_P_7" = VAAN_P7, "VAAN_P_8" =  VAAN_P8, "VAAN_P_9" = VAAN_P9, "VAAN_P_10" = VAAN_P10, "VAAN_P_11" = VAAN_P11, "VAAN_P_12" = VAAN_P12, "VAAN_P_13" = VAAN_P13, "VAAN_P_14" = VAAN_P14, "VAAN_P_15" = VAAN_P15, "VAAN_P_16" = VAAN_P16)
VAAN_P <- as.data.frame(aictab(cand.set = Cand_models_VAAN_P))
# Split string
VAAN_P_sep <- separate(VAAN_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_P)))
# Merge AICc and R2 tables together
VAAN_P_results <- merge(VAAN_P_sep, VAAN_P_R2, by.x="ModNumber", by.y = "rowname")












# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Quantity Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ABBA Qty_C Models #### 
ABBA_Qty_C1 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_C2 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_C3 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_C4 <- glm(Qty_C ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_C5 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_C6 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_C7 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_C8 <- glm(Qty_C ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_C9 <- glm(Qty_C ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_C10 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_C11 <- glm(Qty_C ~ LandCover + EVI, data = ABBA)
ABBA_Qty_C12 <- glm(Qty_C ~ LandCover, data = ABBA)
ABBA_Qty_C13 <- glm(Qty_C ~ EVI, data = ABBA)
ABBA_Qty_C14 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_C15 <- glm(Qty_C ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_C16 <- glm(Qty_C ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_Qty_C <- list("ABBA_QtyC_1" = ABBA_Qty_C1, "ABBA_QtyC_2" = ABBA_Qty_C2, "ABBA_QtyC_3" = ABBA_Qty_C3, "ABBA_QtyC_4" = ABBA_Qty_C4, "ABBA_QtyC_5" = ABBA_Qty_C5, "ABBA_QtyC_6" = ABBA_Qty_C6, "ABBA_QtyC_7" = ABBA_Qty_C7, "ABBA_QtyC_8" =  ABBA_Qty_C8, "ABBA_QtyC_9" = ABBA_Qty_C9, "ABBA_QtyC_10" = ABBA_Qty_C10, "ABBA_QtyC_11" = ABBA_Qty_C11, "ABBA_QtyC_12" = ABBA_Qty_C12, "ABBA_QtyC_13" = ABBA_Qty_C13, "ABBA_QtyC_14" = ABBA_Qty_C14, "ABBA_QtyC_15" = ABBA_Qty_C15, "ABBA_QtyC_16" = ABBA_Qty_C16)
ABBA_Qty_C <- as.data.frame(aictab(cand.set = Cand_models_ABBA_Qty_C))
# Split string
ABBA_Qty_C_sep <- separate(ABBA_Qty_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_Qty_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_Qty_C)))
# Merge AICc and R2 tables together
ABBA_Qty_C_results <- merge(ABBA_Qty_C_sep, ABBA_Qty_C_R2, by.x="ModNumber", by.y = "rowname")





# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ABBA Qty_N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_Qty_N1 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_N2 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_N3 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_N4 <- glm(Qty_N ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_N5 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_N6 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_N7 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_N8 <- glm(Qty_N ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_N9 <- glm(Qty_N ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_N10 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_N11 <- glm(Qty_N ~ LandCover + EVI, data = ABBA)
ABBA_Qty_N12 <- glm(Qty_N ~ LandCover, data = ABBA)
ABBA_Qty_N13 <- glm(Qty_N ~ EVI, data = ABBA)
ABBA_Qty_N14 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_N15 <- glm(Qty_N ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_N16 <- glm(Qty_N ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_Qty_N <- list("ABBA_QtyN_1" = ABBA_Qty_N1, "ABBA_QtyN_2" = ABBA_Qty_N2, "ABBA_QtyN_3" = ABBA_Qty_N3, "ABBA_QtyN_4" = ABBA_Qty_N4, "ABBA_QtyN_5" = ABBA_Qty_N5, "ABBA_QtyN_6" = ABBA_Qty_N6, "ABBA_QtyN_7" = ABBA_Qty_N7, "ABBA_QtyN_8" =  ABBA_Qty_N8, "ABBA_QtyN_9" = ABBA_Qty_N9, "ABBA_QtyN_10" = ABBA_Qty_N10, "ABBA_QtyN_11" = ABBA_Qty_N11, "ABBA_QtyN_12" = ABBA_Qty_N12, "ABBA_QtyN_13" = ABBA_Qty_N13, "ABBA_QtyN_14" = ABBA_Qty_N14, "ABBA_QtyN_15" = ABBA_Qty_N15, "ABBA_QtyN_16" = ABBA_Qty_N16)
ABBA_Qty_N <- as.data.frame(aictab(cand.set = Cand_models_ABBA_Qty_N))
# Split string
ABBA_Qty_N_sep <- separate(ABBA_Qty_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_Qty_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_Qty_N)))
# Merge AICc and R2 tables together
ABBA_Qty_N_results <- merge(ABBA_Qty_N_sep, ABBA_Qty_N_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ABBA Qty_P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_Qty_P1 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_P2 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_P3 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_P4 <- glm(Qty_P ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_P5 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_P6 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_P7 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_P8 <- glm(Qty_P ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_P9 <- glm(Qty_P ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_P10 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_P11 <- glm(Qty_P ~ LandCover + EVI, data = ABBA)
ABBA_Qty_P12 <- glm(Qty_P ~ LandCover, data = ABBA)
ABBA_Qty_P13 <- glm(Qty_P ~ EVI, data = ABBA)
ABBA_Qty_P14 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_Qty_P15 <- glm(Qty_P ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_Qty_P16 <- glm(Qty_P ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_Qty_P <- list("ABBA_QtyP_1" = ABBA_Qty_P1, "ABBA_QtyP_2" = ABBA_Qty_P2, "ABBA_QtyP_3" = ABBA_Qty_P3, "ABBA_QtyP_4" = ABBA_Qty_P4, "ABBA_QtyP_5" = ABBA_Qty_P5, "ABBA_QtyP_6" = ABBA_Qty_P6, "ABBA_QtyP_7" = ABBA_Qty_P7, "ABBA_QtyP_8" =  ABBA_Qty_P8, "ABBA_QtyP_9" = ABBA_Qty_P9, "ABBA_QtyP_10" = ABBA_Qty_P10, "ABBA_QtyP_11" = ABBA_Qty_P11, "ABBA_QtyP_12" = ABBA_Qty_P12, "ABBA_QtyP_13" = ABBA_Qty_P13, "ABBA_QtyP_14" = ABBA_Qty_P14, "ABBA_QtyP_15" = ABBA_Qty_P15, "ABBA_QtyP_16" = ABBA_Qty_P16)
ABBA_Qty_P <- as.data.frame(aictab(cand.set = Cand_models_ABBA_Qty_P))
# Split string
ABBA_Qty_P_sep <- separate(ABBA_Qty_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_Qty_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_Qty_P)))
# Merge AICc and R2 tables together
ABBA_Qty_P_results <- merge(ABBA_Qty_P_sep, ABBA_Qty_P_R2, by.x="ModNumber", by.y = "rowname")






# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU Qty_C Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_Qty_C1 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_C2 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_C3 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_C4 <- glm(Qty_C ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_C5 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_C6 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_C7 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_C8 <- glm(Qty_C ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_C9 <- glm(Qty_C ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_C10 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_C11 <- glm(Qty_C ~ LandCover + EVI, data = ACRU)
ACRU_Qty_C12 <- glm(Qty_C ~ LandCover, data = ACRU)
ACRU_Qty_C13 <- glm(Qty_C ~ EVI, data = ACRU)
ACRU_Qty_C14 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_C15 <- glm(Qty_C ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_C16 <- glm(Qty_C ~ 1, data =  ACRU)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_Qty_C <- list("ACRU_QtyC_1" = ACRU_Qty_C1, "ACRU_QtyC_2" = ACRU_Qty_C2, "ACRU_QtyC_3" = ACRU_Qty_C3, "ACRU_QtyC_4" = ACRU_Qty_C4, "ACRU_QtyC_5" = ACRU_Qty_C5, "ACRU_QtyC_6" = ACRU_Qty_C6, "ACRU_QtyC_7" = ACRU_Qty_C7, "ACRU_QtyC_8" =  ACRU_Qty_C8, "ACRU_QtyC_9" = ACRU_Qty_C9, "ACRU_QtyC_10" = ACRU_Qty_C10, "ACRU_QtyC_11" = ACRU_Qty_C11, "ACRU_QtyC_12" = ACRU_Qty_C12, "ACRU_QtyC_13" = ACRU_Qty_C13, "ACRU_QtyC_14" = ACRU_Qty_C14, "ACRU_QtyC_15" = ACRU_Qty_C15, "ACRU_QtyC_16" = ACRU_Qty_C16)
ACRU_Qty_C <- as.data.frame(aictab(cand.set = Cand_models_ACRU_Qty_C))
# Split string
ACRU_Qty_C_sep <- separate(ACRU_Qty_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_Qty_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_Qty_C)))
# Merge AICc and R2 tables together
ACRU_Qty_C_results <- merge(ACRU_Qty_C_sep, ACRU_Qty_C_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU Qty_N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_Qty_N1 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_N2 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_N3 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_N4 <- glm(Qty_N ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_N5 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_N6 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_N7 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_N8 <- glm(Qty_N ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_N9 <- glm(Qty_N ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_N10 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_N11 <- glm(Qty_N ~ LandCover + EVI, data = ACRU)
ACRU_Qty_N12 <- glm(Qty_N ~ LandCover, data = ACRU)
ACRU_Qty_N13 <- glm(Qty_N ~ EVI, data = ACRU)
ACRU_Qty_N14 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_N15 <- glm(Qty_N ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_N16 <- glm(Qty_N ~ 1, data =  ACRU)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_Qty_N <- list("ACRU_QtyN_1" = ACRU_Qty_N1, "ACRU_QtyN_2" = ACRU_Qty_N2, "ACRU_QtyN_3" = ACRU_Qty_N3, "ACRU_QtyN_4" = ACRU_Qty_N4, "ACRU_QtyN_5" = ACRU_Qty_N5, "ACRU_QtyN_6" = ACRU_Qty_N6, "ACRU_QtyN_7" = ACRU_Qty_N7, "ACRU_QtyN_8" =  ACRU_Qty_N8, "ACRU_QtyN_9" = ACRU_Qty_N9, "ACRU_QtyN_10" = ACRU_Qty_N10, "ACRU_QtyN_11" = ACRU_Qty_N11, "ACRU_QtyN_12" = ACRU_Qty_N12, "ACRU_QtyN_13" = ACRU_Qty_N13, "ACRU_QtyN_14" = ACRU_Qty_N14, "ACRU_QtyN_15" = ACRU_Qty_N15, "ACRU_QtyN_16" = ACRU_Qty_N16)
ACRU_Qty_N <- as.data.frame(aictab(cand.set = Cand_models_ACRU_Qty_N))
# Split string
ACRU_Qty_N_sep <- separate(ACRU_Qty_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_Qty_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_Qty_N)))
# Merge AICc and R2 tables together
ACRU_Qty_N_results <- merge(ACRU_Qty_N_sep, ACRU_Qty_N_R2, by.x="ModNumber", by.y = "rowname")





# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU Qty_P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_Qty_P1 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_P2 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_P3 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_P4 <- glm(Qty_P ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_P5 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_P6 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_P7 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_P8 <- glm(Qty_P ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_P9 <- glm(Qty_P ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_P10 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_P11 <- glm(Qty_P ~ LandCover + EVI, data = ACRU)
ACRU_Qty_P12 <- glm(Qty_P ~ LandCover, data = ACRU)
ACRU_Qty_P13 <- glm(Qty_P ~ EVI, data = ACRU)
ACRU_Qty_P14 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_Qty_P15 <- glm(Qty_P ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_Qty_P16 <- glm(Qty_P ~ 1, data =  ACRU)
# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_Qty_P <- list("ACRU_QtyP_1" = ACRU_Qty_P1, "ACRU_QtyP_2" = ACRU_Qty_P2, "ACRU_QtyP_3" = ACRU_Qty_P3, "ACRU_QtyP_4" = ACRU_Qty_P4, "ACRU_QtyP_5" = ACRU_Qty_P5, "ACRU_QtyP_6" = ACRU_Qty_P6, "ACRU_QtyP_7" = ACRU_Qty_P7, "ACRU_QtyP_8" =  ACRU_Qty_P8, "ACRU_QtyP_9" = ACRU_Qty_P9, "ACRU_QtyP_10" = ACRU_Qty_P10, "ACRU_QtyP_11" = ACRU_Qty_P11, "ACRU_QtyP_12" = ACRU_Qty_P12, "ACRU_QtyP_13" = ACRU_Qty_P13, "ACRU_QtyP_14" = ACRU_Qty_P14, "ACRU_QtyP_15" = ACRU_Qty_P15, "ACRU_QtyP_16" = ACRU_Qty_P16)
ACRU_Qty_P <- as.data.frame(aictab(cand.set = Cand_models_ACRU_Qty_P))
# Split string
ACRU_Qty_P_sep <- separate(ACRU_Qty_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_Qty_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_Qty_P)))
# Merge AICc and R2 tables together
ACRU_Qty_P_results <- merge(ACRU_Qty_P_sep, ACRU_Qty_P_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA Qty_C Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_Qty_C1 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_C2 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_C3 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_C4 <- glm(Qty_C ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_C5 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_C6 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_C7 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_C8 <- glm(Qty_C ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_C9 <- glm(Qty_C ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_C10 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_C11 <- glm(Qty_C ~ LandCover + EVI, data = BEPA)
BEPA_Qty_C12 <- glm(Qty_C ~ LandCover, data = BEPA)
BEPA_Qty_C13 <- glm(Qty_C ~ EVI, data = BEPA)
BEPA_Qty_C14 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_C15 <- glm(Qty_C ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_C16 <- glm(Qty_C ~ 1, data =  BEPA)
# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_Qty_C <- list("BEPA_QtyC_1" = BEPA_Qty_C1, "BEPA_QtyC_2" = BEPA_Qty_C2, "BEPA_QtyC_3" = BEPA_Qty_C3, "BEPA_QtyC_4" = BEPA_Qty_C4, "BEPA_QtyC_5" = BEPA_Qty_C5, "BEPA_QtyC_6" = BEPA_Qty_C6, "BEPA_QtyC_7" = BEPA_Qty_C7, "BEPA_QtyC_8" =  BEPA_Qty_C8, "BEPA_QtyC_9" = BEPA_Qty_C9, "BEPA_QtyC_10" = BEPA_Qty_C10, "BEPA_QtyC_11" = BEPA_Qty_C11, "BEPA_QtyC_12" = BEPA_Qty_C12, "BEPA_QtyC_13" = BEPA_Qty_C13, "BEPA_QtyC_14" = BEPA_Qty_C14, "BEPA_QtyC_15" = BEPA_Qty_C15, "BEPA_QtyC_16" = BEPA_Qty_C16)
BEPA_Qty_C <- as.data.frame(aictab(cand.set = Cand_models_BEPA_Qty_C))
# Split string
BEPA_Qty_C_sep <- separate(BEPA_Qty_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_Qty_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_Qty_C)))
# Merge AICc and R2 tables together
BEPA_Qty_C_results <- merge(BEPA_Qty_C_sep, BEPA_Qty_C_R2, by.x="ModNumber", by.y = "rowname")









# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA Qty_N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_Qty_N1 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_N2 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_N3 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_N4 <- glm(Qty_N ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_N5 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_N6 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_N7 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_N8 <- glm(Qty_N ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_N9 <- glm(Qty_N ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_N10 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_N11 <- glm(Qty_N ~ LandCover + EVI, data = BEPA)
BEPA_Qty_N12 <- glm(Qty_N ~ LandCover, data = BEPA)
BEPA_Qty_N13 <- glm(Qty_N ~ EVI, data = BEPA)
BEPA_Qty_N14 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_N15 <- glm(Qty_N ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_N16 <- glm(Qty_N ~ 1, data =  BEPA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_Qty_N <- list("BEPA_QtyN_1" = BEPA_Qty_N1, "BEPA_QtyN_2" = BEPA_Qty_N2, "BEPA_QtyN_3" = BEPA_Qty_N3, "BEPA_QtyN_4" = BEPA_Qty_N4, "BEPA_QtyN_5" = BEPA_Qty_N5, "BEPA_QtyN_6" = BEPA_Qty_N6, "BEPA_QtyN_7" = BEPA_Qty_N7, "BEPA_QtyN_8" =  BEPA_Qty_N8, "BEPA_QtyN_9" = BEPA_Qty_N9, "BEPA_QtyN_10" = BEPA_Qty_N10, "BEPA_QtyN_11" = BEPA_Qty_N11, "BEPA_QtyN_12" = BEPA_Qty_N12, "BEPA_QtyN_13" = BEPA_Qty_N13, "BEPA_QtyN_14" = BEPA_Qty_N14, "BEPA_QtyN_15" = BEPA_Qty_N15, "BEPA_QtyN_16" = BEPA_Qty_N16)
BEPA_Qty_N <- as.data.frame(aictab(cand.set = Cand_models_BEPA_Qty_N))
# Split string
BEPA_Qty_N_sep <- separate(BEPA_Qty_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_Qty_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_Qty_N)))
# Merge AICc and R2 tables together
BEPA_Qty_N_results <- merge(BEPA_Qty_N_sep, BEPA_Qty_N_R2, by.x="ModNumber", by.y = "rowname")










# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA Qty_P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_Qty_P1 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_P2 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_P3 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_P4 <- glm(Qty_P ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_P5 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_P6 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_P7 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_P8 <- glm(Qty_P ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_P9 <- glm(Qty_P ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_P10 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_P11 <- glm(Qty_P ~ LandCover + EVI, data = BEPA)
BEPA_Qty_P12 <- glm(Qty_P ~ LandCover, data = BEPA)
BEPA_Qty_P13 <- glm(Qty_P ~ EVI, data = BEPA)
BEPA_Qty_P14 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_Qty_P15 <- glm(Qty_P ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_Qty_P16 <- glm(Qty_P ~ 1, data =  BEPA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_Qty_P <- list("BEPA_QtyP_1" = BEPA_Qty_P1, "BEPA_QtyP_2" = BEPA_Qty_P2, "BEPA_QtyP_3" = BEPA_Qty_P3, "BEPA_QtyP_4" = BEPA_Qty_P4, "BEPA_QtyP_5" = BEPA_Qty_P5, "BEPA_QtyP_6" = BEPA_Qty_P6, "BEPA_QtyP_7" = BEPA_Qty_P7, "BEPA_QtyP_8" =  BEPA_Qty_P8, "BEPA_QtyP_9" = BEPA_Qty_P9, "BEPA_QtyP_10" = BEPA_Qty_P10, "BEPA_QtyP_11" = BEPA_Qty_P11, "BEPA_QtyP_12" = BEPA_Qty_P12, "BEPA_QtyP_13" = BEPA_Qty_P13, "BEPA_QtyP_14" = BEPA_Qty_P14, "BEPA_QtyP_15" = BEPA_Qty_P15, "BEPA_QtyP_16" = BEPA_Qty_P16)
BEPA_Qty_P <- as.data.frame(aictab(cand.set = Cand_models_BEPA_Qty_P))
# Split string
BEPA_Qty_P_sep <- separate(BEPA_Qty_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_Qty_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_Qty_P)))
# Merge AICc and R2 tables together
BEPA_Qty_P_results <- merge(BEPA_Qty_P_sep, BEPA_Qty_P_R2, by.x="ModNumber", by.y = "rowname")











# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA Qty_C Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_Qty_C1 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_C2 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_C3 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_C4 <- glm(Qty_C ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_C5 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_C6 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_C7 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_C8 <- glm(Qty_C ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_C9 <- glm(Qty_C ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_C10 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_C11 <- glm(Qty_C ~ LandCover + EVI, data = PIMA)
PIMA_Qty_C12 <- glm(Qty_C ~ LandCover, data = PIMA)
PIMA_Qty_C13 <- glm(Qty_C ~ EVI, data = PIMA)
PIMA_Qty_C14 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_C15 <- glm(Qty_C ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_C16 <- glm(Qty_C ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_Qty_C <- list("PIMA_QtyC_1" = PIMA_Qty_C1, "PIMA_QtyC_2" = PIMA_Qty_C2, "PIMA_QtyC_3" = PIMA_Qty_C3, "PIMA_QtyC_4" = PIMA_Qty_C4, "PIMA_QtyC_5" = PIMA_Qty_C5, "PIMA_QtyC_6" = PIMA_Qty_C6, "PIMA_QtyC_7" = PIMA_Qty_C7, "PIMA_QtyC_8" =  PIMA_Qty_C8, "PIMA_QtyC_9" = PIMA_Qty_C9, "PIMA_QtyC_10" = PIMA_Qty_C10, "PIMA_QtyC_11" = PIMA_Qty_C11, "PIMA_QtyC_12" = PIMA_Qty_C12, "PIMA_QtyC_13" = PIMA_Qty_C13, "PIMA_QtyC_14" = PIMA_Qty_C14, "PIMA_QtyC_15" = PIMA_Qty_C15, "PIMA_QtyC_16" = PIMA_Qty_C16)
PIMA_Qty_C <- as.data.frame(aictab(cand.set = Cand_models_PIMA_Qty_C))
# Split string
PIMA_Qty_C_sep <- separate(PIMA_Qty_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_Qty_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_Qty_C)))
# Merge AICc and R2 tables together
PIMA_Qty_C_results <- merge(PIMA_Qty_C_sep, PIMA_Qty_C_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA Qty_N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_Qty_N1 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_N2 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_N3 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_N4 <- glm(Qty_N ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_N5 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_N6 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_N7 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_N8 <- glm(Qty_N ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_N9 <- glm(Qty_N ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_N10 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_N11 <- glm(Qty_N ~ LandCover + EVI, data = PIMA)
PIMA_Qty_N12 <- glm(Qty_N ~ LandCover, data = PIMA)
PIMA_Qty_N13 <- glm(Qty_N ~ EVI, data = PIMA)
PIMA_Qty_N14 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_N15 <- glm(Qty_N ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_N16 <- glm(Qty_N ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_Qty_N <- list("PIMA_QtyN_1" = PIMA_Qty_N1, "PIMA_QtyN_2" = PIMA_Qty_N2, "PIMA_QtyN_3" = PIMA_Qty_N3, "PIMA_QtyN_4" = PIMA_Qty_N4, "PIMA_QtyN_5" = PIMA_Qty_N5, "PIMA_QtyN_6" = PIMA_Qty_N6, "PIMA_QtyN_7" = PIMA_Qty_N7, "PIMA_QtyN_8" =  PIMA_Qty_N8, "PIMA_QtyN_9" = PIMA_Qty_N9, "PIMA_QtyN_10" = PIMA_Qty_N10, "PIMA_QtyN_11" = PIMA_Qty_N11, "PIMA_QtyN_12" = PIMA_Qty_N12, "PIMA_QtyN_13" = PIMA_Qty_N13, "PIMA_QtyN_14" = PIMA_Qty_N14, "PIMA_QtyN_15" = PIMA_Qty_N15, "PIMA_QtyN_16" = PIMA_Qty_N16)
PIMA_Qty_N <- as.data.frame(aictab(cand.set = Cand_models_PIMA_Qty_N))
# Split string
PIMA_Qty_N_sep <- separate(PIMA_Qty_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_Qty_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_Qty_N)))
# Merge AICc and R2 tables together
PIMA_Qty_N_results <- merge(PIMA_Qty_N_sep, PIMA_Qty_N_R2, by.x="ModNumber", by.y = "rowname")









# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA Qty_P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_Qty_P1 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_P2 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_P3 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_P4 <- glm(Qty_P ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_P5 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_P6 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_P7 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_P8 <- glm(Qty_P ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_P9 <- glm(Qty_P ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_P10 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_P11 <- glm(Qty_P ~ LandCover + EVI, data = PIMA)
PIMA_Qty_P12 <- glm(Qty_P ~ LandCover, data = PIMA)
PIMA_Qty_P13 <- glm(Qty_P ~ EVI, data = PIMA)
PIMA_Qty_P14 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_Qty_P15 <- glm(Qty_P ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_Qty_P16 <- glm(Qty_P ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_Qty_P <- list("PIMA_QtyP_1" = PIMA_Qty_P1, "PIMA_QtyP_2" = PIMA_Qty_P2, "PIMA_QtyP_3" = PIMA_Qty_P3, "PIMA_QtyP_4" = PIMA_Qty_P4, "PIMA_QtyP_5" = PIMA_Qty_P5, "PIMA_QtyP_6" = PIMA_Qty_P6, "PIMA_QtyP_7" = PIMA_Qty_P7, "PIMA_QtyP_8" =  PIMA_Qty_P8, "PIMA_QtyP_9" = PIMA_Qty_P9, "PIMA_QtyP_10" = PIMA_Qty_P10, "PIMA_QtyP_11" = PIMA_Qty_P11, "PIMA_QtyP_12" = PIMA_Qty_P12, "PIMA_QtyP_13" = PIMA_Qty_P13, "PIMA_QtyP_14" = PIMA_Qty_P14, "PIMA_QtyP_15" = PIMA_Qty_P15, "PIMA_QtyP_16" = PIMA_Qty_P16)
PIMA_Qty_P <- as.data.frame(aictab(cand.set = Cand_models_PIMA_Qty_P))
# Split string
PIMA_Qty_P_sep <- separate(PIMA_Qty_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_Qty_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_Qty_P)))
# Merge AICc and R2 tables together
PIMA_Qty_P_results <- merge(PIMA_Qty_P_sep, PIMA_Qty_P_R2, by.x="ModNumber", by.y = "rowname")











# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN Qty_C Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_Qty_C1 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_C2 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_C3 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_C4 <- glm(Qty_C ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_C5 <- glm(Qty_C ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_C6 <- glm(Qty_C ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_C7 <- glm(Qty_C ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_C8 <- glm(Qty_C ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_C9 <- glm(Qty_C ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_C10 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_C11 <- glm(Qty_C ~ LandCover + EVI, data = VAAN)
VAAN_Qty_C12 <- glm(Qty_C ~ LandCover, data = VAAN)
VAAN_Qty_C13 <- glm(Qty_C ~ EVI, data = VAAN)
VAAN_Qty_C14 <- glm(Qty_C ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_C15 <- glm(Qty_C ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_C16 <- glm(Qty_C ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_Qty_C <- list("VAAN_QtyC_1" = VAAN_Qty_C1, "VAAN_QtyC_2" = VAAN_Qty_C2, "VAAN_QtyC_3" = VAAN_Qty_C3, "VAAN_QtyC_4" = VAAN_Qty_C4, "VAAN_QtyC_5" = VAAN_Qty_C5, "VAAN_QtyC_6" = VAAN_Qty_C6, "VAAN_QtyC_7" = VAAN_Qty_C7, "VAAN_QtyC_8" =  VAAN_Qty_C8, "VAAN_QtyC_9" = VAAN_Qty_C9, "VAAN_QtyC_10" = VAAN_Qty_C10, "VAAN_QtyC_11" = VAAN_Qty_C11, "VAAN_QtyC_12" = VAAN_Qty_C12, "VAAN_QtyC_13" = VAAN_Qty_C13, "VAAN_QtyC_14" = VAAN_Qty_C14, "VAAN_QtyC_15" = VAAN_Qty_C15, "VAAN_QtyC_16" = VAAN_Qty_C16)
VAAN_Qty_C <- as.data.frame(aictab(cand.set = Cand_models_VAAN_Qty_C))
# Split string
VAAN_Qty_C_sep <- separate(VAAN_Qty_C, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_Qty_C_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_Qty_C)))
# Merge AICc and R2 tables together
VAAN_Qty_C_results <- merge(VAAN_Qty_C_sep, VAAN_Qty_C_R2, by.x="ModNumber", by.y = "rowname")









# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN Qty_N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_Qty_N1 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_N2 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_N3 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_N4 <- glm(Qty_N ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_N5 <- glm(Qty_N ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_N6 <- glm(Qty_N ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_N7 <- glm(Qty_N ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_N8 <- glm(Qty_N ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_N9 <- glm(Qty_N ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_N10 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_N11 <- glm(Qty_N ~ LandCover + EVI, data = VAAN)
VAAN_Qty_N12 <- glm(Qty_N ~ LandCover, data = VAAN)
VAAN_Qty_N13 <- glm(Qty_N ~ EVI, data = VAAN)
VAAN_Qty_N14 <- glm(Qty_N ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_N15 <- glm(Qty_N ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_N16 <- glm(Qty_N ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_Qty_N <- list("VAAN_QtyN_1" = VAAN_Qty_N1, "VAAN_QtyN_2" = VAAN_Qty_N2, "VAAN_QtyN_3" = VAAN_Qty_N3, "VAAN_QtyN_4" = VAAN_Qty_N4, "VAAN_QtyN_5" = VAAN_Qty_N5, "VAAN_QtyN_6" = VAAN_Qty_N6, "VAAN_QtyN_7" = VAAN_Qty_N7, "VAAN_QtyN_8" =  VAAN_Qty_N8, "VAAN_QtyN_9" = VAAN_Qty_N9, "VAAN_QtyN_10" = VAAN_Qty_N10, "VAAN_QtyN_11" = VAAN_Qty_N11, "VAAN_QtyN_12" = VAAN_Qty_N12, "VAAN_QtyN_13" = VAAN_Qty_N13, "VAAN_QtyN_14" = VAAN_Qty_N14, "VAAN_QtyN_15" = VAAN_Qty_N15, "VAAN_QtyN_16" = VAAN_Qty_N16)
VAAN_Qty_N <- as.data.frame(aictab(cand.set = Cand_models_VAAN_Qty_N))
# Split string
VAAN_Qty_N_sep <- separate(VAAN_Qty_N, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_Qty_N_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_Qty_N)))
# Merge AICc and R2 tables together
VAAN_Qty_N_results <- merge(VAAN_Qty_N_sep, VAAN_Qty_N_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN Qty_P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_Qty_P1 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_P2 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_P3 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_P4 <- glm(Qty_P ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_P5 <- glm(Qty_P ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_P6 <- glm(Qty_P ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_P7 <- glm(Qty_P ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_P8 <- glm(Qty_P ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_P9 <- glm(Qty_P ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_P10 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_P11 <- glm(Qty_P ~ LandCover + EVI, data = VAAN)
VAAN_Qty_P12 <- glm(Qty_P ~ LandCover, data = VAAN)
VAAN_Qty_P13 <- glm(Qty_P ~ EVI, data = VAAN)
VAAN_Qty_P14 <- glm(Qty_P ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_Qty_P15 <- glm(Qty_P ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_Qty_P16 <- glm(Qty_P ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_Qty_P <- list("VAAN_QtyP_1" = VAAN_Qty_P1, "VAAN_QtyP_2" = VAAN_Qty_P2, "VAAN_QtyP_3" = VAAN_Qty_P3, "VAAN_QtyP_4" = VAAN_Qty_P4, "VAAN_QtyP_5" = VAAN_Qty_P5, "VAAN_QtyP_6" = VAAN_Qty_P6, "VAAN_QtyP_7" = VAAN_Qty_P7, "VAAN_QtyP_8" =  VAAN_Qty_P8, "VAAN_QtyP_9" = VAAN_Qty_P9, "VAAN_QtyP_10" = VAAN_Qty_P10, "VAAN_QtyP_11" = VAAN_Qty_P11, "VAAN_QtyP_12" = VAAN_Qty_P12, "VAAN_QtyP_13" = VAAN_Qty_P13, "VAAN_QtyP_14" = VAAN_Qty_P14, "VAAN_QtyP_15" = VAAN_Qty_P15, "VAAN_QtyP_16" = VAAN_Qty_P16)
VAAN_Qty_P <- as.data.frame(aictab(cand.set = Cand_models_VAAN_Qty_P))
# Split string
VAAN_Qty_P_sep <- separate(VAAN_Qty_P, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_Qty_P_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_Qty_P)))
# Merge AICc and R2 tables together
VAAN_Qty_P_results <- merge(VAAN_Qty_P_sep, VAAN_Qty_P_R2, by.x="ModNumber", by.y = "rowname")












# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Stoichiometric Ratio Models ####
# Fit models of C:N, or C:P, and N:P as a function of landscape covariates for each species
#### ABBA C:N Models #### 
ABBA_CN1 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_CN2 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_CN3 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_CN4 <- glm(CNRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_CN5 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_CN6 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_CN7 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_CN8 <- glm(CNRatio ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_CN9 <- glm(CNRatio ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_CN10 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_CN11 <- glm(CNRatio ~ LandCover + EVI, data = ABBA)
ABBA_CN12 <- glm(CNRatio ~ LandCover, data = ABBA)
ABBA_CN13 <- glm(CNRatio ~ EVI, data = ABBA)
ABBA_CN14 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_CN15 <- glm(CNRatio ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_CN16 <- glm(CNRatio ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_CN <- list("ABBA_CN_1" = ABBA_CN1, "ABBA_CN_2" = ABBA_CN2, "ABBA_CN_3" = ABBA_CN3, "ABBA_CN_4" = ABBA_CN4, "ABBA_CN_5" = ABBA_CN5, "ABBA_CN_6" = ABBA_CN6, "ABBA_CN_7" = ABBA_CN7, "ABBA_CN_8" =  ABBA_CN8, "ABBA_CN_9" = ABBA_CN9, "ABBA_CN_10" = ABBA_CN10, "ABBA_CN_11" = ABBA_CN11, "ABBA_CN_12" = ABBA_CN12, "ABBA_CN_13" = ABBA_CN13, "ABBA_CN_14" = ABBA_CN14, "ABBA_CN_15" = ABBA_CN15, "ABBA_CN_16" = ABBA_CN16)
ABBA_CN <- as.data.frame(aictab(cand.set = Cand_models_ABBA_CN))
# Split string
ABBA_CN_sep <- separate(ABBA_CN, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_CN_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_CN)))
# Merge AICc and R2 tables together
ABBA_CN_results <- merge(ABBA_CN_sep, ABBA_CN_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ABBA C:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_CP1 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_CP2 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_CP3 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_CP4 <- glm(CPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_CP5 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_CP6 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_CP7 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_CP8 <- glm(CPRatio ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_CP9 <- glm(CPRatio ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_CP10 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_CP11 <- glm(CPRatio ~ LandCover + EVI, data = ABBA)
ABBA_CP12 <- glm(CPRatio ~ LandCover, data = ABBA)
ABBA_CP13 <- glm(CPRatio ~ EVI, data = ABBA)
ABBA_CP14 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_CP15 <- glm(CPRatio ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_CP16 <- glm(CPRatio ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_CP <- list("ABBA_CP_1" = ABBA_CP1, "ABBA_CP_2" = ABBA_CP2, "ABBA_CP_3" = ABBA_CP3, "ABBA_CP_4" = ABBA_CP4, "ABBA_CP_5" = ABBA_CP5, "ABBA_CP_6" = ABBA_CP6, "ABBA_CP_7" = ABBA_CP7, "ABBA_CP_8" =  ABBA_CP8, "ABBA_CP_9" = ABBA_CP9, "ABBA_CP_10" = ABBA_CP10, "ABBA_CP_11" = ABBA_CP11, "ABBA_CP_12" = ABBA_CP12, "ABBA_CP_13" = ABBA_CP13, "ABBA_CP_14" = ABBA_CP14, "ABBA_CP_15" = ABBA_CP15, "ABBA_CP_16" = ABBA_CP16)
ABBA_CP <- as.data.frame(aictab(cand.set = Cand_models_ABBA_CP))
# Split string
ABBA_CP_sep <- separate(ABBA_CP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_CP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_CP)))
# Merge AICc and R2 tables together
ABBA_CP_results <- merge(ABBA_CP_sep, ABBA_CP_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ABBA N:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_NP1 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_NP2 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_NP3 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_NP4 <- glm(NPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_NP5 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_NP6 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_NP7 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_NP8 <- glm(NPRatio ~ LandCover + Aspect + Slope + Elevation, data = ABBA)
ABBA_NP9 <- glm(NPRatio ~ EVI + Aspect + Slope + Elevation, data = ABBA)
ABBA_NP10 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ABBA)
ABBA_NP11 <- glm(NPRatio ~ LandCover + EVI, data = ABBA)
ABBA_NP12 <- glm(NPRatio ~ LandCover, data = ABBA)
ABBA_NP13 <- glm(NPRatio ~ EVI, data = ABBA)
ABBA_NP14 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns, data = ABBA)
ABBA_NP15 <- glm(NPRatio ~ Aspect + Slope + Elevation, data = ABBA)
ABBA_NP16 <- glm(NPRatio ~ 1, data =  ABBA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ABBA_NP <- list("ABBA_NP_1" = ABBA_NP1, "ABBA_NP_2" = ABBA_NP2, "ABBA_NP_3" = ABBA_NP3, "ABBA_NP_4" = ABBA_NP4, "ABBA_NP_5" = ABBA_NP5, "ABBA_NP_6" = ABBA_NP6, "ABBA_NP_7" = ABBA_NP7, "ABBA_NP_8" =  ABBA_NP8, "ABBA_NP_9" = ABBA_NP9, "ABBA_NP_10" = ABBA_NP10, "ABBA_NP_11" = ABBA_NP11, "ABBA_NP_12" = ABBA_NP12, "ABBA_NP_13" = ABBA_NP13, "ABBA_NP_14" = ABBA_NP14, "ABBA_NP_15" = ABBA_NP15, "ABBA_NP_16" = ABBA_NP16)
ABBA_NP <- as.data.frame(aictab(cand.set = Cand_models_ABBA_NP))
# Split string
ABBA_NP_sep <- separate(ABBA_NP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_NP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_NP)))
# Merge AICc and R2 tables together
ABBA_NP_results <- merge(ABBA_NP_sep, ABBA_NP_R2, by.x="ModNumber", by.y = "rowname")


# Extract summary for models above null
summary(ABBA_NP15)
summary(ABBA_NP9)
tab_model(ABBA_NP9)



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU C:N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_CN1 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_CN2 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_CN3 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_CN4 <- glm(CNRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_CN5 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_CN6 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_CN7 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_CN8 <- glm(CNRatio ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_CN9 <- glm(CNRatio ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_CN10 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_CN11 <- glm(CNRatio ~ LandCover + EVI, data = ACRU)
ACRU_CN12 <- glm(CNRatio ~ LandCover, data = ACRU)
ACRU_CN13 <- glm(CNRatio ~ EVI, data = ACRU)
ACRU_CN14 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_CN15 <- glm(CNRatio ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_CN16 <- glm(CNRatio ~ 1, data =  ACRU)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_CN <- list("ACRU_CN_1" = ACRU_CN1, "ACRU_CN_2" = ACRU_CN2, "ACRU_CN_3" = ACRU_CN3, "ACRU_CN_4" = ACRU_CN4, "ACRU_CN_5" = ACRU_CN5, "ACRU_CN_6" = ACRU_CN6, "ACRU_CN_7" = ACRU_CN7, "ACRU_CN_8" =  ACRU_CN8, "ACRU_CN_9" = ACRU_CN9, "ACRU_CN_10" = ACRU_CN10, "ACRU_CN_11" = ACRU_CN11, "ACRU_CN_12" = ACRU_CN12, "ACRU_CN_13" = ACRU_CN13, "ACRU_CN_14" = ACRU_CN14, "ACRU_CN_15" = ACRU_CN15, "ACRU_CN_16" = ACRU_CN16)
ACRU_CN <- as.data.frame(aictab(cand.set = Cand_models_ACRU_CN))
# Split string
ACRU_CN_sep <- separate(ACRU_CN, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_CN_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_CN)))
# Merge AICc and R2 tables together
ACRU_CN_results <- merge(ACRU_CN_sep, ACRU_CN_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU C:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_CP1 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_CP2 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_CP3 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_CP4 <- glm(CPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_CP5 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_CP6 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_CP7 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_CP8 <- glm(CPRatio ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_CP9 <- glm(CPRatio ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_CP10 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_CP11 <- glm(CPRatio ~ LandCover + EVI, data = ACRU)
ACRU_CP12 <- glm(CPRatio ~ LandCover, data = ACRU)
ACRU_CP13 <- glm(CPRatio ~ EVI, data = ACRU)
ACRU_CP14 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_CP15 <- glm(CPRatio ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_CP16 <- glm(CPRatio ~ 1, data =  ACRU)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_CP <- list("ACRU_CP_1" = ACRU_CP1, "ACRU_CP_2" = ACRU_CP2, "ACRU_CP_3" = ACRU_CP3, "ACRU_CP_4" = ACRU_CP4, "ACRU_CP_5" = ACRU_CP5, "ACRU_CP_6" = ACRU_CP6, "ACRU_CP_7" = ACRU_CP7, "ACRU_CP_8" =  ACRU_CP8, "ACRU_CP_9" = ACRU_CP9, "ACRU_CP_10" = ACRU_CP10, "ACRU_CP_11" = ACRU_CP11, "ACRU_CP_12" = ACRU_CP12, "ACRU_CP_13" = ACRU_CP13, "ACRU_CP_14" = ACRU_CP14, "ACRU_CP_15" = ACRU_CP15, "ACRU_CP_16" = ACRU_CP16)
ACRU_CP <- as.data.frame(aictab(cand.set = Cand_models_ACRU_CP))
# Split string
ACRU_CP_sep <- separate(ACRU_CP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_CP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_CP)))
# Merge AICc and R2 tables together
ACRU_CP_results <- merge(ACRU_CP_sep, ACRU_CP_R2, by.x="ModNumber", by.y = "rowname")


# Extract model summary above null
summary(ACRU_CP15)





# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### ACRU N:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ACRU_NP1 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_NP2 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_NP3 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_NP4 <- glm(NPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_NP5 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_NP6 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_NP7 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_NP8 <- glm(NPRatio ~ LandCover + Aspect + Slope + Elevation, data = ACRU)
ACRU_NP9 <- glm(NPRatio ~ EVI + Aspect + Slope + Elevation, data = ACRU)
ACRU_NP10 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = ACRU)
ACRU_NP11 <- glm(NPRatio ~ LandCover + EVI, data = ACRU)
ACRU_NP12 <- glm(NPRatio ~ LandCover, data = ACRU)
ACRU_NP13 <- glm(NPRatio ~ EVI, data = ACRU)
ACRU_NP14 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns, data = ACRU)
ACRU_NP15 <- glm(NPRatio ~ Aspect + Slope + Elevation, data = ACRU)
ACRU_NP16 <- glm(NPRatio ~ 1, data =  ACRU)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_ACRU_NP <- list("ACRU_NP_1" = ACRU_NP1, "ACRU_NP_2" = ACRU_NP2, "ACRU_NP_3" = ACRU_NP3, "ACRU_NP_4" = ACRU_NP4, "ACRU_NP_5" = ACRU_NP5, "ACRU_NP_6" = ACRU_NP6, "ACRU_NP_7" = ACRU_NP7, "ACRU_NP_8" =  ACRU_NP8, "ACRU_NP_9" = ACRU_NP9, "ACRU_NP_10" = ACRU_NP10, "ACRU_NP_11" = ACRU_NP11, "ACRU_NP_12" = ACRU_NP12, "ACRU_NP_13" = ACRU_NP13, "ACRU_NP_14" = ACRU_NP14, "ACRU_NP_15" = ACRU_NP15, "ACRU_NP_16" = ACRU_NP16)
ACRU_NP <- as.data.frame(aictab(cand.set = Cand_models_ACRU_NP))
# Split string
ACRU_NP_sep <- separate(ACRU_NP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ACRU_NP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ACRU_NP)))
# Merge AICc and R2 tables together
ACRU_NP_results <- merge(ACRU_NP_sep, ACRU_NP_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA C:N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_CN1 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_CN2 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_CN3 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_CN4 <- glm(CNRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_CN5 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_CN6 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_CN7 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_CN8 <- glm(CNRatio ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_CN9 <- glm(CNRatio ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_CN10 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_CN11 <- glm(CNRatio ~ LandCover + EVI, data = BEPA)
BEPA_CN12 <- glm(CNRatio ~ LandCover, data = BEPA)
BEPA_CN13 <- glm(CNRatio ~ EVI, data = BEPA)
BEPA_CN14 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_CN15 <- glm(CNRatio ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_CN16 <- glm(CNRatio ~ 1, data =  BEPA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_CN <- list("BEPA_CN_1" = BEPA_CN1, "BEPA_CN_2" = BEPA_CN2, "BEPA_CN_3" = BEPA_CN3, "BEPA_CN_4" = BEPA_CN4, "BEPA_CN_5" = BEPA_CN5, "BEPA_CN_6" = BEPA_CN6, "BEPA_CN_7" = BEPA_CN7, "BEPA_CN_8" =  BEPA_CN8, "BEPA_CN_9" = BEPA_CN9, "BEPA_CN_10" = BEPA_CN10, "BEPA_CN_11" = BEPA_CN11, "BEPA_CN_12" = BEPA_CN12, "BEPA_CN_13" = BEPA_CN13, "BEPA_CN_14" = BEPA_CN14, "BEPA_CN_15" = BEPA_CN15, "BEPA_CN_16" = BEPA_CN16)
BEPA_CN <- as.data.frame(aictab(cand.set = Cand_models_BEPA_CN))
# Split string
BEPA_CN_sep <- separate(BEPA_CN, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_CN_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_CN)))
# Merge AICc and R2 tables together
BEPA_CN_results <- merge(BEPA_CN_sep, BEPA_CN_R2, by.x="ModNumber", by.y = "rowname")










# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA C:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_CP1 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_CP2 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_CP3 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_CP4 <- glm(CPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_CP5 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_CP6 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_CP7 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_CP8 <- glm(CPRatio ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_CP9 <- glm(CPRatio ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_CP10 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_CP11 <- glm(CPRatio ~ LandCover + EVI, data = BEPA)
BEPA_CP12 <- glm(CPRatio ~ LandCover, data = BEPA)
BEPA_CP13 <- glm(CPRatio ~ EVI, data = BEPA)
BEPA_CP14 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_CP15 <- glm(CPRatio ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_CP16 <- glm(CPRatio ~ 1, data =  BEPA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_CP <- list("BEPA_CP_1" = BEPA_CP1, "BEPA_CP_2" = BEPA_CP2, "BEPA_CP_3" = BEPA_CP3, "BEPA_CP_4" = BEPA_CP4, "BEPA_CP_5" = BEPA_CP5, "BEPA_CP_6" = BEPA_CP6, "BEPA_CP_7" = BEPA_CP7, "BEPA_CP_8" =  BEPA_CP8, "BEPA_CP_9" = BEPA_CP9, "BEPA_CP_10" = BEPA_CP10, "BEPA_CP_11" = BEPA_CP11, "BEPA_CP_12" = BEPA_CP12, "BEPA_CP_13" = BEPA_CP13, "BEPA_CP_14" = BEPA_CP14, "BEPA_CP_15" = BEPA_CP15, "BEPA_CP_16" = BEPA_CP16)
BEPA_CP <- as.data.frame(aictab(cand.set = Cand_models_BEPA_CP))
# Split string
BEPA_CP_sep <- separate(BEPA_CP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_CP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_CP)))
# Merge AICc and R2 tables together
BEPA_CP_results <- merge(BEPA_CP_sep, BEPA_CP_R2, by.x="ModNumber", by.y = "rowname")









# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### BEPA N:P Models  #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
BEPA_NP1 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_NP2 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_NP3 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_NP4 <- glm(NPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_NP5 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_NP6 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_NP7 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_NP8 <- glm(NPRatio ~ LandCover + Aspect + Slope + Elevation, data = BEPA)
BEPA_NP9 <- glm(NPRatio ~ EVI + Aspect + Slope + Elevation, data = BEPA)
BEPA_NP10 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = BEPA)
BEPA_NP11 <- glm(NPRatio ~ LandCover + EVI, data = BEPA)
BEPA_NP12 <- glm(NPRatio ~ LandCover, data = BEPA)
BEPA_NP13 <- glm(NPRatio ~ EVI, data = BEPA)
BEPA_NP14 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns, data = BEPA)
BEPA_NP15 <- glm(NPRatio ~ Aspect + Slope + Elevation, data = BEPA)
BEPA_NP16 <- glm(NPRatio ~ 1, data =  BEPA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_BEPA_NP <- list("BEPA_NP_1" = BEPA_NP1, "BEPA_NP_2" = BEPA_NP2, "BEPA_NP_3" = BEPA_NP3, "BEPA_NP_4" = BEPA_NP4, "BEPA_NP_5" = BEPA_NP5, "BEPA_NP_6" = BEPA_NP6, "BEPA_NP_7" = BEPA_NP7, "BEPA_NP_8" =  BEPA_NP8, "BEPA_NP_9" = BEPA_NP9, "BEPA_NP_10" = BEPA_NP10, "BEPA_NP_11" = BEPA_NP11, "BEPA_NP_12" = BEPA_NP12, "BEPA_NP_13" = BEPA_NP13, "BEPA_NP_14" = BEPA_NP14, "BEPA_NP_15" = BEPA_NP15, "BEPA_NP_16" = BEPA_NP16)
BEPA_NP <- as.data.frame(aictab(cand.set = Cand_models_BEPA_NP))
# Split string
BEPA_NP_sep <- separate(BEPA_NP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
BEPA_NP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_BEPA_NP)))
# Merge AICc and R2 tables together
BEPA_NP_results <- merge(BEPA_NP_sep, BEPA_NP_R2, by.x="ModNumber", by.y = "rowname")










# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA C:N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_CN1 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_CN2 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_CN3 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_CN4 <- glm(CNRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_CN5 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_CN6 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_CN7 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_CN8 <- glm(CNRatio ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_CN9 <- glm(CNRatio ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_CN10 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_CN11 <- glm(CNRatio ~ LandCover + EVI, data = PIMA)
PIMA_CN12 <- glm(CNRatio ~ LandCover, data = PIMA)
PIMA_CN13 <- glm(CNRatio ~ EVI, data = PIMA)
PIMA_CN14 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_CN15 <- glm(CNRatio ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_CN16 <- glm(CNRatio ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_CN <- list("PIMA_CN_1" = PIMA_CN1, "PIMA_CN_2" = PIMA_CN2, "PIMA_CN_3" = PIMA_CN3, "PIMA_CN_4" = PIMA_CN4, "PIMA_CN_5" = PIMA_CN5, "PIMA_CN_6" = PIMA_CN6, "PIMA_CN_7" = PIMA_CN7, "PIMA_CN_8" =  PIMA_CN8, "PIMA_CN_9" = PIMA_CN9, "PIMA_CN_10" = PIMA_CN10, "PIMA_CN_11" = PIMA_CN11, "PIMA_CN_12" = PIMA_CN12, "PIMA_CN_13" = PIMA_CN13, "PIMA_CN_14" = PIMA_CN14, "PIMA_CN_15" = PIMA_CN15, "PIMA_CN_16" = PIMA_CN16)
PIMA_CN <- as.data.frame(aictab(cand.set = Cand_models_PIMA_CN))
# Split string
PIMA_CN_sep <- separate(PIMA_CN, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_CN_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_CN)))
# Merge AICc and R2 tables together
PIMA_CN_results <- merge(PIMA_CN_sep, PIMA_CN_R2, by.x="ModNumber", by.y = "rowname")






# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA C:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_CP1 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_CP2 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_CP3 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_CP4 <- glm(CPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_CP5 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_CP6 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_CP7 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_CP8 <- glm(CPRatio ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_CP9 <- glm(CPRatio ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_CP10 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_CP11 <- glm(CPRatio ~ LandCover + EVI, data = PIMA)
PIMA_CP12 <- glm(CPRatio ~ LandCover, data = PIMA)
PIMA_CP13 <- glm(CPRatio ~ EVI, data = PIMA)
PIMA_CP14 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_CP15 <- glm(CPRatio ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_CP16 <- glm(CPRatio ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_CP <- list("PIMA_CP_1" = PIMA_CP1, "PIMA_CP_2" = PIMA_CP2, "PIMA_CP_3" = PIMA_CP3, "PIMA_CP_4" = PIMA_CP4, "PIMA_CP_5" = PIMA_CP5, "PIMA_CP_6" = PIMA_CP6, "PIMA_CP_7" = PIMA_CP7, "PIMA_CP_8" =  PIMA_CP8, "PIMA_CP_9" = PIMA_CP9, "PIMA_CP_10" = PIMA_CP10, "PIMA_CP_11" = PIMA_CP11, "PIMA_CP_12" = PIMA_CP12, "PIMA_CP_13" = PIMA_CP13, "PIMA_CP_14" = PIMA_CP14, "PIMA_CP_15" = PIMA_CP15, "PIMA_CP_16" = PIMA_CP16)
PIMA_CP <- as.data.frame(aictab(cand.set = Cand_models_PIMA_CP))
# Split string
PIMA_CP_sep <- separate(PIMA_CP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_CP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_CP)))
# Merge AICc and R2 tables together
PIMA_CP_results <- merge(PIMA_CP_sep, PIMA_CP_R2, by.x="ModNumber", by.y = "rowname")













# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### PIMA N:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_NP1 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_NP2 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_NP3 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_NP4 <- glm(NPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_NP5 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_NP6 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_NP7 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_NP8 <- glm(NPRatio ~ LandCover + Aspect + Slope + Elevation, data = PIMA)
PIMA_NP9 <- glm(NPRatio ~ EVI + Aspect + Slope + Elevation, data = PIMA)
PIMA_NP10 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = PIMA)
PIMA_NP11 <- glm(NPRatio ~ LandCover + EVI, data = PIMA)
PIMA_NP12 <- glm(NPRatio ~ LandCover, data = PIMA)
PIMA_NP13 <- glm(NPRatio ~ EVI, data = PIMA)
PIMA_NP14 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns, data = PIMA)
PIMA_NP15 <- glm(NPRatio ~ Aspect + Slope + Elevation, data = PIMA)
PIMA_NP16 <- glm(NPRatio ~ 1, data =  PIMA)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_PIMA_NP <- list("PIMA_NP_1" = PIMA_NP1, "PIMA_NP_2" = PIMA_NP2, "PIMA_NP_3" = PIMA_NP3, "PIMA_NP_4" = PIMA_NP4, "PIMA_NP_5" = PIMA_NP5, "PIMA_NP_6" = PIMA_NP6, "PIMA_NP_7" = PIMA_NP7, "PIMA_NP_8" =  PIMA_NP8, "PIMA_NP_9" = PIMA_NP9, "PIMA_NP_10" = PIMA_NP10, "PIMA_NP_11" = PIMA_NP11, "PIMA_NP_12" = PIMA_NP12, "PIMA_NP_13" = PIMA_NP13, "PIMA_NP_14" = PIMA_NP14, "PIMA_NP_15" = PIMA_NP15, "PIMA_NP_16" = PIMA_NP16)
PIMA_NP <- as.data.frame(aictab(cand.set = Cand_models_PIMA_NP))
# Split string
PIMA_NP_sep <- separate(PIMA_NP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_NP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_NP)))
# Merge AICc and R2 tables together
PIMA_NP_results <- merge(PIMA_NP_sep, PIMA_NP_R2, by.x="ModNumber", by.y = "rowname")











# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN C:N Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_CN1 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_CN2 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_CN3 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_CN4 <- glm(CNRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_CN5 <- glm(CNRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_CN6 <- glm(CNRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_CN7 <- glm(CNRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_CN8 <- glm(CNRatio ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_CN9 <- glm(CNRatio ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_CN10 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_CN11 <- glm(CNRatio ~ LandCover + EVI, data = VAAN)
VAAN_CN12 <- glm(CNRatio ~ LandCover, data = VAAN)
VAAN_CN13 <- glm(CNRatio ~ EVI, data = VAAN)
VAAN_CN14 <- glm(CNRatio ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_CN15 <- glm(CNRatio ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_CN16 <- glm(CNRatio ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_CN <- list("VAAN_CN_1" = VAAN_CN1, "VAAN_CN_2" = VAAN_CN2, "VAAN_CN_3" = VAAN_CN3, "VAAN_CN_4" = VAAN_CN4, "VAAN_CN_5" = VAAN_CN5, "VAAN_CN_6" = VAAN_CN6, "VAAN_CN_7" = VAAN_CN7, "VAAN_CN_8" =  VAAN_CN8, "VAAN_CN_9" = VAAN_CN9, "VAAN_CN_10" = VAAN_CN10, "VAAN_CN_11" = VAAN_CN11, "VAAN_CN_12" = VAAN_CN12, "VAAN_CN_13" = VAAN_CN13, "VAAN_CN_14" = VAAN_CN14, "VAAN_CN_15" = VAAN_CN15, "VAAN_CN_16" = VAAN_CN16)
VAAN_CN <- as.data.frame(aictab(cand.set = Cand_models_VAAN_CN))
# Split string
VAAN_CN_sep <- separate(VAAN_CN, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_CN_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_CN)))
# Merge AICc and R2 tables together
VAAN_CN_results <- merge(VAAN_CN_sep, VAAN_CN_R2, by.x="ModNumber", by.y = "rowname")




# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN C:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_CP1 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_CP2 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_CP3 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_CP4 <- glm(CPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_CP5 <- glm(CPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_CP6 <- glm(CPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_CP7 <- glm(CPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_CP8 <- glm(CPRatio ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_CP9 <- glm(CPRatio ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_CP10 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_CP11 <- glm(CPRatio ~ LandCover + EVI, data = VAAN)
VAAN_CP12 <- glm(CPRatio ~ LandCover, data = VAAN)
VAAN_CP13 <- glm(CPRatio ~ EVI, data = VAAN)
VAAN_CP14 <- glm(CPRatio ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_CP15 <- glm(CPRatio ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_CP16 <- glm(CPRatio ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_CP <- list("VAAN_CP_1" = VAAN_CP1, "VAAN_CP_2" = VAAN_CP2, "VAAN_CP_3" = VAAN_CP3, "VAAN_CP_4" = VAAN_CP4, "VAAN_CP_5" = VAAN_CP5, "VAAN_CP_6" = VAAN_CP6, "VAAN_CP_7" = VAAN_CP7, "VAAN_CP_8" =  VAAN_CP8, "VAAN_CP_9" = VAAN_CP9, "VAAN_CP_10" = VAAN_CP10, "VAAN_CP_11" = VAAN_CP11, "VAAN_CP_12" = VAAN_CP12, "VAAN_CP_13" = VAAN_CP13, "VAAN_CP_14" = VAAN_CP14, "VAAN_CP_15" = VAAN_CP15, "VAAN_CP_16" = VAAN_CP16)
VAAN_CP <- as.data.frame(aictab(cand.set = Cand_models_VAAN_CP))
# Split string
VAAN_CP_sep <- separate(VAAN_CP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_CP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_CP)))
# Merge AICc and R2 tables together
VAAN_CP_results <- merge(VAAN_CP_sep, VAAN_CP_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### VAAN N:P Models #### 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
VAAN_NP1 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_NP2 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_NP3 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_NP4 <- glm(NPRatio ~ LandCover + EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_NP5 <- glm(NPRatio ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_NP6 <- glm(NPRatio ~ LandCover + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_NP7 <- glm(NPRatio ~ EVI + AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_NP8 <- glm(NPRatio ~ LandCover + Aspect + Slope + Elevation, data = VAAN)
VAAN_NP9 <- glm(NPRatio ~ EVI + Aspect + Slope + Elevation, data = VAAN)
VAAN_NP10 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = VAAN)
VAAN_NP11 <- glm(NPRatio ~ LandCover + EVI, data = VAAN)
VAAN_NP12 <- glm(NPRatio ~ LandCover, data = VAAN)
VAAN_NP13 <- glm(NPRatio ~ EVI, data = VAAN)
VAAN_NP14 <- glm(NPRatio ~ AgeClss + HghtCls + CrwnDns, data = VAAN)
VAAN_NP15 <- glm(NPRatio ~ Aspect + Slope + Elevation, data = VAAN)
VAAN_NP16 <- glm(NPRatio ~ 1, data =  VAAN)

# Create an AICc table to show the "best model" to use as a prediction of spatial stoichiometry
Cand_models_VAAN_NP <- list("VAAN_NP_1" = VAAN_NP1, "VAAN_NP_2" = VAAN_NP2, "VAAN_NP_3" = VAAN_NP3, "VAAN_NP_4" = VAAN_NP4, "VAAN_NP_5" = VAAN_NP5, "VAAN_NP_6" = VAAN_NP6, "VAAN_NP_7" = VAAN_NP7, "VAAN_NP_8" =  VAAN_NP8, "VAAN_NP_9" = VAAN_NP9, "VAAN_NP_10" = VAAN_NP10, "VAAN_NP_11" = VAAN_NP11, "VAAN_NP_12" = VAAN_NP12, "VAAN_NP_13" = VAAN_NP13, "VAAN_NP_14" = VAAN_NP14, "VAAN_NP_15" = VAAN_NP15, "VAAN_NP_16" = VAAN_NP16)
VAAN_NP <- as.data.frame(aictab(cand.set = Cand_models_VAAN_NP))
# Split string
VAAN_NP_sep <- separate(VAAN_NP, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
VAAN_NP_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_VAAN_NP)))
# Merge AICc and R2 tables together
VAAN_NP_results <- merge(VAAN_NP_sep, VAAN_NP_R2, by.x="ModNumber", by.y = "rowname")
  
  




# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
###### Phytochemical Models #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
##### ABBA Raw ######
# Load raw phytochemistry data for balsam fir
ABBA.PhytoRaw <- read.csv("Data/Outputs/Phytochemical/ABBA_Phytochemistry.csv")
str(ABBA.PhytoRaw)
ABBA.PhytoRaw$Diversity <- diversity(ABBA.PhytoRaw[4:30], index="shannon")
ABBA.PhytoRaw.sub <- subset(ABBA.PhytoRaw, select = c(PlotName, Total.Terpene, Total.Monoterpene, Total.Monoterpenic.Alcohol, Bornyl.acetate..Monoterpenic.ester., Total.Sesquiterpene, Diversity))

colnames(ABBA.PhytoRaw.sub)[colnames(ABBA.PhytoRaw.sub)=="Total.Terpene"] <- "Terpene"
colnames(ABBA.PhytoRaw.sub)[colnames(ABBA.PhytoRaw.sub)=="Total.Monoterpene"] <- "Monoterpene"
colnames(ABBA.PhytoRaw.sub)[colnames(ABBA.PhytoRaw.sub)=="Total.Monoterpenic.Alcohol"] <- "MonoAlcohol"
colnames(ABBA.PhytoRaw.sub)[colnames(ABBA.PhytoRaw.sub)=="Bornyl.acetate..Monoterpenic.ester."] <- "MonoEster"
colnames(ABBA.PhytoRaw.sub)[colnames(ABBA.PhytoRaw.sub)=="Total.Sesquiterpene"] <- "Sesquiterpene"

bF_Phyto_Raw <- merge(ABBA.PhytoRaw.sub, Covariates, by_x="PlotName", by_y="PlotName", all_x=T)

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Set biotic/land cover fields to factors
bF_Phyto_Raw$AgeClss <- as.factor(bF_Phyto_Raw$AgeClss)
bF_Phyto_Raw$HghtCls <- as.factor(bF_Phyto_Raw$HghtCls)
bF_Phyto_Raw$CrwnDns <- as.factor(bF_Phyto_Raw$CrwnDns)
bF_Phyto_Raw$LandCover <- as.factor(bF_Phyto_Raw$LandCover)

# scale continuous variables
bF_Phyto_Raw$EVI <- c(scale(bF_Phyto_Raw$EVI.ns))
bF_Phyto_Raw$Elevation <- c(scale(bF_Phyto_Raw$Elevation.ns))
bF_Phyto_Raw$Aspect <- c(scale(bF_Phyto_Raw$Aspect.ns))
bF_Phyto_Raw$Slope <- c(scale(bF_Phyto_Raw$Slope.ns))
 
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
##### Terpene Models #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_TerpeneRaw_1 <- glm(Terpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_2 <- glm(Terpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_3 <- glm(Terpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_4 <- glm(Terpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_5 <- glm(Terpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_6 <- glm(Terpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_7 <- glm(Terpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_8 <- glm(Terpene ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_9 <- glm(Terpene ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_10 <- glm(Terpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_11 <- glm(Terpene ~ LandCover + EVI, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_12 <- glm(Terpene ~ LandCover, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_13 <- glm(Terpene ~ EVI, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_14 <- glm(Terpene ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_15 <- glm(Terpene ~ Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_TerpeneRaw_16 <- glm(Terpene ~ 1, data =  bF_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_TerpeneRaw <- list("ABBA_TerpeneRaw_1" = ABBA_TerpeneRaw_1, "ABBA_TerpeneRaw_2" = ABBA_TerpeneRaw_2, "ABBA_TerpeneRaw_3" = ABBA_TerpeneRaw_3, "ABBA_TerpeneRaw_4" = ABBA_TerpeneRaw_4, "ABBA_TerpeneRaw_5" = ABBA_TerpeneRaw_5, "ABBA_TerpeneRaw_6" = ABBA_TerpeneRaw_6, "ABBA_TerpeneRaw_7" = ABBA_TerpeneRaw_7, "ABBA_TerpeneRaw_8" =  ABBA_TerpeneRaw_8, "ABBA_TerpeneRaw_9" = ABBA_TerpeneRaw_9, "ABBA_TerpeneRaw_10" = ABBA_TerpeneRaw_10, "ABBA_TerpeneRaw_11" = ABBA_TerpeneRaw_11, "ABBA_TerpeneRaw_12" = ABBA_TerpeneRaw_12, "ABBA_TerpeneRaw_13" = ABBA_TerpeneRaw_13, "ABBA_TerpeneRaw_14" = ABBA_TerpeneRaw_14, "ABBA_TerpeneRaw_15" = ABBA_TerpeneRaw_15, "ABBA_TerpeneRaw_16" = ABBA_TerpeneRaw_16)
ABBA_TerpeneRaw <- as.data.frame(aictab(cand.set = Cand_models_ABBA_TerpeneRaw))
# Split string
ABBA_TerpeneRaw_sep <- separate(ABBA_TerpeneRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_TerpeneRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_TerpeneRaw)))
# Merge AICc and R2 tables together
ABBA_TerpeneRaw_results <- merge(ABBA_TerpeneRaw_sep, ABBA_TerpeneRaw_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpene Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_MonoterpeneRaw_1 <- glm(Monoterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_2 <- glm(Monoterpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_3 <- glm(Monoterpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_4 <- glm(Monoterpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_5 <- glm(Monoterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_6 <- glm(Monoterpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_7 <- glm(Monoterpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_8 <- glm(Monoterpene ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_9 <- glm(Monoterpene ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_10 <- glm(Monoterpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_11 <- glm(Monoterpene ~ LandCover + EVI, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_12 <- glm(Monoterpene ~ LandCover, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_13 <- glm(Monoterpene ~ EVI, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_14 <- glm(Monoterpene ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_15 <- glm(Monoterpene ~ Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoterpeneRaw_16 <- glm(Monoterpene ~ 1, data =  bF_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_MonoterpeneRaw <- list("ABBA_MonoterpeneRaw_1" = ABBA_MonoterpeneRaw_1, "ABBA_MonoterpeneRaw_2" = ABBA_MonoterpeneRaw_2, "ABBA_MonoterpeneRaw_3" = ABBA_MonoterpeneRaw_3, "ABBA_MonoterpeneRaw_4" = ABBA_MonoterpeneRaw_4, "ABBA_MonoterpeneRaw_5" = ABBA_MonoterpeneRaw_5, "ABBA_MonoterpeneRaw_6" = ABBA_MonoterpeneRaw_6, "ABBA_MonoterpeneRaw_7" = ABBA_MonoterpeneRaw_7, "ABBA_MonoterpeneRaw_8" =  ABBA_MonoterpeneRaw_8, "ABBA_MonoterpeneRaw_9" = ABBA_MonoterpeneRaw_9, "ABBA_MonoterpeneRaw_10" = ABBA_MonoterpeneRaw_10, "ABBA_MonoterpeneRaw_11" = ABBA_MonoterpeneRaw_11, "ABBA_MonoterpeneRaw_12" = ABBA_MonoterpeneRaw_12, "ABBA_MonoterpeneRaw_13" = ABBA_MonoterpeneRaw_13, "ABBA_MonoterpeneRaw_14" = ABBA_MonoterpeneRaw_14, "ABBA_MonoterpeneRaw_15" = ABBA_MonoterpeneRaw_15, "ABBA_MonoterpeneRaw_16" = ABBA_MonoterpeneRaw_16)
ABBA_MonoterpeneRaw <- as.data.frame(aictab(cand.set = Cand_models_ABBA_MonoterpeneRaw))
# Split string
ABBA_MonoterpeneRaw_sep <- separate(ABBA_MonoterpeneRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_MonoterpeneRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_MonoterpeneRaw)))
# Merge AICc and R2 tables together
ABBA_MonoterpeneRaw_results <- merge(ABBA_MonoterpeneRaw_sep, ABBA_MonoterpeneRaw_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpenic Alcohol Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_MonoAlcoholRaw_1 <- glm(MonoAlcohol ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_2 <- glm(MonoAlcohol ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_3 <- glm(MonoAlcohol ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_4 <- glm(MonoAlcohol ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_5 <- glm(MonoAlcohol ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_6 <- glm(MonoAlcohol ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_7 <- glm(MonoAlcohol ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_8 <- glm(MonoAlcohol ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_9 <- glm(MonoAlcohol ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_10 <- glm(MonoAlcohol ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_11 <- glm(MonoAlcohol ~ LandCover + EVI, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_12 <- glm(MonoAlcohol ~ LandCover, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_13 <- glm(MonoAlcohol ~ EVI, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_14 <- glm(MonoAlcohol ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_15 <- glm(MonoAlcohol ~ Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoAlcoholRaw_16 <- glm(MonoAlcohol ~ 1, data =  bF_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_MonoAlcoholRaw <- list("ABBA_MonoAlcoholRaw_1" = ABBA_MonoAlcoholRaw_1, "ABBA_MonoAlcoholRaw_2" = ABBA_MonoAlcoholRaw_2, "ABBA_MonoAlcoholRaw_3" = ABBA_MonoAlcoholRaw_3, "ABBA_MonoAlcoholRaw_4" = ABBA_MonoAlcoholRaw_4, "ABBA_MonoAlcoholRaw_5" = ABBA_MonoAlcoholRaw_5, "ABBA_MonoAlcoholRaw_6" = ABBA_MonoAlcoholRaw_6, "ABBA_MonoAlcoholRaw_7" = ABBA_MonoAlcoholRaw_7, "ABBA_MonoAlcoholRaw_8" =  ABBA_MonoAlcoholRaw_8, "ABBA_MonoAlcoholRaw_9" = ABBA_MonoAlcoholRaw_9, "ABBA_MonoAlcoholRaw_10" = ABBA_MonoAlcoholRaw_10, "ABBA_MonoAlcoholRaw_11" = ABBA_MonoAlcoholRaw_11, "ABBA_MonoAlcoholRaw_12" = ABBA_MonoAlcoholRaw_12, "ABBA_MonoAlcoholRaw_13" = ABBA_MonoAlcoholRaw_13, "ABBA_MonoAlcoholRaw_14" = ABBA_MonoAlcoholRaw_14, "ABBA_MonoAlcoholRaw_15" = ABBA_MonoAlcoholRaw_15, "ABBA_MonoAlcoholRaw_16" = ABBA_MonoAlcoholRaw_16)
ABBA_MonoAlcoholRaw <- as.data.frame(aictab(cand.set = Cand_models_ABBA_MonoAlcoholRaw))
# Split string
ABBA_MonoAlcoholRaw_sep <- separate(ABBA_MonoAlcoholRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_MonoAlcoholRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_MonoAlcoholRaw)))
# Merge AICc and R2 tables together
ABBA_MonoAlcoholRaw_results <- merge(ABBA_MonoAlcoholRaw_sep, ABBA_MonoAlcoholRaw_R2, by.x="ModNumber", by.y = "rowname")

# Extract model summary for models above null
summary(ABBA_MonoAlcoholRaw_12)



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpenic Ester Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_MonoEsterRaw_1 <- glm(MonoEster ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_2 <- glm(MonoEster ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_3 <- glm(MonoEster ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_4 <- glm(MonoEster ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_5 <- glm(MonoEster ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_6 <- glm(MonoEster ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_7 <- glm(MonoEster ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_8 <- glm(MonoEster ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_9 <- glm(MonoEster ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_10 <- glm(MonoEster ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_11 <- glm(MonoEster ~ LandCover + EVI, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_12 <- glm(MonoEster ~ LandCover, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_13 <- glm(MonoEster ~ EVI, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_14 <- glm(MonoEster ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_15 <- glm(MonoEster ~ Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_MonoEsterRaw_16 <- glm(MonoEster ~ 1, data =  bF_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_MonoEsterRaw <- list("ABBA_MonoEsterRaw_1" = ABBA_MonoEsterRaw_1, "ABBA_MonoEsterRaw_2" = ABBA_MonoEsterRaw_2, "ABBA_MonoEsterRaw_3" = ABBA_MonoEsterRaw_3, "ABBA_MonoEsterRaw_4" = ABBA_MonoEsterRaw_4, "ABBA_MonoEsterRaw_5" = ABBA_MonoEsterRaw_5, "ABBA_MonoEsterRaw_6" = ABBA_MonoEsterRaw_6, "ABBA_MonoEsterRaw_7" = ABBA_MonoEsterRaw_7, "ABBA_MonoEsterRaw_8" =  ABBA_MonoEsterRaw_8, "ABBA_MonoEsterRaw_9" = ABBA_MonoEsterRaw_9, "ABBA_MonoEsterRaw_10" = ABBA_MonoEsterRaw_10, "ABBA_MonoEsterRaw_11" = ABBA_MonoEsterRaw_11, "ABBA_MonoEsterRaw_12" = ABBA_MonoEsterRaw_12, "ABBA_MonoEsterRaw_13" = ABBA_MonoEsterRaw_13, "ABBA_MonoEsterRaw_14" = ABBA_MonoEsterRaw_14, "ABBA_MonoEsterRaw_15" = ABBA_MonoEsterRaw_15, "ABBA_MonoEsterRaw_16" = ABBA_MonoEsterRaw_16)
ABBA_MonoEsterRaw <- as.data.frame(aictab(cand.set = Cand_models_ABBA_MonoEsterRaw))
# Split string
ABBA_MonoEsterRaw_sep <- separate(ABBA_MonoEsterRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_MonoEsterRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_MonoEsterRaw)))
# Merge AICc and R2 tables together
ABBA_MonoEsterRaw_results <- merge(ABBA_MonoEsterRaw_sep, ABBA_MonoEsterRaw_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Sesquiterpene Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_SesquiterpeneRaw_1 <- glm(Sesquiterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_2 <- glm(Sesquiterpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_3 <- glm(Sesquiterpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_4 <- glm(Sesquiterpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_5 <- glm(Sesquiterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_6 <- glm(Sesquiterpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_7 <- glm(Sesquiterpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_8 <- glm(Sesquiterpene ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_9 <- glm(Sesquiterpene ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_10 <- glm(Sesquiterpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_11 <- glm(Sesquiterpene ~ LandCover + EVI, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_12 <- glm(Sesquiterpene ~ LandCover, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_13 <- glm(Sesquiterpene ~ EVI, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_14 <- glm(Sesquiterpene ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_15 <- glm(Sesquiterpene ~ Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_SesquiterpeneRaw_16 <- glm(Sesquiterpene ~ 1, data =  bF_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_SesquiterpeneRaw <- list("ABBA_SesquiterpeneRaw_1" = ABBA_SesquiterpeneRaw_1, "ABBA_SesquiterpeneRaw_2" = ABBA_SesquiterpeneRaw_2, "ABBA_SesquiterpeneRaw_3" = ABBA_SesquiterpeneRaw_3, "ABBA_SesquiterpeneRaw_4" = ABBA_SesquiterpeneRaw_4, "ABBA_SesquiterpeneRaw_5" = ABBA_SesquiterpeneRaw_5, "ABBA_SesquiterpeneRaw_6" = ABBA_SesquiterpeneRaw_6, "ABBA_SesquiterpeneRaw_7" = ABBA_SesquiterpeneRaw_7, "ABBA_SesquiterpeneRaw_8" =  ABBA_SesquiterpeneRaw_8, "ABBA_SesquiterpeneRaw_9" = ABBA_SesquiterpeneRaw_9, "ABBA_SesquiterpeneRaw_10" = ABBA_SesquiterpeneRaw_10, "ABBA_SesquiterpeneRaw_11" = ABBA_SesquiterpeneRaw_11, "ABBA_SesquiterpeneRaw_12" = ABBA_SesquiterpeneRaw_12, "ABBA_SesquiterpeneRaw_13" = ABBA_SesquiterpeneRaw_13, "ABBA_SesquiterpeneRaw_14" = ABBA_SesquiterpeneRaw_14, "ABBA_SesquiterpeneRaw_15" = ABBA_SesquiterpeneRaw_15, "ABBA_SesquiterpeneRaw_16" = ABBA_SesquiterpeneRaw_16)
ABBA_SesquiterpeneRaw <- as.data.frame(aictab(cand.set = Cand_models_ABBA_SesquiterpeneRaw))
# Split string
ABBA_SesquiterpeneRaw_sep <- separate(ABBA_SesquiterpeneRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_SesquiterpeneRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_SesquiterpeneRaw)))
# Merge AICc and R2 tables together
ABBA_SesquiterpeneRaw_results <- merge(ABBA_SesquiterpeneRaw_sep, ABBA_SesquiterpeneRaw_R2, by.x="ModNumber", by.y = "rowname")






# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Diversity Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_DiversityRaw_1 <- glm(Diversity ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_DiversityRaw_2 <- glm(Diversity ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_DiversityRaw_3 <- glm(Diversity ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_DiversityRaw_4 <- glm(Diversity ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_DiversityRaw_5 <- glm(Diversity ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_DiversityRaw_6 <- glm(Diversity ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_DiversityRaw_7 <- glm(Diversity ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_DiversityRaw_8 <- glm(Diversity ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_DiversityRaw_9 <- glm(Diversity ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_DiversityRaw_10 <- glm(Diversity ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_DiversityRaw_11 <- glm(Diversity ~ LandCover + EVI, data = bF_Phyto_Raw)
ABBA_DiversityRaw_12 <- glm(Diversity ~ LandCover, data = bF_Phyto_Raw)
ABBA_DiversityRaw_13 <- glm(Diversity ~ EVI, data = bF_Phyto_Raw)
ABBA_DiversityRaw_14 <- glm(Diversity ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_Raw)
ABBA_DiversityRaw_15 <- glm(Diversity ~ Aspect + Slope + Elevation, data = bF_Phyto_Raw)
ABBA_DiversityRaw_16 <- glm(Diversity ~ 1, data =  bF_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_DiversityRaw <- list("ABBA_DiversityRaw_1" = ABBA_DiversityRaw_1, "ABBA_DiversityRaw_2" = ABBA_DiversityRaw_2, "ABBA_DiversityRaw_3" = ABBA_DiversityRaw_3, "ABBA_DiversityRaw_4" = ABBA_DiversityRaw_4, "ABBA_DiversityRaw_5" = ABBA_DiversityRaw_5, "ABBA_DiversityRaw_6" = ABBA_DiversityRaw_6, "ABBA_DiversityRaw_7" = ABBA_DiversityRaw_7, "ABBA_DiversityRaw_8" =  ABBA_DiversityRaw_8, "ABBA_DiversityRaw_9" = ABBA_DiversityRaw_9, "ABBA_DiversityRaw_10" = ABBA_DiversityRaw_10, "ABBA_DiversityRaw_11" = ABBA_DiversityRaw_11, "ABBA_DiversityRaw_12" = ABBA_DiversityRaw_12, "ABBA_DiversityRaw_13" = ABBA_DiversityRaw_13, "ABBA_DiversityRaw_14" = ABBA_DiversityRaw_14, "ABBA_DiversityRaw_15" = ABBA_DiversityRaw_15, "ABBA_DiversityRaw_16" = ABBA_DiversityRaw_16)
ABBA_DiversityRaw <- as.data.frame(aictab(cand.set = Cand_models_ABBA_DiversityRaw))
# Split string
ABBA_DiversityRaw_sep <- separate(ABBA_DiversityRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_DiversityRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_DiversityRaw)))
# Merge AICc and R2 tables together
ABBA_DiversityRaw_results <- merge(ABBA_DiversityRaw_sep, ABBA_DiversityRaw_R2, by.x="ModNumber", by.y = "rowname")


# Extract summary for models above null
summary(ABBA_DiversityRaw_15)





##### ABBA Biomass ######

# Load biomass phytochemistry data for balsam fir
ABBA.PhytoBM <- read.csv("Data/Outputs/Phytochemical/ABBA_BiomassBasis_Phytochemistry.csv")
str(ABBA.PhytoBM)
ABBA.PhytoBM$Diversity <- diversity(ABBA.PhytoBM[4:30], index="shannon")

ABBA.PhytoBM.sub <- subset(ABBA.PhytoBM, select = c(PlotName, Total.Terpene, Total.Monoterpene, Total.Monoterpenic.Alcohol, Bornyl.acetate..Monoterpenic.ester., Total.Sesquiterpene, Diversity))
colnames(ABBA.PhytoBM.sub)[colnames(ABBA.PhytoBM.sub)=="Total.Terpene"] <- "Terpene"
colnames(ABBA.PhytoBM.sub)[colnames(ABBA.PhytoBM.sub)=="Total.Monoterpene"] <- "Monoterpene"
colnames(ABBA.PhytoBM.sub)[colnames(ABBA.PhytoBM.sub)=="Total.Monoterpenic.Alcohol"] <- "MonoAlcohol"
colnames(ABBA.PhytoBM.sub)[colnames(ABBA.PhytoBM.sub)=="Bornyl.acetate..Monoterpenic.ester."] <- "MonoEster"
colnames(ABBA.PhytoBM.sub)[colnames(ABBA.PhytoBM.sub)=="Total.Sesquiterpene"] <- "Sesquiterpene"

# Join ABBA phytochemistry to the landscape covariates
bF_Phyto_BM <- merge(ABBA.PhytoBM.sub, Covariates, by.x="PlotName", by.y="PlotName", all.x=T)
str(bF_Phyto_BM)


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Set biotic/land cover fields to factors
bF_Phyto_BM$AgeClss <- as.factor(bF_Phyto_BM$AgeClss)
bF_Phyto_BM$HghtCls <- as.factor(bF_Phyto_BM$HghtCls)
bF_Phyto_BM$CrwnDns <- as.factor(bF_Phyto_BM$CrwnDns)
bF_Phyto_BM$LandCover <- as.factor(bF_Phyto_BM$LandCover)

# scale continuous variables
bF_Phyto_BM$EVI <- c(scale(bF_Phyto_BM$EVI.ns))
bF_Phyto_BM$Elevation <- c(scale(bF_Phyto_BM$Elevation.ns))
bF_Phyto_BM$Aspect <- c(scale(bF_Phyto_BM$Aspect.ns))
bF_Phyto_BM$Slope <- c(scale(bF_Phyto_BM$Slope.ns))



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
##### Terpene Models #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_TerpeneBM_1 <- glm(Terpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_TerpeneBM_2 <- glm(Terpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_TerpeneBM_3 <- glm(Terpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_TerpeneBM_4 <- glm(Terpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_TerpeneBM_5 <- glm(Terpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_TerpeneBM_6 <- glm(Terpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_TerpeneBM_7 <- glm(Terpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_TerpeneBM_8 <- glm(Terpene ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_TerpeneBM_9 <- glm(Terpene ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_TerpeneBM_10 <- glm(Terpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_TerpeneBM_11 <- glm(Terpene ~ LandCover + EVI, data = bF_Phyto_BM)
ABBA_TerpeneBM_12 <- glm(Terpene ~ LandCover, data = bF_Phyto_BM)
ABBA_TerpeneBM_13 <- glm(Terpene ~ EVI, data = bF_Phyto_BM)
ABBA_TerpeneBM_14 <- glm(Terpene ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_TerpeneBM_15 <- glm(Terpene ~ Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_TerpeneBM_16 <- glm(Terpene ~ 1, data =  bF_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_TerpeneBM <- list("ABBA_TerpeneBM_1" = ABBA_TerpeneBM_1, "ABBA_TerpeneBM_2" = ABBA_TerpeneBM_2, "ABBA_TerpeneBM_3" = ABBA_TerpeneBM_3, "ABBA_TerpeneBM_4" = ABBA_TerpeneBM_4, "ABBA_TerpeneBM_5" = ABBA_TerpeneBM_5, "ABBA_TerpeneBM_6" = ABBA_TerpeneBM_6, "ABBA_TerpeneBM_7" = ABBA_TerpeneBM_7, "ABBA_TerpeneBM_8" =  ABBA_TerpeneBM_8, "ABBA_TerpeneBM_9" = ABBA_TerpeneBM_9, "ABBA_TerpeneBM_10" = ABBA_TerpeneBM_10, "ABBA_TerpeneBM_11" = ABBA_TerpeneBM_11, "ABBA_TerpeneBM_12" = ABBA_TerpeneBM_12, "ABBA_TerpeneBM_13" = ABBA_TerpeneBM_13, "ABBA_TerpeneBM_14" = ABBA_TerpeneBM_14, "ABBA_TerpeneBM_15" = ABBA_TerpeneBM_15, "ABBA_TerpeneBM_16" = ABBA_TerpeneBM_16)
ABBA_TerpeneBM <- as.data.frame(aictab(cand.set = Cand_models_ABBA_TerpeneBM))
# Split string
ABBA_TerpeneBM_sep <- separate(ABBA_TerpeneBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_TerpeneBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_TerpeneBM)))
# Merge AICc and R2 tables together
ABBA_TerpeneBM_results <- merge(ABBA_TerpeneBM_sep, ABBA_TerpeneBM_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpene Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_MonoterpeneBM_1 <- glm(Monoterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_2 <- glm(Monoterpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_3 <- glm(Monoterpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_4 <- glm(Monoterpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_5 <- glm(Monoterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_6 <- glm(Monoterpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_7 <- glm(Monoterpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_8 <- glm(Monoterpene ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_9 <- glm(Monoterpene ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_10 <- glm(Monoterpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_11 <- glm(Monoterpene ~ LandCover + EVI, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_12 <- glm(Monoterpene ~ LandCover, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_13 <- glm(Monoterpene ~ EVI, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_14 <- glm(Monoterpene ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_15 <- glm(Monoterpene ~ Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoterpeneBM_16 <- glm(Monoterpene ~ 1, data =  bF_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_MonoterpeneBM <- list("ABBA_MonoterpeneBM_1" = ABBA_MonoterpeneBM_1, "ABBA_MonoterpeneBM_2" = ABBA_MonoterpeneBM_2, "ABBA_MonoterpeneBM_3" = ABBA_MonoterpeneBM_3, "ABBA_MonoterpeneBM_4" = ABBA_MonoterpeneBM_4, "ABBA_MonoterpeneBM_5" = ABBA_MonoterpeneBM_5, "ABBA_MonoterpeneBM_6" = ABBA_MonoterpeneBM_6, "ABBA_MonoterpeneBM_7" = ABBA_MonoterpeneBM_7, "ABBA_MonoterpeneBM_8" =  ABBA_MonoterpeneBM_8, "ABBA_MonoterpeneBM_9" = ABBA_MonoterpeneBM_9, "ABBA_MonoterpeneBM_10" = ABBA_MonoterpeneBM_10, "ABBA_MonoterpeneBM_11" = ABBA_MonoterpeneBM_11, "ABBA_MonoterpeneBM_12" = ABBA_MonoterpeneBM_12, "ABBA_MonoterpeneBM_13" = ABBA_MonoterpeneBM_13, "ABBA_MonoterpeneBM_14" = ABBA_MonoterpeneBM_14, "ABBA_MonoterpeneBM_15" = ABBA_MonoterpeneBM_15, "ABBA_MonoterpeneBM_16" = ABBA_MonoterpeneBM_16)
ABBA_MonoterpeneBM <- as.data.frame(aictab(cand.set = Cand_models_ABBA_MonoterpeneBM))
# Split string
ABBA_MonoterpeneBM_sep <- separate(ABBA_MonoterpeneBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_MonoterpeneBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_MonoterpeneBM)))
# Merge AICc and R2 tables together
ABBA_MonoterpeneBM_results <- merge(ABBA_MonoterpeneBM_sep, ABBA_MonoterpeneBM_R2, by.x="ModNumber", by.y = "rowname")










# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpenic Alcohol Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_MonoAlcoholBM_1 <- glm(MonoAlcohol ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_2 <- glm(MonoAlcohol ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_3 <- glm(MonoAlcohol ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_4 <- glm(MonoAlcohol ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_5 <- glm(MonoAlcohol ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_6 <- glm(MonoAlcohol ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_7 <- glm(MonoAlcohol ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_8 <- glm(MonoAlcohol ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_9 <- glm(MonoAlcohol ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_10 <- glm(MonoAlcohol ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_11 <- glm(MonoAlcohol ~ LandCover + EVI, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_12 <- glm(MonoAlcohol ~ LandCover, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_13 <- glm(MonoAlcohol ~ EVI, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_14 <- glm(MonoAlcohol ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_15 <- glm(MonoAlcohol ~ Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoAlcoholBM_16 <- glm(MonoAlcohol ~ 1, data =  bF_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_MonoAlcoholBM <- list("ABBA_MonoAlcoholBM_1" = ABBA_MonoAlcoholBM_1, "ABBA_MonoAlcoholBM_2" = ABBA_MonoAlcoholBM_2, "ABBA_MonoAlcoholBM_3" = ABBA_MonoAlcoholBM_3, "ABBA_MonoAlcoholBM_4" = ABBA_MonoAlcoholBM_4, "ABBA_MonoAlcoholBM_5" = ABBA_MonoAlcoholBM_5, "ABBA_MonoAlcoholBM_6" = ABBA_MonoAlcoholBM_6, "ABBA_MonoAlcoholBM_7" = ABBA_MonoAlcoholBM_7, "ABBA_MonoAlcoholBM_8" =  ABBA_MonoAlcoholBM_8, "ABBA_MonoAlcoholBM_9" = ABBA_MonoAlcoholBM_9, "ABBA_MonoAlcoholBM_10" = ABBA_MonoAlcoholBM_10, "ABBA_MonoAlcoholBM_11" = ABBA_MonoAlcoholBM_11, "ABBA_MonoAlcoholBM_12" = ABBA_MonoAlcoholBM_12, "ABBA_MonoAlcoholBM_13" = ABBA_MonoAlcoholBM_13, "ABBA_MonoAlcoholBM_14" = ABBA_MonoAlcoholBM_14, "ABBA_MonoAlcoholBM_15" = ABBA_MonoAlcoholBM_15, "ABBA_MonoAlcoholBM_16" = ABBA_MonoAlcoholBM_16)
ABBA_MonoAlcoholBM <- as.data.frame(aictab(cand.set = Cand_models_ABBA_MonoAlcoholBM))
# Split string
ABBA_MonoAlcoholBM_sep <- separate(ABBA_MonoAlcoholBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_MonoAlcoholBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_MonoAlcoholBM)))
# Merge AICc and R2 tables together
ABBA_MonoAlcoholBM_results <- merge(ABBA_MonoAlcoholBM_sep, ABBA_MonoAlcoholBM_R2, by.x="ModNumber", by.y = "rowname")





# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpenic Ester Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_MonoEsterBM_1 <- glm(MonoEster ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoEsterBM_2 <- glm(MonoEster ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoEsterBM_3 <- glm(MonoEster ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoEsterBM_4 <- glm(MonoEster ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoEsterBM_5 <- glm(MonoEster ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoEsterBM_6 <- glm(MonoEster ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoEsterBM_7 <- glm(MonoEster ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoEsterBM_8 <- glm(MonoEster ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoEsterBM_9 <- glm(MonoEster ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoEsterBM_10 <- glm(MonoEster ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoEsterBM_11 <- glm(MonoEster ~ LandCover + EVI, data = bF_Phyto_BM)
ABBA_MonoEsterBM_12 <- glm(MonoEster ~ LandCover, data = bF_Phyto_BM)
ABBA_MonoEsterBM_13 <- glm(MonoEster ~ EVI, data = bF_Phyto_BM)
ABBA_MonoEsterBM_14 <- glm(MonoEster ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_MonoEsterBM_15 <- glm(MonoEster ~ Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_MonoEsterBM_16 <- glm(MonoEster ~ 1, data =  bF_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_MonoEsterBM <- list("ABBA_MonoEsterBM_1" = ABBA_MonoEsterBM_1, "ABBA_MonoEsterBM_2" = ABBA_MonoEsterBM_2, "ABBA_MonoEsterBM_3" = ABBA_MonoEsterBM_3, "ABBA_MonoEsterBM_4" = ABBA_MonoEsterBM_4, "ABBA_MonoEsterBM_5" = ABBA_MonoEsterBM_5, "ABBA_MonoEsterBM_6" = ABBA_MonoEsterBM_6, "ABBA_MonoEsterBM_7" = ABBA_MonoEsterBM_7, "ABBA_MonoEsterBM_8" =  ABBA_MonoEsterBM_8, "ABBA_MonoEsterBM_9" = ABBA_MonoEsterBM_9, "ABBA_MonoEsterBM_10" = ABBA_MonoEsterBM_10, "ABBA_MonoEsterBM_11" = ABBA_MonoEsterBM_11, "ABBA_MonoEsterBM_12" = ABBA_MonoEsterBM_12, "ABBA_MonoEsterBM_13" = ABBA_MonoEsterBM_13, "ABBA_MonoEsterBM_14" = ABBA_MonoEsterBM_14, "ABBA_MonoEsterBM_15" = ABBA_MonoEsterBM_15, "ABBA_MonoEsterBM_16" = ABBA_MonoEsterBM_16)
ABBA_MonoEsterBM <- as.data.frame(aictab(cand.set = Cand_models_ABBA_MonoEsterBM))
# Split string
ABBA_MonoEsterBM_sep <- separate(ABBA_MonoEsterBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_MonoEsterBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_MonoEsterBM)))
# Merge AICc and R2 tables together
ABBA_MonoEsterBM_results <- merge(ABBA_MonoEsterBM_sep, ABBA_MonoEsterBM_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Sesquiterpene Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_SesquiterpeneBM_1 <- glm(Sesquiterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_2 <- glm(Sesquiterpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_3 <- glm(Sesquiterpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_4 <- glm(Sesquiterpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_5 <- glm(Sesquiterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_6 <- glm(Sesquiterpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_7 <- glm(Sesquiterpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_8 <- glm(Sesquiterpene ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_9 <- glm(Sesquiterpene ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_10 <- glm(Sesquiterpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_11 <- glm(Sesquiterpene ~ LandCover + EVI, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_12 <- glm(Sesquiterpene ~ LandCover, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_13 <- glm(Sesquiterpene ~ EVI, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_14 <- glm(Sesquiterpene ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_15 <- glm(Sesquiterpene ~ Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_SesquiterpeneBM_16 <- glm(Sesquiterpene ~ 1, data =  bF_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_SesquiterpeneBM <- list("ABBA_SesquiterpeneBM_1" = ABBA_SesquiterpeneBM_1, "ABBA_SesquiterpeneBM_2" = ABBA_SesquiterpeneBM_2, "ABBA_SesquiterpeneBM_3" = ABBA_SesquiterpeneBM_3, "ABBA_SesquiterpeneBM_4" = ABBA_SesquiterpeneBM_4, "ABBA_SesquiterpeneBM_5" = ABBA_SesquiterpeneBM_5, "ABBA_SesquiterpeneBM_6" = ABBA_SesquiterpeneBM_6, "ABBA_SesquiterpeneBM_7" = ABBA_SesquiterpeneBM_7, "ABBA_SesquiterpeneBM_8" =  ABBA_SesquiterpeneBM_8, "ABBA_SesquiterpeneBM_9" = ABBA_SesquiterpeneBM_9, "ABBA_SesquiterpeneBM_10" = ABBA_SesquiterpeneBM_10, "ABBA_SesquiterpeneBM_11" = ABBA_SesquiterpeneBM_11, "ABBA_SesquiterpeneBM_12" = ABBA_SesquiterpeneBM_12, "ABBA_SesquiterpeneBM_13" = ABBA_SesquiterpeneBM_13, "ABBA_SesquiterpeneBM_14" = ABBA_SesquiterpeneBM_14, "ABBA_SesquiterpeneBM_15" = ABBA_SesquiterpeneBM_15, "ABBA_SesquiterpeneBM_16" = ABBA_SesquiterpeneBM_16)
ABBA_SesquiterpeneBM <- as.data.frame(aictab(cand.set = Cand_models_ABBA_SesquiterpeneBM))
# Split string
ABBA_SesquiterpeneBM_sep <- separate(ABBA_SesquiterpeneBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_SesquiterpeneBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_SesquiterpeneBM)))
# Merge AICc and R2 tables together
ABBA_SesquiterpeneBM_results <- merge(ABBA_SesquiterpeneBM_sep, ABBA_SesquiterpeneBM_R2, by.x="ModNumber", by.y = "rowname")

# Extract summary from models above the null
summary(ABBA_SesquiterpeneBM_13)
summary(ABBA_SesquiterpeneBM_10)


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Diversity Models #### Not included in final product as it is exactly the same as the raw models
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
ABBA_DiversityBM_1 <- glm(Diversity ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_DiversityBM_2 <- glm(Diversity ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_DiversityBM_3 <- glm(Diversity ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_DiversityBM_4 <- glm(Diversity ~ LandCover + EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_DiversityBM_5 <- glm(Diversity ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_DiversityBM_6 <- glm(Diversity ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_DiversityBM_7 <- glm(Diversity ~ EVI + AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_DiversityBM_8 <- glm(Diversity ~ LandCover + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_DiversityBM_9 <- glm(Diversity ~ EVI + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_DiversityBM_10 <- glm(Diversity ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_DiversityBM_11 <- glm(Diversity ~ LandCover + EVI, data = bF_Phyto_BM)
ABBA_DiversityBM_12 <- glm(Diversity ~ LandCover, data = bF_Phyto_BM)
ABBA_DiversityBM_13 <- glm(Diversity ~ EVI, data = bF_Phyto_BM)
ABBA_DiversityBM_14 <- glm(Diversity ~ AgeClss + HghtCls + CrwnDns, data = bF_Phyto_BM)
ABBA_DiversityBM_15 <- glm(Diversity ~ Aspect + Slope + Elevation, data = bF_Phyto_BM)
ABBA_DiversityBM_16 <- glm(Diversity ~ 1, data =  bF_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_ABBA_DiversityBM <- list("ABBA_DiversityBM_1" = ABBA_DiversityBM_1, "ABBA_DiversityBM_2" = ABBA_DiversityBM_2, "ABBA_DiversityBM_3" = ABBA_DiversityBM_3, "ABBA_DiversityBM_4" = ABBA_DiversityBM_4, "ABBA_DiversityBM_5" = ABBA_DiversityBM_5, "ABBA_DiversityBM_6" = ABBA_DiversityBM_6, "ABBA_DiversityBM_7" = ABBA_DiversityBM_7, "ABBA_DiversityBM_8" =  ABBA_DiversityBM_8, "ABBA_DiversityBM_9" = ABBA_DiversityBM_9, "ABBA_DiversityBM_10" = ABBA_DiversityBM_10, "ABBA_DiversityBM_11" = ABBA_DiversityBM_11, "ABBA_DiversityBM_12" = ABBA_DiversityBM_12, "ABBA_DiversityBM_13" = ABBA_DiversityBM_13, "ABBA_DiversityBM_14" = ABBA_DiversityBM_14, "ABBA_DiversityBM_15" = ABBA_DiversityBM_15, "ABBA_DiversityBM_16" = ABBA_DiversityBM_16)
ABBA_DiversityBM <- as.data.frame(aictab(cand.set = Cand_models_ABBA_DiversityBM))
# Split string
ABBA_DiversityBM_sep <- separate(ABBA_DiversityBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
ABBA_DiversityBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_ABBA_DiversityBM)))
# Merge AICc and R2 tables together
ABBA_DiversityBM_results <- merge(ABBA_DiversityBM_sep, ABBA_DiversityBM_R2, by.x="ModNumber", by.y = "rowname")







###### PIMA Raw ######
# Load raw phytochemistry data for black spruce
PIMA.PhytoRaw <- read.csv("Data/Outputs/Phytochemical/PIMA_Phytochemistry.csv")
str(PIMA.PhytoRaw)
PIMA.PhytoRaw$Diversity <- diversity(PIMA.PhytoRaw[2:36], index="shannon")
PIMA.PhytoRaw.sub <- subset(PIMA.PhytoRaw, select = c(PlotName, Total.terpene, Total.monoterpene, Total.monoterpenic.alcohol, Total.monoterpenic.ester, Total.sesquiterpene, Diversity))
colnames(PIMA.PhytoRaw.sub)[colnames(PIMA.PhytoRaw.sub)=="Total.terpene"] <- "Terpene"
colnames(PIMA.PhytoRaw.sub)[colnames(PIMA.PhytoRaw.sub)=="Total.monoterpene"] <- "Monoterpene"
colnames(PIMA.PhytoRaw.sub)[colnames(PIMA.PhytoRaw.sub)=="Total.monoterpenic.alcohol"] <- "MonoAlcohol"
colnames(PIMA.PhytoRaw.sub)[colnames(PIMA.PhytoRaw.sub)=="Total.monoterpenic.ester"] <- "MonoEster"
colnames(PIMA.PhytoRaw.sub)[colnames(PIMA.PhytoRaw.sub)=="Total.sesquiterpene"] <- "Sesquiterpene"

bS_Phyto_Raw <- merge(PIMA.PhytoRaw.sub, Covariates, by_x="PlotName", by_y="PlotName", all_x=T)

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Set biotic/land cover fields to factors
bS_Phyto_Raw$AgeClss <- as.factor(bS_Phyto_Raw$AgeClss)
bS_Phyto_Raw$HghtCls <- as.factor(bS_Phyto_Raw$HghtCls)
bS_Phyto_Raw$CrwnDns <- as.factor(bS_Phyto_Raw$CrwnDns)
bS_Phyto_Raw$LandCover <- as.factor(bS_Phyto_Raw$LandCover)

# scale continuous variables
bS_Phyto_Raw$EVI <- c(scale(bS_Phyto_Raw$EVI.ns))
bS_Phyto_Raw$Elevation <- c(scale(bS_Phyto_Raw$Elevation.ns))
bS_Phyto_Raw$Aspect <- c(scale(bS_Phyto_Raw$Aspect.ns))
bS_Phyto_Raw$Slope <- c(scale(bS_Phyto_Raw$Slope.ns))



# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
##### Terpene Models #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_TerpeneRaw_1 <- glm(Terpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_2 <- glm(Terpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_3 <- glm(Terpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_4 <- glm(Terpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_5 <- glm(Terpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_6 <- glm(Terpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_7 <- glm(Terpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_8 <- glm(Terpene ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_9 <- glm(Terpene ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_10 <- glm(Terpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_11 <- glm(Terpene ~ LandCover + EVI, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_12 <- glm(Terpene ~ LandCover, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_13 <- glm(Terpene ~ EVI, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_14 <- glm(Terpene ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_15 <- glm(Terpene ~ Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_TerpeneRaw_16 <- glm(Terpene ~ 1, data =  bS_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_TerpeneRaw <- list("PIMA_TerpeneRaw_1" = PIMA_TerpeneRaw_1, "PIMA_TerpeneRaw_2" = PIMA_TerpeneRaw_2, "PIMA_TerpeneRaw_3" = PIMA_TerpeneRaw_3, "PIMA_TerpeneRaw_4" = PIMA_TerpeneRaw_4, "PIMA_TerpeneRaw_5" = PIMA_TerpeneRaw_5, "PIMA_TerpeneRaw_6" = PIMA_TerpeneRaw_6, "PIMA_TerpeneRaw_7" = PIMA_TerpeneRaw_7, "PIMA_TerpeneRaw_8" =  PIMA_TerpeneRaw_8, "PIMA_TerpeneRaw_9" = PIMA_TerpeneRaw_9, "PIMA_TerpeneRaw_10" = PIMA_TerpeneRaw_10, "PIMA_TerpeneRaw_11" = PIMA_TerpeneRaw_11, "PIMA_TerpeneRaw_12" = PIMA_TerpeneRaw_12, "PIMA_TerpeneRaw_13" = PIMA_TerpeneRaw_13, "PIMA_TerpeneRaw_14" = PIMA_TerpeneRaw_14, "PIMA_TerpeneRaw_15" = PIMA_TerpeneRaw_15, "PIMA_TerpeneRaw_16" = PIMA_TerpeneRaw_16)
PIMA_TerpeneRaw <- as.data.frame(aictab(cand.set = Cand_models_PIMA_TerpeneRaw))
# Split string
PIMA_TerpeneRaw_sep <- separate(PIMA_TerpeneRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_TerpeneRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_TerpeneRaw)))
# Merge AICc and R2 tables together
PIMA_TerpeneRaw_results <- merge(PIMA_TerpeneRaw_sep, PIMA_TerpeneRaw_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpene Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_MonoterpeneRaw_1 <- glm(Monoterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_2 <- glm(Monoterpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_3 <- glm(Monoterpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_4 <- glm(Monoterpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_5 <- glm(Monoterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_6 <- glm(Monoterpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_7 <- glm(Monoterpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_8 <- glm(Monoterpene ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_9 <- glm(Monoterpene ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_10 <- glm(Monoterpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_11 <- glm(Monoterpene ~ LandCover + EVI, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_12 <- glm(Monoterpene ~ LandCover, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_13 <- glm(Monoterpene ~ EVI, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_14 <- glm(Monoterpene ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_15 <- glm(Monoterpene ~ Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoterpeneRaw_16 <- glm(Monoterpene ~ 1, data =  bS_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_MonoterpeneRaw <- list("PIMA_MonoterpeneRaw_1" = PIMA_MonoterpeneRaw_1, "PIMA_MonoterpeneRaw_2" = PIMA_MonoterpeneRaw_2, "PIMA_MonoterpeneRaw_3" = PIMA_MonoterpeneRaw_3, "PIMA_MonoterpeneRaw_4" = PIMA_MonoterpeneRaw_4, "PIMA_MonoterpeneRaw_5" = PIMA_MonoterpeneRaw_5, "PIMA_MonoterpeneRaw_6" = PIMA_MonoterpeneRaw_6, "PIMA_MonoterpeneRaw_7" = PIMA_MonoterpeneRaw_7, "PIMA_MonoterpeneRaw_8" =  PIMA_MonoterpeneRaw_8, "PIMA_MonoterpeneRaw_9" = PIMA_MonoterpeneRaw_9, "PIMA_MonoterpeneRaw_10" = PIMA_MonoterpeneRaw_10, "PIMA_MonoterpeneRaw_11" = PIMA_MonoterpeneRaw_11, "PIMA_MonoterpeneRaw_12" = PIMA_MonoterpeneRaw_12, "PIMA_MonoterpeneRaw_13" = PIMA_MonoterpeneRaw_13, "PIMA_MonoterpeneRaw_14" = PIMA_MonoterpeneRaw_14, "PIMA_MonoterpeneRaw_15" = PIMA_MonoterpeneRaw_15, "PIMA_MonoterpeneRaw_16" = PIMA_MonoterpeneRaw_16)
PIMA_MonoterpeneRaw <- as.data.frame(aictab(cand.set = Cand_models_PIMA_MonoterpeneRaw))
# Split string
PIMA_MonoterpeneRaw_sep <- separate(PIMA_MonoterpeneRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_MonoterpeneRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_MonoterpeneRaw)))
# Merge AICc and R2 tables together
PIMA_MonoterpeneRaw_results <- merge(PIMA_MonoterpeneRaw_sep, PIMA_MonoterpeneRaw_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpenic Alcohol Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_MonoAlcoholRaw_1 <- glm(MonoAlcohol ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_2 <- glm(MonoAlcohol ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_3 <- glm(MonoAlcohol ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_4 <- glm(MonoAlcohol ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_5 <- glm(MonoAlcohol ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_6 <- glm(MonoAlcohol ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_7 <- glm(MonoAlcohol ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_8 <- glm(MonoAlcohol ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_9 <- glm(MonoAlcohol ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_10 <- glm(MonoAlcohol ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_11 <- glm(MonoAlcohol ~ LandCover + EVI, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_12 <- glm(MonoAlcohol ~ LandCover, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_13 <- glm(MonoAlcohol ~ EVI, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_14 <- glm(MonoAlcohol ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_15 <- glm(MonoAlcohol ~ Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoAlcoholRaw_16 <- glm(MonoAlcohol ~ 1, data =  bS_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_MonoAlcoholRaw <- list("PIMA_MonoAlcoholRaw_1" = PIMA_MonoAlcoholRaw_1, "PIMA_MonoAlcoholRaw_2" = PIMA_MonoAlcoholRaw_2, "PIMA_MonoAlcoholRaw_3" = PIMA_MonoAlcoholRaw_3, "PIMA_MonoAlcoholRaw_4" = PIMA_MonoAlcoholRaw_4, "PIMA_MonoAlcoholRaw_5" = PIMA_MonoAlcoholRaw_5, "PIMA_MonoAlcoholRaw_6" = PIMA_MonoAlcoholRaw_6, "PIMA_MonoAlcoholRaw_7" = PIMA_MonoAlcoholRaw_7, "PIMA_MonoAlcoholRaw_8" =  PIMA_MonoAlcoholRaw_8, "PIMA_MonoAlcoholRaw_9" = PIMA_MonoAlcoholRaw_9, "PIMA_MonoAlcoholRaw_10" = PIMA_MonoAlcoholRaw_10, "PIMA_MonoAlcoholRaw_11" = PIMA_MonoAlcoholRaw_11, "PIMA_MonoAlcoholRaw_12" = PIMA_MonoAlcoholRaw_12, "PIMA_MonoAlcoholRaw_13" = PIMA_MonoAlcoholRaw_13, "PIMA_MonoAlcoholRaw_14" = PIMA_MonoAlcoholRaw_14, "PIMA_MonoAlcoholRaw_15" = PIMA_MonoAlcoholRaw_15, "PIMA_MonoAlcoholRaw_16" = PIMA_MonoAlcoholRaw_16)
PIMA_MonoAlcoholRaw <- as.data.frame(aictab(cand.set = Cand_models_PIMA_MonoAlcoholRaw))
# Split string
PIMA_MonoAlcoholRaw_sep <- separate(PIMA_MonoAlcoholRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_MonoAlcoholRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_MonoAlcoholRaw)))
# Merge AICc and R2 tables together
PIMA_MonoAlcoholRaw_results <- merge(PIMA_MonoAlcoholRaw_sep, PIMA_MonoAlcoholRaw_R2, by.x="ModNumber", by.y = "rowname")





# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpenic Ester Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_MonoEsterRaw_1 <- glm(MonoEster ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_2 <- glm(MonoEster ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_3 <- glm(MonoEster ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_4 <- glm(MonoEster ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_5 <- glm(MonoEster ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_6 <- glm(MonoEster ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_7 <- glm(MonoEster ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_8 <- glm(MonoEster ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_9 <- glm(MonoEster ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_10 <- glm(MonoEster ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_11 <- glm(MonoEster ~ LandCover + EVI, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_12 <- glm(MonoEster ~ LandCover, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_13 <- glm(MonoEster ~ EVI, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_14 <- glm(MonoEster ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_15 <- glm(MonoEster ~ Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_MonoEsterRaw_16 <- glm(MonoEster ~ 1, data =  bS_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_MonoEsterRaw <- list("PIMA_MonoEsterRaw_1" = PIMA_MonoEsterRaw_1, "PIMA_MonoEsterRaw_2" = PIMA_MonoEsterRaw_2, "PIMA_MonoEsterRaw_3" = PIMA_MonoEsterRaw_3, "PIMA_MonoEsterRaw_4" = PIMA_MonoEsterRaw_4, "PIMA_MonoEsterRaw_5" = PIMA_MonoEsterRaw_5, "PIMA_MonoEsterRaw_6" = PIMA_MonoEsterRaw_6, "PIMA_MonoEsterRaw_7" = PIMA_MonoEsterRaw_7, "PIMA_MonoEsterRaw_8" =  PIMA_MonoEsterRaw_8, "PIMA_MonoEsterRaw_9" = PIMA_MonoEsterRaw_9, "PIMA_MonoEsterRaw_10" = PIMA_MonoEsterRaw_10, "PIMA_MonoEsterRaw_11" = PIMA_MonoEsterRaw_11, "PIMA_MonoEsterRaw_12" = PIMA_MonoEsterRaw_12, "PIMA_MonoEsterRaw_13" = PIMA_MonoEsterRaw_13, "PIMA_MonoEsterRaw_14" = PIMA_MonoEsterRaw_14, "PIMA_MonoEsterRaw_15" = PIMA_MonoEsterRaw_15, "PIMA_MonoEsterRaw_16" = PIMA_MonoEsterRaw_16)
PIMA_MonoEsterRaw <- as.data.frame(aictab(cand.set = Cand_models_PIMA_MonoEsterRaw))
# Split string
PIMA_MonoEsterRaw_sep <- separate(PIMA_MonoEsterRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_MonoEsterRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_MonoEsterRaw)))
# Merge AICc and R2 tables together
PIMA_MonoEsterRaw_results <- merge(PIMA_MonoEsterRaw_sep, PIMA_MonoEsterRaw_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Sesquiterpene Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_SesquiterpeneRaw_1 <- glm(Sesquiterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_2 <- glm(Sesquiterpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_3 <- glm(Sesquiterpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_4 <- glm(Sesquiterpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_5 <- glm(Sesquiterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_6 <- glm(Sesquiterpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_7 <- glm(Sesquiterpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_8 <- glm(Sesquiterpene ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_9 <- glm(Sesquiterpene ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_10 <- glm(Sesquiterpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_11 <- glm(Sesquiterpene ~ LandCover + EVI, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_12 <- glm(Sesquiterpene ~ LandCover, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_13 <- glm(Sesquiterpene ~ EVI, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_14 <- glm(Sesquiterpene ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_15 <- glm(Sesquiterpene ~ Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_SesquiterpeneRaw_16 <- glm(Sesquiterpene ~ 1, data =  bS_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_SesquiterpeneRaw <- list("PIMA_SesquiterpeneRaw_1" = PIMA_SesquiterpeneRaw_1, "PIMA_SesquiterpeneRaw_2" = PIMA_SesquiterpeneRaw_2, "PIMA_SesquiterpeneRaw_3" = PIMA_SesquiterpeneRaw_3, "PIMA_SesquiterpeneRaw_4" = PIMA_SesquiterpeneRaw_4, "PIMA_SesquiterpeneRaw_5" = PIMA_SesquiterpeneRaw_5, "PIMA_SesquiterpeneRaw_6" = PIMA_SesquiterpeneRaw_6, "PIMA_SesquiterpeneRaw_7" = PIMA_SesquiterpeneRaw_7, "PIMA_SesquiterpeneRaw_8" =  PIMA_SesquiterpeneRaw_8, "PIMA_SesquiterpeneRaw_9" = PIMA_SesquiterpeneRaw_9, "PIMA_SesquiterpeneRaw_10" = PIMA_SesquiterpeneRaw_10, "PIMA_SesquiterpeneRaw_11" = PIMA_SesquiterpeneRaw_11, "PIMA_SesquiterpeneRaw_12" = PIMA_SesquiterpeneRaw_12, "PIMA_SesquiterpeneRaw_13" = PIMA_SesquiterpeneRaw_13, "PIMA_SesquiterpeneRaw_14" = PIMA_SesquiterpeneRaw_14, "PIMA_SesquiterpeneRaw_15" = PIMA_SesquiterpeneRaw_15, "PIMA_SesquiterpeneRaw_16" = PIMA_SesquiterpeneRaw_16)
PIMA_SesquiterpeneRaw <- as.data.frame(aictab(cand.set = Cand_models_PIMA_SesquiterpeneRaw))
# Split string
PIMA_SesquiterpeneRaw_sep <- separate(PIMA_SesquiterpeneRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_SesquiterpeneRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_SesquiterpeneRaw)))
# Merge AICc and R2 tables together
PIMA_SesquiterpeneRaw_results <- merge(PIMA_SesquiterpeneRaw_sep, PIMA_SesquiterpeneRaw_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Diversity Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_DiversityRaw_1 <- glm(Diversity ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_DiversityRaw_2 <- glm(Diversity ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_DiversityRaw_3 <- glm(Diversity ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_DiversityRaw_4 <- glm(Diversity ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_DiversityRaw_5 <- glm(Diversity ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_DiversityRaw_6 <- glm(Diversity ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_DiversityRaw_7 <- glm(Diversity ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_DiversityRaw_8 <- glm(Diversity ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_DiversityRaw_9 <- glm(Diversity ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_DiversityRaw_10 <- glm(Diversity ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_DiversityRaw_11 <- glm(Diversity ~ LandCover + EVI, data = bS_Phyto_Raw)
PIMA_DiversityRaw_12 <- glm(Diversity ~ LandCover, data = bS_Phyto_Raw)
PIMA_DiversityRaw_13 <- glm(Diversity ~ EVI, data = bS_Phyto_Raw)
PIMA_DiversityRaw_14 <- glm(Diversity ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_Raw)
PIMA_DiversityRaw_15 <- glm(Diversity ~ Aspect + Slope + Elevation, data = bS_Phyto_Raw)
PIMA_DiversityRaw_16 <- glm(Diversity ~ 1, data =  bS_Phyto_Raw)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_DiversityRaw <- list("PIMA_DiversityRaw_1" = PIMA_DiversityRaw_1, "PIMA_DiversityRaw_2" = PIMA_DiversityRaw_2, "PIMA_DiversityRaw_3" = PIMA_DiversityRaw_3, "PIMA_DiversityRaw_4" = PIMA_DiversityRaw_4, "PIMA_DiversityRaw_5" = PIMA_DiversityRaw_5, "PIMA_DiversityRaw_6" = PIMA_DiversityRaw_6, "PIMA_DiversityRaw_7" = PIMA_DiversityRaw_7, "PIMA_DiversityRaw_8" =  PIMA_DiversityRaw_8, "PIMA_DiversityRaw_9" = PIMA_DiversityRaw_9, "PIMA_DiversityRaw_10" = PIMA_DiversityRaw_10, "PIMA_DiversityRaw_11" = PIMA_DiversityRaw_11, "PIMA_DiversityRaw_12" = PIMA_DiversityRaw_12, "PIMA_DiversityRaw_13" = PIMA_DiversityRaw_13, "PIMA_DiversityRaw_14" = PIMA_DiversityRaw_14, "PIMA_DiversityRaw_15" = PIMA_DiversityRaw_15, "PIMA_DiversityRaw_16" = PIMA_DiversityRaw_16)
PIMA_DiversityRaw <- as.data.frame(aictab(cand.set = Cand_models_PIMA_DiversityRaw))
# Split string
PIMA_DiversityRaw_sep <- separate(PIMA_DiversityRaw, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_DiversityRaw_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_Diversity)))
# Merge AICc and R2 tables together
PIMA_DiversityRaw_results <- merge(PIMA_DiversityRaw_sep, PIMA_DiversityRaw_R2, by.x="ModNumber", by.y = "rowname")












###### PIMA Biomass #####
# Load biomass phytochemistry data for black spruce
PIMA.PhytoBM <- read.csv("Data/Outputs/Phytochemical/PIMA_BiomassBasis_Phytochemistry.csv")
str(PIMA.PhytoBM)
PIMA.PhytoBM$Diversity <- diversity(PIMA.PhytoBM[3:37], index="shannon")
PIMA.PhytoBM.sub <- subset(PIMA.PhytoBM, select = c(PlotName, Total.terpene, Total.monoterpene, Total.monoterpenic.alcohol, Total.monoterpenic.ester, Total.sesquiterpene, Diversity))
colnames(PIMA.PhytoBM.sub)[colnames(PIMA.PhytoBM.sub)=="Total.terpene"] <- "Terpene"
colnames(PIMA.PhytoBM.sub)[colnames(PIMA.PhytoBM.sub)=="Total.monoterpene"] <- "Monoterpene"
colnames(PIMA.PhytoBM.sub)[colnames(PIMA.PhytoBM.sub)=="Total.monoterpenic.alcohol"] <- "MonoAlcohol"
colnames(PIMA.PhytoBM.sub)[colnames(PIMA.PhytoBM.sub)=="Total.monoterpenic.ester"] <- "MonoEster"
colnames(PIMA.PhytoBM.sub)[colnames(PIMA.PhytoBM.sub)=="Total.sesquiterpene"] <- "Sesquiterpene"

# Join ABBA phytochemistry to the landscape covariates
bS_Phyto_BM <- merge(PIMA.PhytoBM.sub, Covariates, by.x="PlotName", by.y="PlotName", all.x=T)
str(bS_Phyto_BM)


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
# Set biotic/land cover fields to factors
bS_Phyto_BM$AgeClss <- as.factor(bS_Phyto_BM$AgeClss)
bS_Phyto_BM$HghtCls <- as.factor(bS_Phyto_BM$HghtCls)
bS_Phyto_BM$CrwnDns <- as.factor(bS_Phyto_BM$CrwnDns)
bS_Phyto_BM$LandCover <- as.factor(bS_Phyto_BM$LandCover)

# scale continuous variables
bS_Phyto_BM$EVI <- c(scale(bS_Phyto_BM$EVI.ns))
bS_Phyto_BM$Elevation <- c(scale(bS_Phyto_BM$Elevation.ns))
bS_Phyto_BM$Aspect <- c(scale(bS_Phyto_BM$Aspect.ns))
bS_Phyto_BM$Slope <- c(scale(bS_Phyto_BM$Slope.ns))









# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
##### Terpene Models #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_TerpeneBM_1 <- glm(Terpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_TerpeneBM_2 <- glm(Terpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_TerpeneBM_3 <- glm(Terpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_TerpeneBM_4 <- glm(Terpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_TerpeneBM_5 <- glm(Terpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_TerpeneBM_6 <- glm(Terpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_TerpeneBM_7 <- glm(Terpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_TerpeneBM_8 <- glm(Terpene ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_TerpeneBM_9 <- glm(Terpene ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_TerpeneBM_10 <- glm(Terpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_TerpeneBM_11 <- glm(Terpene ~ LandCover + EVI, data = bS_Phyto_BM)
PIMA_TerpeneBM_12 <- glm(Terpene ~ LandCover, data = bS_Phyto_BM)
PIMA_TerpeneBM_13 <- glm(Terpene ~ EVI, data = bS_Phyto_BM)
PIMA_TerpeneBM_14 <- glm(Terpene ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_TerpeneBM_15 <- glm(Terpene ~ Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_TerpeneBM_16 <- glm(Terpene ~ 1, data =  bS_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_TerpeneBM <- list("PIMA_TerpeneBM_1" = PIMA_TerpeneBM_1, "PIMA_TerpeneBM_2" = PIMA_TerpeneBM_2, "PIMA_TerpeneBM_3" = PIMA_TerpeneBM_3, "PIMA_TerpeneBM_4" = PIMA_TerpeneBM_4, "PIMA_TerpeneBM_5" = PIMA_TerpeneBM_5, "PIMA_TerpeneBM_6" = PIMA_TerpeneBM_6, "PIMA_TerpeneBM_7" = PIMA_TerpeneBM_7, "PIMA_TerpeneBM_8" =  PIMA_TerpeneBM_8, "PIMA_TerpeneBM_9" = PIMA_TerpeneBM_9, "PIMA_TerpeneBM_10" = PIMA_TerpeneBM_10, "PIMA_TerpeneBM_11" = PIMA_TerpeneBM_11, "PIMA_TerpeneBM_12" = PIMA_TerpeneBM_12, "PIMA_TerpeneBM_13" = PIMA_TerpeneBM_13, "PIMA_TerpeneBM_14" = PIMA_TerpeneBM_14, "PIMA_TerpeneBM_15" = PIMA_TerpeneBM_15, "PIMA_TerpeneBM_16" = PIMA_TerpeneBM_16)
PIMA_TerpeneBM <- as.data.frame(aictab(cand.set = Cand_models_PIMA_TerpeneBM))
# Split string
PIMA_TerpeneBM_sep <- separate(PIMA_TerpeneBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_TerpeneBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_TerpeneBM)))
# Merge AICc and R2 tables together
PIMA_TerpeneBM_results <- merge(PIMA_TerpeneBM_sep, PIMA_TerpeneBM_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpene Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_MonoterpeneBM_1 <- glm(Monoterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_2 <- glm(Monoterpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_3 <- glm(Monoterpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_4 <- glm(Monoterpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_5 <- glm(Monoterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_6 <- glm(Monoterpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_7 <- glm(Monoterpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_8 <- glm(Monoterpene ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_9 <- glm(Monoterpene ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_10 <- glm(Monoterpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_11 <- glm(Monoterpene ~ LandCover + EVI, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_12 <- glm(Monoterpene ~ LandCover, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_13 <- glm(Monoterpene ~ EVI, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_14 <- glm(Monoterpene ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_15 <- glm(Monoterpene ~ Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoterpeneBM_16 <- glm(Monoterpene ~ 1, data =  bS_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_MonoterpeneBM <- list("PIMA_MonoterpeneBM_1" = PIMA_MonoterpeneBM_1, "PIMA_MonoterpeneBM_2" = PIMA_MonoterpeneBM_2, "PIMA_MonoterpeneBM_3" = PIMA_MonoterpeneBM_3, "PIMA_MonoterpeneBM_4" = PIMA_MonoterpeneBM_4, "PIMA_MonoterpeneBM_5" = PIMA_MonoterpeneBM_5, "PIMA_MonoterpeneBM_6" = PIMA_MonoterpeneBM_6, "PIMA_MonoterpeneBM_7" = PIMA_MonoterpeneBM_7, "PIMA_MonoterpeneBM_8" =  PIMA_MonoterpeneBM_8, "PIMA_MonoterpeneBM_9" = PIMA_MonoterpeneBM_9, "PIMA_MonoterpeneBM_10" = PIMA_MonoterpeneBM_10, "PIMA_MonoterpeneBM_11" = PIMA_MonoterpeneBM_11, "PIMA_MonoterpeneBM_12" = PIMA_MonoterpeneBM_12, "PIMA_MonoterpeneBM_13" = PIMA_MonoterpeneBM_13, "PIMA_MonoterpeneBM_14" = PIMA_MonoterpeneBM_14, "PIMA_MonoterpeneBM_15" = PIMA_MonoterpeneBM_15, "PIMA_MonoterpeneBM_16" = PIMA_MonoterpeneBM_16)
PIMA_MonoterpeneBM <- as.data.frame(aictab(cand.set = Cand_models_PIMA_MonoterpeneBM))
# Split string
PIMA_MonoterpeneBM_sep <- separate(PIMA_MonoterpeneBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_MonoterpeneBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_MonoterpeneBM)))
# Merge AICc and R2 tables together
PIMA_MonoterpeneBM_results <- merge(PIMA_MonoterpeneBM_sep, PIMA_MonoterpeneBM_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpenic Alcohol Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_MonoAlcoholBM_1 <- glm(MonoAlcohol ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_2 <- glm(MonoAlcohol ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_3 <- glm(MonoAlcohol ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_4 <- glm(MonoAlcohol ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_5 <- glm(MonoAlcohol ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_6 <- glm(MonoAlcohol ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_7 <- glm(MonoAlcohol ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_8 <- glm(MonoAlcohol ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_9 <- glm(MonoAlcohol ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_10 <- glm(MonoAlcohol ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_11 <- glm(MonoAlcohol ~ LandCover + EVI, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_12 <- glm(MonoAlcohol ~ LandCover, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_13 <- glm(MonoAlcohol ~ EVI, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_14 <- glm(MonoAlcohol ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_15 <- glm(MonoAlcohol ~ Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoAlcoholBM_16 <- glm(MonoAlcohol ~ 1, data =  bS_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_MonoAlcoholBM <- list("PIMA_MonoAlcoholBM_1" = PIMA_MonoAlcoholBM_1, "PIMA_MonoAlcoholBM_2" = PIMA_MonoAlcoholBM_2, "PIMA_MonoAlcoholBM_3" = PIMA_MonoAlcoholBM_3, "PIMA_MonoAlcoholBM_4" = PIMA_MonoAlcoholBM_4, "PIMA_MonoAlcoholBM_5" = PIMA_MonoAlcoholBM_5, "PIMA_MonoAlcoholBM_6" = PIMA_MonoAlcoholBM_6, "PIMA_MonoAlcoholBM_7" = PIMA_MonoAlcoholBM_7, "PIMA_MonoAlcoholBM_8" =  PIMA_MonoAlcoholBM_8, "PIMA_MonoAlcoholBM_9" = PIMA_MonoAlcoholBM_9, "PIMA_MonoAlcoholBM_10" = PIMA_MonoAlcoholBM_10, "PIMA_MonoAlcoholBM_11" = PIMA_MonoAlcoholBM_11, "PIMA_MonoAlcoholBM_12" = PIMA_MonoAlcoholBM_12, "PIMA_MonoAlcoholBM_13" = PIMA_MonoAlcoholBM_13, "PIMA_MonoAlcoholBM_14" = PIMA_MonoAlcoholBM_14, "PIMA_MonoAlcoholBM_15" = PIMA_MonoAlcoholBM_15, "PIMA_MonoAlcoholBM_16" = PIMA_MonoAlcoholBM_16)
PIMA_MonoAlcoholBM <- as.data.frame(aictab(cand.set = Cand_models_PIMA_MonoAlcoholBM))
# Split string
PIMA_MonoAlcoholBM_sep <- separate(PIMA_MonoAlcoholBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_MonoAlcoholBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_MonoAlcoholBM)))
# Merge AICc and R2 tables together
PIMA_MonoAlcoholBM_results <- merge(PIMA_MonoAlcoholBM_sep, PIMA_MonoAlcoholBM_R2, by.x="ModNumber", by.y = "rowname")





# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Monoterpenic Ester Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_MonoEsterBM_1 <- glm(MonoEster ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoEsterBM_2 <- glm(MonoEster ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoEsterBM_3 <- glm(MonoEster ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoEsterBM_4 <- glm(MonoEster ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoEsterBM_5 <- glm(MonoEster ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoEsterBM_6 <- glm(MonoEster ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoEsterBM_7 <- glm(MonoEster ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoEsterBM_8 <- glm(MonoEster ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoEsterBM_9 <- glm(MonoEster ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoEsterBM_10 <- glm(MonoEster ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoEsterBM_11 <- glm(MonoEster ~ LandCover + EVI, data = bS_Phyto_BM)
PIMA_MonoEsterBM_12 <- glm(MonoEster ~ LandCover, data = bS_Phyto_BM)
PIMA_MonoEsterBM_13 <- glm(MonoEster ~ EVI, data = bS_Phyto_BM)
PIMA_MonoEsterBM_14 <- glm(MonoEster ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_MonoEsterBM_15 <- glm(MonoEster ~ Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_MonoEsterBM_16 <- glm(MonoEster ~ 1, data =  bS_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_MonoEsterBM <- list("PIMA_MonoEsterBM_1" = PIMA_MonoEsterBM_1, "PIMA_MonoEsterBM_2" = PIMA_MonoEsterBM_2, "PIMA_MonoEsterBM_3" = PIMA_MonoEsterBM_3, "PIMA_MonoEsterBM_4" = PIMA_MonoEsterBM_4, "PIMA_MonoEsterBM_5" = PIMA_MonoEsterBM_5, "PIMA_MonoEsterBM_6" = PIMA_MonoEsterBM_6, "PIMA_MonoEsterBM_7" = PIMA_MonoEsterBM_7, "PIMA_MonoEsterBM_8" =  PIMA_MonoEsterBM_8, "PIMA_MonoEsterBM_9" = PIMA_MonoEsterBM_9, "PIMA_MonoEsterBM_10" = PIMA_MonoEsterBM_10, "PIMA_MonoEsterBM_11" = PIMA_MonoEsterBM_11, "PIMA_MonoEsterBM_12" = PIMA_MonoEsterBM_12, "PIMA_MonoEsterBM_13" = PIMA_MonoEsterBM_13, "PIMA_MonoEsterBM_14" = PIMA_MonoEsterBM_14, "PIMA_MonoEsterBM_15" = PIMA_MonoEsterBM_15, "PIMA_MonoEsterBM_16" = PIMA_MonoEsterBM_16)
PIMA_MonoEsterBM <- as.data.frame(aictab(cand.set = Cand_models_PIMA_MonoEsterBM))
# Split string
PIMA_MonoEsterBM_sep <- separate(PIMA_MonoEsterBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_MonoEsterBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_MonoEsterBM)))
# Merge AICc and R2 tables together
PIMA_MonoEsterBM_results <- merge(PIMA_MonoEsterBM_sep, PIMA_MonoEsterBM_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Sesquiterpene Models ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_SesquiterpeneBM_1 <- glm(Sesquiterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_2 <- glm(Sesquiterpene ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_3 <- glm(Sesquiterpene ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_4 <- glm(Sesquiterpene ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_5 <- glm(Sesquiterpene ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_6 <- glm(Sesquiterpene ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_7 <- glm(Sesquiterpene ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_8 <- glm(Sesquiterpene ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_9 <- glm(Sesquiterpene ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_10 <- glm(Sesquiterpene ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_11 <- glm(Sesquiterpene ~ LandCover + EVI, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_12 <- glm(Sesquiterpene ~ LandCover, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_13 <- glm(Sesquiterpene ~ EVI, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_14 <- glm(Sesquiterpene ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_15 <- glm(Sesquiterpene ~ Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_SesquiterpeneBM_16 <- glm(Sesquiterpene ~ 1, data =  bS_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_SesquiterpeneBM <- list("PIMA_SesquiterpeneBM_1" = PIMA_SesquiterpeneBM_1, "PIMA_SesquiterpeneBM_2" = PIMA_SesquiterpeneBM_2, "PIMA_SesquiterpeneBM_3" = PIMA_SesquiterpeneBM_3, "PIMA_SesquiterpeneBM_4" = PIMA_SesquiterpeneBM_4, "PIMA_SesquiterpeneBM_5" = PIMA_SesquiterpeneBM_5, "PIMA_SesquiterpeneBM_6" = PIMA_SesquiterpeneBM_6, "PIMA_SesquiterpeneBM_7" = PIMA_SesquiterpeneBM_7, "PIMA_SesquiterpeneBM_8" =  PIMA_SesquiterpeneBM_8, "PIMA_SesquiterpeneBM_9" = PIMA_SesquiterpeneBM_9, "PIMA_SesquiterpeneBM_10" = PIMA_SesquiterpeneBM_10, "PIMA_SesquiterpeneBM_11" = PIMA_SesquiterpeneBM_11, "PIMA_SesquiterpeneBM_12" = PIMA_SesquiterpeneBM_12, "PIMA_SesquiterpeneBM_13" = PIMA_SesquiterpeneBM_13, "PIMA_SesquiterpeneBM_14" = PIMA_SesquiterpeneBM_14, "PIMA_SesquiterpeneBM_15" = PIMA_SesquiterpeneBM_15, "PIMA_SesquiterpeneBM_16" = PIMA_SesquiterpeneBM_16)
PIMA_SesquiterpeneBM <- as.data.frame(aictab(cand.set = Cand_models_PIMA_SesquiterpeneBM))
# Split string
PIMA_SesquiterpeneBM_sep <- separate(PIMA_SesquiterpeneBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_SesquiterpeneBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_SesquiterpeneBM)))
# Merge AICc and R2 tables together
PIMA_SesquiterpeneBM_results <- merge(PIMA_SesquiterpeneBM_sep, PIMA_SesquiterpeneBM_R2, by.x="ModNumber", by.y = "rowname")








# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Diversity Models #### Not included in final product as it is exactly the same as the raw models
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
PIMA_DiversityBM_1 <- glm(Diversity ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_DiversityBM_2 <- glm(Diversity ~ EVI + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_DiversityBM_3 <- glm(Diversity ~ LandCover + AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_DiversityBM_4 <- glm(Diversity ~ LandCover + EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_DiversityBM_5 <- glm(Diversity ~ LandCover + EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_DiversityBM_6 <- glm(Diversity ~ LandCover + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_DiversityBM_7 <- glm(Diversity ~ EVI + AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_DiversityBM_8 <- glm(Diversity ~ LandCover + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_DiversityBM_9 <- glm(Diversity ~ EVI + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_DiversityBM_10 <- glm(Diversity ~ AgeClss + HghtCls + CrwnDns + Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_DiversityBM_11 <- glm(Diversity ~ LandCover + EVI, data = bS_Phyto_BM)
PIMA_DiversityBM_12 <- glm(Diversity ~ LandCover, data = bS_Phyto_BM)
PIMA_DiversityBM_13 <- glm(Diversity ~ EVI, data = bS_Phyto_BM)
PIMA_DiversityBM_14 <- glm(Diversity ~ AgeClss + HghtCls + CrwnDns, data = bS_Phyto_BM)
PIMA_DiversityBM_15 <- glm(Diversity ~ Aspect + Slope + Elevation, data = bS_Phyto_BM)
PIMA_DiversityBM_16 <- glm(Diversity ~ 1, data =  bS_Phyto_BM)

# Create an AICc table to show the "best model" to use as a prediction 
Cand_models_PIMA_DiversityBM <- list("PIMA_DiversityBM_1" = PIMA_DiversityBM_1, "PIMA_DiversityBM_2" = PIMA_DiversityBM_2, "PIMA_DiversityBM_3" = PIMA_DiversityBM_3, "PIMA_DiversityBM_4" = PIMA_DiversityBM_4, "PIMA_DiversityBM_5" = PIMA_DiversityBM_5, "PIMA_DiversityBM_6" = PIMA_DiversityBM_6, "PIMA_DiversityBM_7" = PIMA_DiversityBM_7, "PIMA_DiversityBM_8" =  PIMA_DiversityBM_8, "PIMA_DiversityBM_9" = PIMA_DiversityBM_9, "PIMA_DiversityBM_10" = PIMA_DiversityBM_10, "PIMA_DiversityBM_11" = PIMA_DiversityBM_11, "PIMA_DiversityBM_12" = PIMA_DiversityBM_12, "PIMA_DiversityBM_13" = PIMA_DiversityBM_13, "PIMA_DiversityBM_14" = PIMA_DiversityBM_14, "PIMA_DiversityBM_15" = PIMA_DiversityBM_15, "PIMA_DiversityBM_16" = PIMA_DiversityBM_16)
PIMA_DiversityBM <- as.data.frame(aictab(cand.set = Cand_models_PIMA_DiversityBM))
# Split string
PIMA_DiversityBM_sep <- separate(PIMA_DiversityBM, Modnames, into = c("Species", "Trait", "ModNumber"), sep = "_")
# Get Elfron's R2 for model set
PIMA_DiversityBM_R2<- rownames_to_column(as.data.frame(accuracy(Cand_models_PIMA_DiversityBM)))
# Merge AICc and R2 tables together
PIMA_DiversityBM_results <- merge(PIMA_DiversityBM_sep, PIMA_DiversityBM_R2, by.x="ModNumber", by.y = "rowname")







# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#### Combine all AIC results #####
# Stack percent elemental AIC tables
PercentElemental_AIC_all <- rbind(ABBA_C_results, ABBA_N_results, ABBA_P_results, ACRU_C_results, ACRU_N_results, ACRU_P_results, BEPA_C_results, BEPA_N_results, BEPA_P_results, PIMA_C_results, PIMA_N_results, PIMA_P_results, VAAN_C_results, VAAN_N_results, VAAN_P_results)
PercentElemental_AIC_all$TraitType <- "Elemental: percent"

# Stack quantity elemental AIC tables
Quantity_AIC_all <- rbind(ABBA_Qty_C_results, ABBA_Qty_N_results, ABBA_Qty_P_results, ACRU_Qty_C_results, ACRU_Qty_N_results, ACRU_Qty_P_results, BEPA_Qty_C_results, BEPA_Qty_N_results, BEPA_Qty_P_results, PIMA_Qty_C_results, PIMA_Qty_N_results, PIMA_Qty_P_results, VAAN_Qty_C_results, VAAN_Qty_N_results, VAAN_Qty_P_results)
Quantity_AIC_all$TraitType <- "Elemental: quantity"

# Stack stoichiometry AIC tables
Stoichiometry_AIC_all <- rbind(ABBA_CN_results, ABBA_CP_results, ABBA_NP_results, ACRU_CN_results, ACRU_CP_results, ACRU_NP_results, BEPA_CN_results, BEPA_CP_results, BEPA_NP_results, PIMA_CN_results, PIMA_CP_results, PIMA_NP_results, VAAN_CN_results, VAAN_CP_results, VAAN_NP_results)
Stoichiometry_AIC_all$TraitType <- "Stoichiometric"

# Stack phytochemical AIC tables
Phytochemical_AIC_all <- rbind(ABBA_TerpeneRaw_results, ABBA_MonoterpeneRaw_results, ABBA_MonoAlcoholRaw_results, ABBA_MonoEsterRaw_results, ABBA_SesquiterpeneRaw_results, ABBA_DiversityRaw_results, ABBA_TerpeneBM_results, ABBA_MonoterpeneBM_results, ABBA_MonoAlcoholBM_results, ABBA_MonoEsterBM_results, ABBA_SesquiterpeneBM_results, PIMA_TerpeneRaw_results, PIMA_MonoterpeneRaw_results, PIMA_MonoAlcoholRaw_results, PIMA_MonoEsterRaw_results, PIMA_SesquiterpeneRaw_results, PIMA_DiversityRaw_results, PIMA_TerpeneBM_results, PIMA_MonoterpeneBM_results, PIMA_MonoAlcoholBM_results, PIMA_MonoEsterBM_results, PIMA_SesquiterpeneBM_results)
Phytochemical_AIC_all$TraitType <- "Phytochemical"

# Combine all AIC tables
AIC_Data <- rbind(PercentElemental_AIC_all, Quantity_AIC_all, Stoichiometry_AIC_all, Phytochemical_AIC_all)
# Load model descriptions
ModelDescription <- read.csv("Data/Outputs/ModelDescriptions.csv")
# Merge AIC tables and model descriptions together
AIC_ModelDescriptions <- merge(AIC_Data, ModelDescription, by.x="ModNumber", by.y="ModelNumber", all.x=T)

# Change variable names 
unique(AIC_ModelDescriptions$Trait)
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "TerpeneRaw"] <- "Terpene (raw)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "MonoterpeneRaw"] <- "Monoterpene (raw)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "MonoAlcoholRaw"] <- "Monoterpenic alcohol (raw)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "MonoEsterRaw"] <- "Monoterpenic ester (raw)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "SesquiterpeneRaw"] <- "Sesquiterpene (raw)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "DiversityRaw"] <- "Diversity (raw)"

AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "TerpeneBM"] <- "Terpene (bm)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "MonoterpeneBM"] <- "Monoterpene (bm)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "MonoAlcoholBM"] <- "Monoterpenic alcohol (bm)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "MonoEsterBM"] <- "Monoterpenic ester (bm)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "SesquiterpeneBM"] <- "Sesquiterpene (bm)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "DiversityBM"] <- "Diversity (bm)"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "CN"] <- "C:N ratio"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "CP"] <- "C:P ratio"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "NP"] <- "N:P ratio"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "QtyC"] <- "Qty C"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "QtyN"] <- "Qty N"
AIC_ModelDescriptions$Trait[AIC_ModelDescriptions$Trait == "QtyP"] <- "Qty P"

# Change field names 
str(AIC_ModelDescriptions)
colnames(AIC_ModelDescriptions)[colnames(AIC_ModelDescriptions)=="Delta_AICc"] <- "DeltaAICc"
colnames(AIC_ModelDescriptions)[colnames(AIC_ModelDescriptions)=="AICcWt"] <- "WeightsAICc"
colnames(AIC_ModelDescriptions)[colnames(AIC_ModelDescriptions)=="R.squared"] <- "R2"
colnames(AIC_ModelDescriptions)[colnames(AIC_ModelDescriptions)=="Fit.criteria.Efron.r.squared"] <- "R2"

# Export AIC table
write.csv(AIC_ModelDescriptions, "Deliverables/AIC_ModelResults/AIC_Tables_ForMS/AIC_Table_all.csv")
str(AIC_ModelDescriptions)
# Subset
AIC_sub <- subset(AIC_ModelDescriptions, select=c(ModNumber, TraitType, Trait, Species, ExplanatoryVariables, K, LL, DeltaAICc, WeightsAICc, R2))
str(AIC_sub)

# Subset for top models
AIC_Pars <- subset(AIC_sub, AIC_sub$DeltaAICc < 2)
str(AIC_Parsimony)


write.csv(AIC_Pars, "Deliverables/AIC_ModelResults/AIC_Tables_ForMS/AIC_TwoDeltaAIC.csv") # Add columns to identify PV, variables above the null, and whether to include data point in AIC table and figures.


###### Make AIC figure ######
# Load AIC table with parsimonious models with pretending variable identified
AIC_Parsimony <- read.csv("Deliverables/AIC_ModelResults/AIC_Tables_ForMS/AIC_TwoDeltaAIC_ID_PV_NullWins_Final.csv", stringsAsFactors = F)

# Change diversity to indicate we computed on a raw basis
AIC_Parsimony$Trait[AIC_Parsimony$Trait == "Diversity (raw)"] <- "Phytochemical diversity (raw)"

# Set factor level for explanatory variables
unique(AIC_Parsimony$ExplanatoryVariables)
AIC_Parsimony$ExplanatoryVariables <- factor(AIC_Parsimony$ExplanatoryVariables, levels = c("Land Cover + EVI + Biotic + Abiotic", "EVI + Biotic + Abiotic", "Land Cover + Biotic + Abiotic", "Land Cover + EVI + Abiotic", "Land Cover + EVI + Biotic", "Land Cover + Biotic", "EVI + Biotic", "Land Cover + Abiotic", "EVI + Abiotic", "Biotic + Abiotic", "Land Cover + EVI", "Land Cover", "EVI", "Biotic", "Abiotic", "Intercept" ))

# Subset to remove top ranked models with pretending variables (this field was set manually in excel)
AIC_ParsimonySub <- subset(AIC_Parsimony, AIC_Parsimony$AIC_TabInclude =="Y")

# Make Trait Type Plot
ExVarLegend <- c("Land Cover + EVI + Biotic + Abiotic" = "pink4", "EVI + Biotic + Abiotic" = "#F3C300", "Land Cover + Biotic + Abiotic" = "#875692", "Land Cover + EVI + Abiotic" = "#F38400", "Land Cover + EVI + Biotic" = "#A1CAF1", "Land Cover + Biotic" = "#BE0032", "EVI + Biotic" = "#C2B280", "Land Cover + Abiotic" = "#848482", "EVI + Abiotic" = "#008856", "Biotic + Abiotic" = "#E25822", "Land Cover + EVI" = "#0067A5", "Land Cover" = "#F99379", "EVI" = "burlywood4", "Biotic" = "#B3446C", "Abiotic" = "#8DB600", "Intercept" = "#882D17")



####### Trait Type Plots #######
# Get count data at the trait type level
TraitTypeCount <- count(AIC_ParsimonySub, c("TraitType", "ExplanatoryVariables"))
# aggreate R-squares by mean per top ranked model
TraitTypeR2 <- aggregate(R2 ~ TraitType + ExplanatoryVariables, data = AIC_ParsimonySub, FUN= "mean" )
# Merge count and R-square data together
TraitType_df <- merge(TraitTypeCount, TraitTypeR2, by.x=c("TraitType", "ExplanatoryVariables"), by.y=c("TraitType", "ExplanatoryVariables"))
# Round R-square
TraitType_df$R2 <-  round(TraitType_df$R2, digits=2)
# Create labels
TraitType_df$Label <- paste0("R² = ",TraitType_df$R2, "\n", "Count = ",TraitType_df$freq)

# Extract unique values and set factor levels
unique(TraitType_df$TraitType)
TraitType_df$TraitType <- factor(TraitType_df$TraitType, levels = c("Elemental: quantity", "Elemental: percent", "Stoichiometric", "Phytochemical"))

# Percent and quantity elemental plot
TraitType_Elemental_Plot <- ggplot(subset(TraitType_df, TraitType == "Elemental: percent" | TraitType == "Elemental: quantity"), aes(y=freq, x=TraitType, label = Label, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + coord_flip() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 16)) +theme(axis.text.y = element_text(size=16, angle=45)) + scale_x_discrete(labels = c("Elemental: percent" = "Elemental\npercent", "Elemental: quantity" = "Elemental\nquantity")) + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1")) + ggtitle("(a)") + theme(plot.margin = unit(c(0.1,0.1,0.1,0.1), "cm")) + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE)

# Stoichiometric plot
TraitType_Stoichiometric_Plot <- ggplot(subset(TraitType_df, TraitType == "Stoichiometric"), aes(y=freq, x=TraitType, label = Label, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + coord_flip() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 16)) +theme(axis.text.y = element_text(size=16, angle=45)) + scale_x_discrete(labels = c("Stoichiometric")) + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1")) + ggtitle("(a)") + theme(plot.margin = unit(c(0.1,0.1,0.1,0.1), "cm")) + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE)

# Phytochemical plot
TraitType_Phytochemical_Plot <- ggplot(subset(TraitType_df, TraitType == "Phytochemical"), aes(y=freq, x=TraitType, label = Label, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + coord_flip() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 16)) +theme(axis.text.y = element_text(size=16, angle=45)) + scale_x_discrete(labels = c("Phytochemical")) + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1")) + ggtitle("(a)") + theme(plot.margin = unit(c(0.1,0.1,0.1,0.1), "cm")) + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE)


####### Trait Plots #######
# Subset data for just elemental: percent data
# Get count data at the trait level
TraitCount <- count(AIC_ParsimonySub, c("Trait", "ExplanatoryVariables"))
# aggreate R-squares by mean per top ranked model
TraitR2 <- aggregate(R2 ~ Trait + ExplanatoryVariables, data = AIC_ParsimonySub, FUN= "mean" )
# Merge count and R-square data together
Trait_df <- merge(TraitCount, TraitR2, by.x=c("Trait", "ExplanatoryVariables"), by.y=c("Trait", "ExplanatoryVariables"))
# Round R-square
Trait_df$R2 <-  round(Trait_df$R2, digits=2)
# Create labels
Trait_df$Label <- paste0("R² = ",Trait_df$R2, "\n", "Count = ",Trait_df$freq)

# Extract unique values and set factor levels
unique(Trait_df$Trait)
Trait_df$Trait <- factor(Trait_df$Trait, levels = c("Phytochemical diversity (raw)", "Sesquiterpene (bm)", "Sesquiterpene (raw)", "Monoterpenic ester (bm)", "Monoterpenic ester (raw)", "Monoterpenic alcohol (raw)", "Monoterpene (bm)", "Monoterpene (raw)", "Terpene (bm)", "Terpene (raw)", "N:P ratio", "C:P ratio", "C:N ratio", "Qty P", "Qty N", "Qty C", "P", "N", "C"))

# Percent elemental plot
Trait_EP_Plot <- ggplot(subset(Trait_df, Trait == "C" | Trait == "N" | Trait == "P"), aes(y=freq, x=Trait, label = Label, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + coord_flip() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 10)) + theme(axis.text.y = element_text(size=10))  + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"), expand=c(0,0)) + ggtitle("(a)") + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE) + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank()) + theme(plot.title = element_text(hjust=0)) + scale_x_discrete(expand=c(0,0))



# Quantity elemental plot
Trait_EQ_Plot <- ggplot(subset(Trait_df, Trait == "Qty C" | Trait == "Qty N" | Trait == "Qty P"), aes(y=freq, x=Trait, label = Label, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + coord_flip() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 10)) + theme(axis.text.y = element_text(size=10))  + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"), expand=c(0,0)) + ggtitle("(b)") + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE)  + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank()) + theme(plot.title = element_text(hjust=0)) + scale_x_discrete(expand=c(0,0))


# Stoichiomety plot
Trait_Stoich_Plot <- ggplot(subset(Trait_df, Trait == "C:N ratio" | Trait == "C:P ratio" | Trait == "N:P ratio"), aes(y=freq, x=Trait, label = Label, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + coord_flip() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 10)) + theme(axis.text.y = element_text(size=12))  + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"),expand=c(0,0)) + ggtitle("(a)") + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE) + scale_x_discrete(labels = c("C:N ratio" = "C:N", "C:P ratio" = "C:P", "N:P ratio" = "N:P"), expand=c(0,0)) + ggtitle("(a)") + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank()) + theme(plot.title = element_text(hjust=0))



# Phytochemical plot 1
# Create Phyto labels
#Trait_df$PhytoLabel <- paste0("R² = ",Trait_df$R2, " Count = ",Trait_df$freq)

Trait_Phyto1_Plot <- ggplot(subset(Trait_df, Trait == "Terpene (raw)" | Trait == "Terpene (bm)" | Trait == "Monoterpene (raw)" | Trait == "Monoterpene (bm)" | Trait == "Monoterpenic alcohol (raw)"), aes(y=freq, x=Trait, label = Label, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + coord_flip() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 10)) + theme(axis.text.y = element_text(size=12))  + geom_bar_text(position="fill", reflow=T, min.size =8, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"), expand = c(0, 0)) + ggtitle("(a)") + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE) + scale_x_discrete(labels = c("Terpene (raw)" = "Tr", "Terpene (bm)" = "Tb", "Monoterpene (raw)" = "Mr", "Monoterpene (bm)" = "Mb", "Monoterpenic alcohol (raw)" = "MAr"), expand = c(0, 0)) + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank()) + theme(plot.title = element_text(hjust=0))



# Phytochemical plot 2
Trait_Phyto2_Plot <- ggplot(subset(Trait_df, Trait == "Monoterpenic ester (raw)" | Trait == "Monoterpenic ester (bm)" | Trait == "Sesquiterpene (raw)" | Trait == "Sesquiterpene (bm)" | Trait == "Phytochemical diversity (raw)"), aes(y=freq, x=Trait, label = Label, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + coord_flip() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 10)) + theme(axis.text.y = element_text(size=12))  + geom_bar_text(position="fill", reflow=T, min.size = 8, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"), expand = c(0, 0)) + ggtitle(" ") + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE) + scale_x_discrete(labels = c("Monoterpenic ester (raw)" = "MEr", "Monoterpenic ester (bm)" = "MEb", "Sesquiterpene (raw)" = "Sr", "Sesquiterpene (bm)" = "Sb", "Phytochemical diversity (raw)" = "D"), expand = c(0, 0)) + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank())


####### Species Plots #######
AIC_Spp <- AIC_ParsimonySub
AIC_Spp$Species <- as.character(AIC_Spp$Species)
AIC_Spp$TraitType <- as.character(AIC_Spp$TraitType)
AIC_Spp$Species[AIC_Spp$Species == "ABBA"] <- "Balsam fir"
AIC_Spp$Species[AIC_Spp$Species == "PIMA"] <- "Black spruce"
AIC_Spp$Species[AIC_Spp$Species == "ACRU"] <- "Red maple"
AIC_Spp$Species[AIC_Spp$Species == "BEPA"] <- "White birch"
AIC_Spp$Species[AIC_Spp$Species == "VAAN"] <- "Lowbush blueberry"

# Set factor level order for explanatory variables
unique(AIC_Spp$ExplanatoryVariables)
AIC_Spp$ExplanatoryVariables <- factor(AIC_Spp$ExplanatoryVariables, levels = c("Land Cover + EVI + Biotic + Abiotic", "EVI + Biotic + Abiotic", "Land Cover + Biotic + Abiotic", "Land Cover + EVI + Abiotic", "Land Cover + EVI + Biotic", "Land Cover + Biotic", "EVI + Biotic", "Land Cover + Abiotic", "EVI + Abiotic", "Biotic + Abiotic", "Land Cover + EVI", "Land Cover", "EVI", "Biotic", "Abiotic", "Intercept" ))

# Create labels
# Get count
Spp_Count <- count(AIC_Spp, c("Species", "TraitType", "ExplanatoryVariables"))
# Get r-squares
Spp_R2 <- aggregate(R2 ~ Species + TraitType + ExplanatoryVariables, data = AIC_Spp, FUN= "mean" ) 
# Merge count and r-squares together
Spp_merge <- merge(Spp_Count, Spp_R2, by.x=c("Species", "TraitType", "ExplanatoryVariables"), by.y=c("Species", "TraitType", "ExplanatoryVariables"))

# Load labels
SppLabels <- read.csv("Figures/ExplanatoryVarAssessment/SpeciesTraits_Labels_UTF8.csv", stringsAsFactor=F)

# Merge all
Spp_df <- merge(Spp_merge, SppLabels, by.x=c("Species", "TraitType", "ExplanatoryVariables"), by.y=c("Species", "TraitType", "ExplanatoryVariables"), all.x=T)
Spp_df$Label <- as.character(Spp_df$Label)
Spp_df$Species <- as.character(Spp_df$Species)

# Round r-squares
Spp_df$R2 <-  round(Spp_df$R2, digits=2)
# Create complete label
Spp_df$VarLabels <- paste0("R² = ", Spp_df$R2, " Count = ", Spp_df$freq, "\n", " ", "\n", Spp_df$FullLabel)

# Set factor level order for species
Spp_df$Species <- factor(Spp_df$Species, levels = c("Balsam fir", "Black spruce", "Red maple", "White birch", "Lowbush blueberry"))

# Species percent elemental plot
Spp_EP_Plot <- ggplot(subset(Spp_df, TraitType == "Elemental: percent"), aes(y=freq, x=Species, label = VarLabels, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + scale_fill_manual(values = ExVarLegend, drop = FALSE) + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 12)) + theme(axis.text.y = element_text(size=10))  + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"), expand=c(0,0)) + ggtitle("(c)") + theme(legend.position = "none") + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank(), axis.ticks=element_blank()) + theme(plot.title = element_text(hjust=0)) + scale_x_discrete(expand=c(0,0))


# Species quantity elemental plot
Spp_EQ_Plot <- ggplot(subset(Spp_df, TraitType == "Elemental: quantity"), aes(y=freq, x=Species, label = VarLabels, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 10)) + theme(axis.text.y = element_text(size=10))  + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"), expand=c(0,0)) + ggtitle("(d)") + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE) + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank(), axis.ticks=element_blank()) + theme(plot.title = element_text(hjust=0)) + scale_x_discrete(expand=c(0,0))



# Species stoichiometry plot
Spp_Stoich_Plot <- ggplot(subset(Spp_df, TraitType == "Stoichiometric"), aes(y=freq, x=Species, label = VarLabels, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity")  + theme_minimal() + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 12)) + theme(axis.text.y = element_text(size=11))  + geom_bar_text(position="fill", reflow=T, min.size = 10, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"), expand=c(0,0)) + scale_x_discrete(expand=c(0,0)) + ggtitle("(b)") + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE) + theme(plot.title = element_text(hjust=0)) + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank(), axis.ticks=element_blank())


# Species phytochemical plot
Spp_Phyto_Plot <- ggplot(subset(Spp_df, TraitType == "Phytochemical"), aes(y=freq, x=Species, label = VarLabels, fill = factor(ExplanatoryVariables))) + geom_bar(position = "fill", stat = "identity") + theme_minimal() + theme(plot.background = element_blank(), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.border = element_blank(), axis.ticks=element_blank()) + scale_x_discrete(expand = c(0, 0)) + theme(axis.title.x = element_blank()) + theme(axis.title.y = element_blank()) + theme(axis.text.x = element_text(size = 12, margin=margin(0,0,0,0))) + theme(axis.text.y = element_text(size=11, margin=margin(0,0,0,0)))  + geom_bar_text(position="fill", reflow=T, min.size = 7, place = "topleft") + theme(legend.position = "none") + scale_y_continuous(label = c("0", "0.25", "0.5", "0.75", "1"), expand = c(0, 0)) + ggtitle("(b)") + theme(legend.position = "none") + scale_fill_manual(values = ExVarLegend, drop = FALSE) + theme(plot.title = element_text(hjust=0))

##### Generic Legend #####
# Create plot to get legend that contains all factor levels 
GGlegend <- ggplot(TraitType_df, aes(y=freq, x=TraitType, fill=ExplanatoryVariables)) + geom_bar(position = "fill", stat = "identity") + scale_fill_manual(values = ExVarLegend) + theme(legend.title = element_blank())+ theme(legend.position = "top")+ theme(plot.margin = unit(c(0,0,0,0), "cm")) + theme(legend.text=element_text(size=12))

g_legend<-function(a.gplot){
  tmp <- ggplot_gtable(ggplot_build(a.gplot))
  leg <- which(sapply(tmp$grobs, function(x) x$name) == "guide-box")
  legend <- tmp$grobs[[leg]]
  return(legend)}


mylegend <- g_legend(GGlegend)




# Elemental plot
tiff("Figures/ExplanatoryVarAssessment/FoliarElementalPlot.tiff", width = 12, height = 8, units = "in", res = 600)
grid.arrange(mylegend, nrow=3, heights=c(0.11, 0.32, 0.6), arrangeGrob(Trait_EP_Plot, Trait_EQ_Plot, ncol=2, widths=c(1.2,0.35)), arrangeGrob(Spp_EP_Plot, Spp_EQ_Plot, ncol=2, widths=c(1.2,0.35)))
dev.off()

# Stoichiometric plot
tiff("Figures/ExplanatoryVarAssessment/FoliarStoichPlot_v1.tiff", width = 12, height = 9, units = "in", res = 600)
grid.arrange(mylegend, Trait_Stoich_Plot, Spp_Stoich_Plot, nrow=3, heights=c(0.12, 0.29, 1))
dev.off()

# Phytochemical
tiff("Figures/ExplanatoryVarAssessment/FoliarPhytoPlot.tiff", width = 12, height = 9, units = "in", res = 600)
grid.arrange(mylegend, arrangeGrob(Trait_Phyto1_Plot, Trait_Phyto2_Plot, ncol=2), Spp_Phyto_Plot, nrow=3, heights=c(0.15, 0.5, 1.2))
dev.off()


###### Make R2 graph for traits and speices #######

R2Data <- AIC_ParsimonySub

BoxPlotLegend <- c("ABBA" = "gray17", "ACRU" = "lightcyan4", "BEPA" = "lightgoldenrod4", "PIMA" = "lightsalmon4", "VAAN" = "darkgreen")


R2Data$TraitType <- factor(R2Data$TraitType, levels = c("Phytochemical", "Stoichiometric", "Elemental: quantity", "Elemental: percent"))




library(ggrepel)

TraitTypePlot <- ggplot(R2Data, aes(TraitType, R2, fill = Species)) + geom_boxplot(alpha=0.7, aes(fill=Species, colour=Species)) + coord_flip() + geom_point(position=position_dodge(width=0.75), aes(fill=Species, colour=Species)) + scale_fill_manual(values = BoxPlotLegend) + scale_color_manual(values=BoxPlotLegend) + theme_classic() +  theme(axis.text.x = element_text(size = 12), axis.text.y = element_text(size = 12), axis.title.y = element_blank(), axis.title.x = element_blank(), legend.text = element_text(size=12), legend.title = element_blank()) + geom_text_repel(aes(label = TraitLabel), position=position_dodge(width = 0.75), min.segment.length
= 0, box.padding = 0.3)

R2DataTraits <- R2Data
R2DataTraits$Trait <- factor(R2DataTraits$Trait, levels = c("Phytochemical diversity (raw)", "Sesquiterpene (bm)", "Sesquiterpene (raw)", "Monoterpenic ester (bm)", "Monoterpenic ester (raw)", "Monoterpenic alcohol (raw)", "Monoterpene (bm)", "Monoterpene (raw)", "Terpene (bm)", "Terpene (raw)", "N:P ratio", "C:P ratio", "C:N ratio", "Qty P", "Qty N", "Qty C", "P", "N", "C"))

R2DataTraits$TraitType <- factor(R2DataTraits$TraitType, levels = c("Elemental: percent", "Elemental: quantity", "Stoichiometric", "Phytochemical"))


TraitPlot <- ggplot(R2DataTraits, aes(Trait, R2)) + geom_boxplot() + coord_flip()  + facet_wrap(~TraitType, scales = "free", strip.position = "top", nrow=2, ncol=2) + geom_point(position=position_dodge(width=0.75), aes(fill=Species, colour=Species)) + scale_fill_manual(values = BoxPlotLegend) + scale_color_manual(values=BoxPlotLegend) + theme_classic() +  theme(axis.text.x = element_text(size = 12), axis.text.y = element_text(size = 12), axis.title.y = element_blank(), axis.title.x = element_blank(), legend.text = element_text(size=12), legend.title = element_blank())


ggarrange(TraitTypePlot, TraitPlot, ncol = 1, nrow=2)

# Create figure
tiff("Figures/ExplanatoryVarAssessment/Efron_Rsquared_ESP_Models_all.tiff", width = 12, height = 9, units = "in", res = 600)
ggarrange(TraitTypePlot, TraitPlot, ncol = 1, nrow=2, labels = c("(a)", "(b)"))
dev.off()



###### Extract min max and mean of r-squares trait type, trait, and species #######
# Define function to get min max and mean
R2_Funs <- function(x) c( Min = min(x), Max = max(x), Mean = mean(x), SD = sd(x))

# Across all traits
R2 <- aggregate(R2 ~ R2, data = AIC_ParsimonySub, FUN=R2_Funs )
colnames(TraitTypeR2)[colnames(TraitTypeR2)=="TraitType"] <- "Variable"

# Trait Type
TraitTypeR2 <- aggregate(R2 ~ TraitType, data = AIC_ParsimonySub, FUN=R2_Funs )
colnames(TraitTypeR2)[colnames(TraitTypeR2)=="TraitType"] <- "Variable"

# Trait
TraitR2 <- aggregate(R2 ~ Trait, data = AIC_ParsimonySub, FUN=R2_Funs )
colnames(TraitR2)[colnames(TraitR2)=="Trait"] <- "Variable"

# Species
SpeciesR2 <- aggregate(R2 ~ Species, data = AIC_ParsimonySub, FUN=R2_Funs )
colnames(SpeciesR2)[colnames(SpeciesR2)=="Species"] <- "Variable"

# Combine them
R2_data <- rbind(TraitTypeR2, TraitR2, SpeciesR2)

write.csv(R2_data, "Deliverables/RSquared_Averaged/R2_min_max_mean_sd.csv")


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
###### Co-efficient tables for top models ######
# Combine all model diagnostic plots
# Export model diagnostic plots
library(sjPlot)

CorLabels <- c("(Intercept)" = "Intercept", "LandCover5" = "LandCover5", "LandCover6" = "LandCover6", "EVI" = "EVI", "AgeClss3" = "AgeClss3", "AgeClss4" = "AgeClss4", "AgeClss5" = "AgeClss5", "HghtCls3" = "HghtCls3", "HghtCls4" = "HghtCls4", "HghtCls5" = "HghtCls5", "CrwnDns2" = "CrwnDns2", "CrwnDns3" = "CrwnDns3",  "CrwnDns4" = "CrwnDns4",  "Aspect" = "Aspect", "Slope" = "Slope", "Elevation" = "Elvation")

# Carbon
C_Models <- list(ABBA_C15, ABBA_C9, ACRU_C15, ACRU_C9, BEPA_C14, PIMA_C10, PIMA_C3, VAAN_C3, VAAN_C1)
C_Models_Name <- c("ABBA 15", "ABBA 9", "ACRU 15", "ACRU 9", "BEPA 14", "PIMA 10", "PIMA 3", "VAAN 3", "VAAN 1")
# Elemental: Percent carbon
tab_model(C_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = C_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/C_Models.doc")
# Nitrogen
N_Models <- list(ABBA_N4, ACRU_N6, ACRU_N5, PIMA_N7, VAAN_N13, VAAN_N11)
N_Models_Name <- c("ABBA 4", "ACRU 6", "ACRU 5", "PIMA 7", "VAAN 13", "VAAN 11")
# Elemental: Percent carbon
tab_model(N_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = N_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/N_Models.doc" )

# Phosphorus
P_Models <- list(ABBA_P15, ACRU_P13, ACRU_P9, PIMA_P10, PIMA_P2, VAAN_P7, VAAN_P14)
P_Models_Name <- c("ABBA 15", "ACRU 13", "ACRU 9", "PIMA 10", "PIMA 2", "VAAN 7", "VAAN 14")
# Elemental: Percent carbon
tab_model(P_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = P_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/P_Models.doc" )


# Quantity 
Qty_Models <- list(ABBA_Qty_C10, VAAN_Qty_C8, ABBA_Qty_N10, VAAN_Qty_N8, VAAN_Qty_N4, ABBA_Qty_P10, VAAN_Qty_P8)
Qty_Models_Name <- c("ABBA QtyC 10", "VAAN QtyC 8", "ABBA QtyN 10", "VAAN QtyN 8", "VAAN QtyN 4", "ABBA QtyP 10", "VAANQtyP 8")
# Elemental: Percent carbon
tab_model(Qty_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = Qty_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/Qty_Models.doc" )


# Stoichiometric C:N 
CN_Models <- list(ABBA_CN4, ACRU_CN6, ACRU_CN5, PIMA_CN7, VAAN_CN13, VAAN_CN11)
CN_Models_Name <- c("ABBA 4", "ACRU 6", "ACRU 5", "PIMA 7", "VAAN 13", "VAAN 11")
# Elemental: Percent carbon
tab_model(CN_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = CN_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/CN_Models.doc" )

# Stoichiometric C:P 
CP_Models <- list(ABBA_CP15, PIMA_CP10, PIMA_CP2, VAAN_CP14, VAAN_CP7)
CP_Models_Name <- c("ABBA 15", "PIMA 10", "PIMA 2", "VAAN 14", "VAAN 7")
# Elemental: Percent carbon
tab_model(CP_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = CP_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/CP_Models.doc" )


# Stoichiometric C:P 
CP_Models <- list(ABBA_CP15, PIMA_CP10, PIMA_CP2, VAAN_CP14, VAAN_CP7)
CP_Models_Name <- c("ABBA 15", "PIMA 10", "PIMA 2", "VAAN 14", "VAAN 7")
# Elemental: Percent carbon
tab_model(CP_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = CP_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/CP_Models.doc" )


# Stoichiometric N:P 
NP_Models <- list(ACRU_NP9, PIMA_NP2, VAAN_NP2, VAAN_NP7, VAAN_NP1, VAAN_NP5)
NP_Models_Name <- c("ACRU 9", "PIMA 2", "VAAN 2", "VAAN 7", "VAAN 1", "VAAN 5")
# Elemental: Percent carbon
tab_model(NP_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = NP_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/NP_Models.doc" )

# Phytochemical part 1
Phyto1_Models <- list(ABBA_TerpeneRaw_13, PIMA_TerpeneRaw_2, PIMA_TerpeneRaw_10, ABBA_TerpeneBM_10 , ABBA_MonoterpeneRaw_9, ABBA_MonoterpeneRaw_15, ABBA_MonoterpeneRaw_13, PIMA_MonoterpeneRaw_10, ABBA_MonoterpeneBM_10)
Phyto1_Models_Name <- c("ABBA Terpene 13r", "PIMA Terpene 2r", "PIMA Terpene 10r", "ABBA Terpene 10b", "ABBA Monoterpene 9r", "ABBA Monoterpene 15r", "ABBA Monoterpene 13r", "PIMA Monoterpene 10r", "ABBA Monoterpene 10b")
# Elemental: Percent carbon
tab_model(Phyto1_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = Phyto1_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/Phyto1_Models.doc" )


# Phytochemical part 2
Phyto2_Models <- list(PIMA_MonoAlcoholRaw_10, PIMA_MonoEsterRaw_10, PIMA_MonoEsterRaw_2, ABBA_MonoEsterBM_10)
Phyto2_Models_Name <- c("PIMA MA 10r", "PIMA ME 10r", "PIMA ME 2r", "ABBA ME 10b")
# Elemental: Percent carbon
tab_model(Phyto2_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = Phyto2_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/Phyto2_Models.doc" )


# Phytochemical part 3
Phyto3_Models <- list(ABBA_SesquiterpeneRaw_9, ABBA_SesquiterpeneRaw_13, ABBA_SesquiterpeneRaw_15, PIMA_SesquiterpeneRaw_4, PIMA_SesquiterpeneRaw_15, PIMA_SesquiterpeneRaw_2, PIMA_SesquiterpeneRaw_9, PIMA_Diversity_12, PIMA_Diversity_14, PIMA_Diversity_13)
Phyto3_Models_Name <- c("ABBA Sesq 9r", "ABBA Sesq 13r", "ABBA Sesq 15r", "PIMA Sesq 4r", "PIMA Sesq 15r", "PIMA Sesq 2r", "PIMA Sesq 9r", "PIMA Phytochemical Diversity 12", "PIMA Phytochemical Diversity 14", "PIMA Phytochemical Diversity 13")
# Elemental: Percent carbon
a <- tab_model(Phyto3_Models, collapse.ci = T, collapse.se = T, string.est = " " , show.r2 = F, show.aicc = F, show.p = F, p.style="asterisk", emph.p = T, dv.labels = Phyto3_Models_Name, show.intercept = T, pred.labels = CorLabels, file = "Deliverables/TopModelCoefficientTables/Phyto3_Models.doc" )





###### Model Diagnostic Plots #####
###### Phytochemical ABBA Raw ##### Not finished - probs don't need these anyhow.
ABBA_TerpeneRaw13_plot <- autoplot(ABBA_TerpeneRaw_13, which =  c(2,1,3,5),label=F) + theme(plot.title = element_text(size=12, hjust=0.5, face="bold")) + labs(subtitle="Terpene ~ EVI (model 13)") + theme(plot.subtitle = element_text(size=9)) + theme(plot.margin = unit(c(0.5,0.3,0,0.5), "cm")) 

ABBA_MonoterpeneRaw9_plot <- autoplot(ABBA_MonoterpeneRaw_9, which = c(2,1,3,5), label=F) + ggtitle("") +xlab("") + ylab("") + labs(subtitle="Monoterpene ~ EVI + Abiotic (model 9)") + theme(plot.subtitle = element_text(size=9)) + theme(plot.margin = unit(c(-0.5,0.3,0,0.2), "cm"))

ABBA_MonoterpeneRaw13_plot <- autoplot(ABBA_MonoterpeneRaw_13, which = c(2,1,3,5), label=F) + ggtitle("") +xlab("") + ylab("") + labs(subtitle="Monoterpene ~ EVI (model 13)") + theme(plot.subtitle = element_text(size=9)) + theme(plot.margin = unit(c(-1,0.3,0,0.2), "cm"))

ABBA_MonoterpeneRaw15_plot <- autoplot(ABBA_MonoterpeneRaw_15, which = c(2,1,3,5), label=F) + ggtitle("") +xlab("") + ylab("") + labs(subtitle="Monoterpene ~ Abiotic (model 15)") + theme(plot.subtitle = element_text(size=9)) + theme(plot.margin = unit(c(-1,0.3,0,0.2), "cm"))

ABBA_SesquiterpeneRaw9_plot <- autoplot(ABBA_SesquiterpeneRaw_9, which = c(2,1,3,5), label=F) + ggtitle("") +xlab("") + ylab("") + labs(subtitle="Sesquiterpene ~ EVI + Abiotic (model 9)") + theme(plot.subtitle = element_text(size=9)) + theme(plot.margin = unit(c(-1,0.3,0,0.2), "cm"))

ABBA_SesquiterpeneRaw13_plot <- autoplot(ABBA_SesquiterpeneRaw_13, which = c(2,1,3,5), label=F) + ggtitle("") +xlab("") + ylab("") + labs(subtitle="Sesquiterpene ~ EVI (model 13)") + theme(plot.subtitle = element_text(size=9)) + theme(plot.margin = unit(c(-1,0.3,0,0.2), "cm"))

ABBA_SesquiterpeneRaw15_plot <- autoplot(ABBA_SesquiterpeneRaw_15, which = c(2,1,3,5), label=F) + ggtitle("") +xlab("") + ylab("") + labs(subtitle="Sesquiterpene ~ Abiotic (model 15)") + theme(plot.subtitle = element_text(size=9)) + theme(plot.margin = unit(c(-1,0.3,0,0.2), "cm"))

png("Deliverables/AIC_ModelResults/Phytochemical/ABBA_Raw/Model_DiagnosticPlots/TerpeneTEST.png", width=14, height=15, units='in', res=600)
plot_grid(plotlist =c(Terpene13_plot@plots, Monoterpene9_plot@plots, Monoterpene13_plot@plots, Monoterpene15_plot@plots, Sesquiterpene9_plot@plots, Sesquiterpene13_plot@plots, Sesquiterpene15_plot@plots), label_y=1, label_x=0.02, labels = "auto", label_size=12, ncol=4)
dev.off()




# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
###### Make Rasters #######
# Load raster covariate data 
Aspect <- raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/Aspect.tif")
Elevation <- raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/Elevation.tif")
EVI <- raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/EVI.tif")
Slope <- raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/Slope.tif")

# Load individual rasters binary layers
LandCover1 <- raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/LandCover1.tif")
LandCover5 <- raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/LandCover5.tif")
LandCover6 <- raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/LandCover6.tif")
AgeClss2 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/AgeClss2.tif")
AgeClss3 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/AgeClss3.tif")
AgeClss4 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/AgeClss4.tif")
AgeClss5 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/AgeClss5.tif")
CrwnDns1 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/CrwnDns1.tif")
CrwnDns2 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/CrwnDns2.tif")
CrwnDns3 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/CrwnDns3.tif")
CrwnDns4 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/CrwnDns4.tif")
HghtCls2 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/HghtCls2.tif")
HghtCls3 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/HghtCls3.tif")
HghtCls4 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/HghtCls4.tif")
HghtCls5 <-raster("Data/Spatial/ForDistributionModelling/FinalRasterStack/HghtCls5.tif")


##### Percent Elemental Rasters #####
ABBA.C.DM <- (52.32705 + (-0.08914  * Aspect) + (0.07259 * Slope) + (0.14122 * Elevation))
writeRaster(ABBA.C.DM, filename="Data/Outputs/PercentElemental_Rasters/ABBA_C.tif", overwrite=TRUE)

ABBA.N.DM <- (0.895126  + (-0.198223 * LandCover5) + (-0.021658 * LandCover6) + (0.035675 * EVI) + (0.017656 * Aspect) + (0.002144 * Slope) + (-0.067326 * Elevation))
writeRaster(ABBA.N.DM, filename="Data/Outputs/PercentElemental_Rasters/ABBA_N.tif", overwrite=TRUE)

ABBA.P.DM <- (0.0758842 + (0.0106312 * Aspect) + (0.0038326 * Slope) + (0.0004091 * Elevation))
writeRaster(ABBA.P.DM, filename="Data/Outputs/PercentElemental_Rasters/ABBA_P.tif", overwrite=TRUE)

ACRU.C.DM <- (50.11956 + (-0.07615 * Aspect) + (-0.11104 * Slope) + (-0.15594 * Elevation))
writeRaster(ACRU.C.DM, filename="Data/Outputs/PercentElemental_Rasters/ACRU_C.tif", overwrite=TRUE)

ACRU.N.DM <- (2.16930 + (-0.31980 * LandCover5) + (-0.10091 * LandCover6) + (-0.44989 * AgeClss3) + (-0.62735 * AgeClss4) + (-0.51203 * AgeClss5) + (0.12021 * HghtCls3) + (0.23452 * HghtCls4) + (0.43098 * HghtCls5) + (-0.18302 * CrwnDns2) + (-0.25415 * CrwnDns3) + (-0.29745 * CrwnDns4))
writeRaster(ACRU.N.DM, filename="Data/Outputs/PercentElemental_Rasters/ACRU_N.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
ACRU.P.modavg <- model.avg(object = list(ACRU.P13, ACRU.P9))
summary(ACRU.P.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
ACRU.P.modavg.summary <- summary(ACRU.P.modavg)$coefficients
write.csv(ACRU.P.modavg.summary, "Deliverables/AIC_ModelResults/PercentElemental/ModelAverages/ACRU_P_ModelSummary.csv")
ACRU.P.DM <- (0.136813 + (-0.012178 * Aspect) + (0.003208 * Slope) + (0.005303 * Elevation))
writeRaster(ACRU.P.DM, filename="Data/Outputs/PercentElemental_Rasters/ACRU_P.tif", overwrite=TRUE)

BEPA.C.DM <- (51.0048 + (1.2491 * AgeClss3) + (0.7076  * AgeClss4) + (0.7805 * AgeClss5) + (-1.3895 * HghtCls3) + (-0.8003 * HghtCls4) + (-0.9843 * HghtCls5) + (-0.3594 * CrwnDns2) + (-0.6033 * CrwnDns3))
writeRaster(BEPA.C.DM, filename="Data/Outputs/PercentElemental_Rasters/BEPA_C.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
PIMA.C.modavg <- model.avg(object = list(PIMA.C10, PIMA.C3))
summary(PIMA.C.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
PIMA.C.modavg.summary <- summary(PIMA.C.modavg)$coefficients
write.csv(PIMA.C.modavg.summary, "Deliverables/AIC_ModelResults/PercentElemental/ModelAverages/PIMA_C_ModelSummary.csv")
PIMA.C.DM <- (50.14157 + (2.00553 * AgeClss3) + (2.76762 * AgeClss4) + (2.46166 * AgeClss5) + (-0.46944 * HghtCls3) + (-0.10270 * HghtCls4) + (-0.04016 * HghtCls5) + (0.09779 * CrwnDns2) + (-0.58641 * CrwnDns3) + (-0.08627 * CrwnDns4) + (0.14765 * Aspect) + (0.26076 * Slope) + (0.27133 * Elevation) + (-0.06364 * LandCover5) + (-0.25412 * LandCover6))
writeRaster(PIMA.C.DM, filename="Data/Outputs/PercentElemental_Rasters/PIMA_C.tif", overwrite=TRUE)

PIMA.N.DM <- (0.83966 + (0.04503 * EVI) + (-0.15520 * AgeClss3) + (-0.08319 * AgeClss4) + (-0.07399 * AgeClss5) + (0.14243 * HghtCls3) + (0.08542 * HghtCls4) + (0.17220 * HghtCls5) + (0.09280 * CrwnDns2) + (0.06290 * CrwnDns3) + (0.02469 * CrwnDns4))
writeRaster(PIMA.N.DM, filename="Data/Outputs/PercentElemental_Rasters/PIMA_N.tif", overwrite=TRUE)

PIMA.P.DM <- (0.1260640 + (-0.0623396 * AgeClss3) + (-0.0095660 * AgeClss4) + (-0.0199530 * AgeClss5) + (0.0204160 * HghtCls3) + (0.0006607 * HghtCls4) + (0.0206744 * HghtCls5) + (0.0143824 * CrwnDns2) + (0.0108988 * CrwnDns3) + (-0.0041570 * CrwnDns4) + (0.0003358 * Aspect) + (0.0073696 * Slope) + (0.0099140 * Elevation))
writeRaster(PIMA.P.DM, filename="Data/Outputs/PercentElemental_Rasters/PIMA_P.tif", overwrite=TRUE)

VAAN.C.DM <- (52.44842 + (-0.39548 * LandCover5) + (-0.44238 * LandCover6) + (0.34093 * AgeClss3) + (0.08421 * AgeClss4) + (0.26946 * AgeClss5) + (-0.49292 * HghtCls3) + (-0.31264 * HghtCls4) + (-0.24375 * HghtCls5) + (-0.07234 * CrwnDns2) + (0.19732 * CrwnDns3) + (0.13507 * CrwnDns4) + (-0.05121 * Aspect) + (0.16315 * Slope) + (0.07611 * Elevation))
writeRaster(VAAN.C.DM, filename="Data/Outputs/PercentElemental_Rasters/VAAN_C.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
VAAN.N.modavg <- model.avg(object = list(VAAN.N13, VAAN.N11))
summary(VAAN.N.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
VAAN.N.modavg.summary <- summary(VAAN.N.modavg)$coefficients
write.csv(VAAN.N.modavg.summary, "Deliverables/AIC_ModelResults/PercentElemental/ModelAverages/VAAN_N_ModelSummary.csv")
VAAN.N.DM <- (1.280858 + (0.057608 * EVI) + (-0.067034 * LandCover5) + (-0.007292 * LandCover6))
writeRaster(VAAN.N.DM, filename="Data/Outputs/PercentElemental_Rasters/VAAN_N.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
VAAN.P.modavg <- model.avg(object = list(VAAN.P7, VAAN.P14))
summary(VAAN.P.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
VAAN.P.modavg.summary <- summary(VAAN.P.modavg)$coefficients
write.csv(VAAN.P.modavg.summary, "Deliverables/AIC_ModelResults/PercentElemental/ModelAverages/VAAN_P_ModelSummary.csv")
VAAN.P.DM <- (0.11639966699265 + (-0.00287056604819193 * EVI) + (-0.0396351273147469 * AgeClss3) + (-0.0365657415858059 * AgeClss4) + (-0.0357922323324048 * AgeClss5) + (-0.00217644742466776 * HghtCls3) + (-0.00393675203096597 * HghtCls4) + (0.00198845050000526 * HghtCls5) + (0.0000483419169232743 * CrwnDns2) + (-0.00200646149314469 * CrwnDns3) + (-0.0113280589171474 * CrwnDns4))
writeRaster(VAAN.P.DM, filename="Data/Outputs/PercentElemental_Rasters/VAAN_P.tif", overwrite=TRUE)



##### Quantity Elemental Rasters ######
ABBA.QtyC.DM <- (4.07493 + (-2.52985 * AgeClss3) + (-1.77097 * AgeClss4) + (-2.17096 * AgeClss5) + (-1.80557 * HghtCls3) + (-1.25707 * HghtCls4) + (-1.44275 * HghtCls5) + (-0.08495 * CrwnDns2) + (0.39142 * CrwnDns3) + (1.67577 * CrwnDns4) + (-0.28921 * Aspect) + (0.66870 * Slope) + (0.14883 * Elevation))
ABBA.QtyC.DM[ABBA.QtyC.DM < 0] <- NA
writeRaster(ABBA.QtyC.DM, filename="Data/Outputs/Quantity_Rasters/ABBA_QtyC.tif", overwrite=TRUE)

ABBA.QtyN.DM <- (0.070192 + (-0.044110 * AgeClss3) + (-0.031932 * AgeClss4) + (-0.039920 * AgeClss5) + (-0.029573 * HghtCls3) + (-0.019443 * HghtCls4) + (-0.023221 * HghtCls5) + (-0.002028 * CrwnDns2) + (0.005909 * CrwnDns3) + (0.022122 * CrwnDns4) + (-0.003338 * Aspect) + (0.011774 * Slope) + (0.002358 * Elevation))
ABBA.QtyN.DM[ABBA.QtyN.DM < 0] <- NA
writeRaster(ABBA.QtyN.DM, filename="Data/Outputs/Quantity_Rasters/ABBA_QtyN.tif", overwrite=TRUE)

ABBA.QtyP.DM <- (0.005624 + (-0.003441 * AgeClss3) + (-0.001889 * AgeClss4) + (-0.003247 * AgeClss5) + (-0.002666 * HghtCls3) + (-0.001796 * HghtCls4) + (-0.002247 * HghtCls5) + (0.00008272 * CrwnDns2) + (0.0007486 * CrwnDns3) + (0.001817 * CrwnDns4) + (0.00001488 * Aspect) + (0.001222 * Slope) + (0.003443 * Elevation))
ABBA.QtyP.DM[ABBA.QtyP.DM < 0] <- NA
writeRaster(ABBA.QtyP.DM, filename="Data/Outputs/Quantity_Rasters/ABBA_QtyP.tif", overwrite=TRUE)

VAAN.QtyC.DM <- (1.57778 + (7.26713 * LandCover5) + (0.05806 * LandCover6) + (0.25909 * Aspect) + (-0.17413 * Slope) + (1.43826 * Elevation))
VAAN.QtyC.DM[VAAN.QtyC.DM < 0] <- NA
writeRaster(VAAN.QtyC.DM, filename="Data/Outputs/Quantity_Rasters/VAAN_QtyC.tif", overwrite=TRUE)

VAAN.QtyN.DM <- (0.036001 + (0.143207 * LandCover5) + (0.005230 * LandCover6) + (0.007634 * Aspect) + (-0.004535 * Slope) + (0.032442 * Elevation))
VAAN.QtyN.DM[VAAN.QtyN.DM < 0] <- NA
writeRaster(VAAN.QtyN.DM, filename="Data/Outputs/Quantity_Rasters/VAAN_QtyN.tif", overwrite=TRUE)

VAAN.QtyP.DM <- (0.0023433 + (0.0119929 * LandCover5) + (0.0005116 * LandCover6) + (0.0004231 * Aspect) + (-0.0007310 * Slope) + (0.0020505 * Elevation))
VAAN.QtyP.DM[VAAN.QtyP.DM < 0] <- NA
writeRaster(VAAN.QtyP.DM, filename="Data/Outputs/Quantity_Rasters/VAAN_QtyP.tif", overwrite=TRUE)





###### Stoichiometry Rasters #####
summary(ABBA.CN4)
ABBA.CN.DM <- (70.3416 + (15.5577 * LandCover5) + (2.2423 * LandCover6) + (-3.4758 * EVI) + (-1.9894 * Aspect) + (-0.1474 * Slope) + (4.9014 * Elevation))
writeRaster(ABBA.CN.DM, filename="Data/Outputs/Stoichiometry_Rasters/ABBA_CN.tif", overwrite=TRUE)

summary(ABBA.CP15)
ABBA.CP.DM <- (2060.13 + (-251.44  * Aspect) + (-85.87 * Slope) + (69.19 * Elevation))
writeRaster(ABBA.CP.DM, filename="Data/Outputs/Stoichiometry_Rasters/ABBA_CP.tif", overwrite=TRUE)

summary(ACRU.CN6)
ACRU.CN.DM <- (23.769 + (7.796 * LandCover5) + (3.019 * LandCover6) + (12.047 * AgeClss3) + (16.378 * AgeClss4) + (13.514 * AgeClss5) + (-4.604 * HghtCls3) + (-7.477 * HghtCls4) + (-11.936 * HghtCls5) + (4.099 * CrwnDns2) + (6.039 * CrwnDns3) + (6.982 * CrwnDns4))
writeRaster(ACRU.CN.DM, filename="Data/Outputs/Stoichiometry_Rasters/ACRU_CN.tif", overwrite=TRUE)

summary(ACRU.NP9)
ACRU.NP.DM <- (29.4379 + (2.3651 * EVI) + (-1.8703 * Aspect) + (-2.5244 * Slope) + (-3.6695 * Elevation))
ACRU.NP.DM[ACRU.NP.DM < 0] <- NA
writeRaster(ACRU.NP.DM, filename="Data/Outputs/Stoichiometry_Rasters/ACRU_NP.tif", overwrite=TRUE)

summary(PIMA.CN7)
PIMA.CN.DM <- (70.6141 + (-3.2611  * EVI) + (11.7536 * AgeClss3) + (8.0978 * AgeClss4) + (7.4185 * AgeClss5) + (-9.4355 * HghtCls3) + (-5.1013 * HghtCls4) + (-11.4238 * HghtCls5) + (-6.1412 * CrwnDns2) + (-5.2241 * CrwnDns3) + (-1.8954 * CrwnDns4))
writeRaster(PIMA.CN.DM, filename="Data/Outputs/Stoichiometry_Rasters/PIMA_CN.tif", overwrite=TRUE)

summary(PIMA.CP10)
PIMA.CP.DM <- (1050.36 + (660.74 * AgeClss3) + (195.92 * AgeClss4) + (250.32 * AgeClss5) + (-204.19 * HghtCls3) + (-15.32 * HghtCls4) + (-198.13 * HghtCls5) + (-74.85 * CrwnDns2) + (-109.94 * CrwnDns3) + (65.42 * CrwnDns4) + (-17.44 * Aspect) + (-87.56 * Slope) + (-96.17 * Elevation))
PIMA.CP.DM[PIMA.CP.DM < 0] <- NA
writeRaster(PIMA.CP.DM, filename="Data/Outputs/Stoichiometry_Rasters/PIMA_CP.tif", overwrite=TRUE)

summary(PIMA.NP2)
PIMA.NP.DM <- (14.37952 + (1.45288 * EVI) + (6.37643 * AgeClss3) + (2.44540 * AgeClss4) + (2.47630 * AgeClss5) + (-0.54645 * HghtCls3) + (0.93084 * HghtCls4) + (-0.06117 * HghtCls5) + (0.54708 * CrwnDns2) + (-0.52160 * CrwnDns3) + (0.65647 * CrwnDns4) + (-0.42227 * Aspect) + (-1.22209 * Slope) + (-0.88111 * Elevation))
writeRaster(PIMA.NP.DM, filename="Data/Outputs/Stoichiometry_Rasters/PIMA_NP.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
VAAN.CN.modavg <- model.avg(object = list(VAAN.CN13, VAAN.CN11))
summary(VAAN.CN.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
VAAN.CN.modavg.summary <- summary(VAAN.CN.modavg)$coefficients
write.csv(VAAN.CN.modavg.summary, "Deliverables/AIC_ModelResults/Stoichiometry/ModelAverages/VAAN_CN_ModelSummary.csv")
VAAN.CN.DM <- (48.5407 + (-2.3066 * EVI) + (2.3629 * LandCover5) + (0.2396 * LandCover6))
writeRaster(VAAN.CN.DM, filename="Data/Outputs/Stoichiometry_Rasters/VAAN_CN.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
VAAN.CP.modavg <- model.avg(object = list(VAAN.CP14, VAAN.CP7))
summary(VAAN.CP.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
VAAN.CP.modavg.summary <- summary(VAAN.CP.modavg)$coefficients
write.csv(VAAN.CP.modavg.summary, "Deliverables/AIC_ModelResults/Stoichiometry/ModelAverages/VAAN_CP_ModelSummary.csv")
VAAN.CP.DM <- (1212.59 + (626.46 * AgeClss3) + (507.95 * AgeClss4) + (618.69 * AgeClss5) + (18.96 * HghtCls3) + (101.51 * HghtCls4) + (-47.70 * HghtCls5) + (-40.93 * CrwnDns2) + (47.69 * CrwnDns3) + (197.55 * CrwnDns3) + (197.55 * CrwnDns4) + (69.94 * EVI))
writeRaster(VAAN.CP.DM, filename="Data/Outputs/Stoichiometry_Rasters/VAAN_CP.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
VAAN.NP.modavg <- model.avg(object = list(VAAN.NP2, VAAN.NP7, VAAN.NP1, VAAN.NP5))
summary(VAAN.NP.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
VAAN.NP.modavg.summary <- summary(VAAN.NP.modavg)$coefficients
write.csv(VAAN.NP.modavg.summary, "Deliverables/AIC_ModelResults/Stoichiometry/ModelAverages/VAAN_NP_ModelSummary.csv")
VAAN.NP.DM <- (29.24167 + (2.80174 * EVI) + (12.63273 * AgeClss3) + (8.88995 * AgeClss4) + (12.82563 * AgeClss5) + (-1.75447 * HghtCls3) + (0.98314 * HghtCls4) + (-2.57652 * HghtCls5) + (-2.10097 * CrwnDns2) + (-1.15866 * CrwnDns3) + (0.17172 * CrwnDns4) + (-0.69301 * Aspect) + (0.06788 * Slope) + (-0.91010 * Elevation) + (-2.61826 * LandCover5) + (-1.17195 * LandCover6))
writeRaster(VAAN.NP.DM, filename="Data/Outputs/Stoichiometry_Rasters/VAAN_NP.tif", overwrite=TRUE)



###### Phytochemical Rasters #######
###### Balsam fir Raw ######
summary(Total.Terpene13)
ABBA.Total.Terpene.DM <- (13.6917 + (0.7264 * EVI))
writeRaster(ABBA.Total.Terpene.DM, filename="Data/Outputs/Phytochemical_Rasters/ABBA_Total_Terpene.tif", overwrite=TRUE)

ABBA.Total.Monoterpene.DM <- (7.6310 + (0.3531 * EVI) + (-0.0483 * Aspect) + (0.5437 * Slope) + (0.2282 * Elevation))
writeRaster(ABBA.Total.Monoterpene.DM, filename="Data/Outputs/Phytochemical_Rasters/ABBA_Total_Monoterpene.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
ABBA.Total.Sesquiterpene.modavg <- model.avg(object = list(Total.Sesquiterpene9, Total.Sesquiterpene13, Total.Sesquiterpene15))
summary(ABBA.Total.Sesquiterpene.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
ABBA.Total.Sesquiterpene.modavg.summary <- summary(ABBA.Total.Sesquiterpene.modavg)$coefficients
write.csv(ABBA.Total.Sesquiterpene.modavg.summary, "Deliverables/AIC_ModelResults/Phytochemical/ABBA_Raw/ModelAverages/ABBA_Total.Sesquiterpene_ModelSummary.csv")
ABBA.Total.Sesquiterpene.DM <- (1.38288 + (0.06843 * EVI) + (-0.02659 * Aspect) + (-0.03553 * Slope) + (-0.09731 * Elevation))
writeRaster(ABBA.Total.Sesquiterpene.DM, filename="Data/Outputs/Phytochemical_Rasters/ABBA_Raw_Total_Sesquiterpene.tif", overwrite=TRUE)

##### Balsam fir Biomass #####
# Create raster
summary(Total.Terpene10)
ABBA.Total.Terpene.DM <- (73.579 + (-49.733 * AgeClss3) + (-24.130 * AgeClss4) + (-37.934 * AgeClss5) + (-30.517 * HghtCls3) + (-23.450 * HghtCls4) + (-31.169 * HghtCls5) + (3.747 * CrwnDns2) + (12.279 * CrwnDns3) + (46.336 * CrwnDns4) + (-2.227 * Aspect) + (20.402 * Slope) + (7.449 * Elevation))
ABBA.Total.Terpene.DM[ABBA.Total.Terpene.DM < 0] <- NA
writeRaster(ABBA.Total.Terpene.DM, filename="Data/Outputs/Phytochemical_Rasters/ABBA_Biomass_Total_Terpene.tif", overwrite=TRUE)

# Create raster
summary(Total.Monoterpene10)
ABBA.Total.Monoterpene.DM <- (41.282 + (-30.427 * AgeClss3) + (-14.260 * AgeClss4) + (-22.018 * AgeClss5) + (-15.954 * HghtCls3) + (-12.721 * HghtCls4) + (-18.029 * HghtCls5) + (2.669 * CrwnDns2) + (8.559 * CrwnDns3) + (29.786 * CrwnDns4) + (-1.552 * Aspect) + (12.613 * Slope) + (4.551 * Elevation))
ABBA.Total.Monoterpene.DM[ABBA.Total.Monoterpene.DM < 0] <- NA
writeRaster(ABBA.Total.Monoterpene.DM, filename="Data/Outputs/Phytochemical_Rasters/ABBA_Biomass_Total_Monoterpene.tif", overwrite=TRUE)

# Create raster
summary(Bornyl.acetate..Monoterpenic.ester.10)
ABBA.Monoterpenic.ester.DM <- (12.89148 + (-7.81012 * AgeClss3) + (-3.97283 * AgeClss4) + (-6.36154 * AgeClss5) + (-5.77680 * HghtCls3) + (-4.37628 * HghtCls4) + (-5.85586 * HghtCls5) + (0.52750 * CrwnDns2) + (1.88592 * CrwnDns3) + (6.61370 * CrwnDns4) + (-0.05694 * Aspect) + (3.15435 * Slope) + (1.32430 * Elevation))
ABBA.Monoterpenic.ester.DM[ABBA.Monoterpenic.ester.DM < 0] <- NA
writeRaster(ABBA.Monoterpenic.ester.DM, filename="Data/Outputs/Phytochemical_Rasters/ABBA_Biomass_BornylAcetateMonoterpenicEster.DM.tif", overwrite=TRUE)


###### Black spruce Raw ######
# Model average the top models within 2 Delta AIC
PIMA.Total.terpene.modavg <- model.avg(object = list(Total.terpene2, Total.terpene10))
summary(PIMA.Total.terpene.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
PIMA.Total.terpene.modavg.modavg.summary <- summary(PIMA.Total.terpene.modavg)$coefficients
write.csv(PIMA.Total.terpene.modavg.modavg.summary, "Deliverables/AIC_ModelResults/Phytochemical/PIMA_Raw/ModelAverages/PIMA_Total.terpene_ModelSummary.csv")
PIMA.Total.terpene.DM <- (15.6231 + (-0.8275 * EVI) + (9.0456 * AgeClss3) + (5.0333 * AgeClss4) + (5.8253 * AgeClss5) + (-2.6633 * HghtCls3) + (-2.9918 * HghtCls4) + (-2.3978 * HghtCls5) + (1.2105 * CrwnDns2) + (1.5633 * CrwnDns3) + (4.2192 * CrwnDns4) + (-0.1131 * Aspect) + (-1.6038 * Slope) + (-2.5762 * Elevation))
PIMA.Total.terpene.DM[PIMA.Total.terpene.DM < 0] <- NA
writeRaster(PIMA.Total.terpene.DM, filename="Data/Outputs/Phytochemical_Rasters/PIMA_Raw_Total_terpene.tif", overwrite=TRUE)

summary(Total.monoterpene10)
PIMA.Total.monoterpene.DM <- (5.1179 + (2.6577 * AgeClss3) + (2.2881 * AgeClss4) + (1.8312 * AgeClss5) + (-1.0887 * HghtCls3) + (-1.0430 * HghtCls4) + (-0.8616 * HghtCls5) + (0.9021 * CrwnDns2) + (0.7576 * CrwnDns3) + (1.3658 * CrwnDns4) + (-0.1878 * Aspect) + (-0.3761 * Slope) + (-0.6986 * Elevation))
writeRaster(PIMA.Total.monoterpene.DM, filename="Data/Outputs/Phytochemical_Rasters/PIMA_Raw_TotalMonoterpene.tif", overwrite=TRUE)

summary(Total.monoterpenic.alcohol10)
PIMA.Total.monoterpenic.alcohol.DM <- (0.230362 + (0.186101 * AgeClss3) + (0.171858 * AgeClss4) + (0.126849 * AgeClss5) + (-0.079955 * HghtCls3) + (-0.064980 * HghtCls4) + (-0.044627 * HghtCls5) + (0.047470 * CrwnDns2) + (0.044945 * CrwnDns3) + (0.136721 * CrwnDns4) + (-0.001541 * Aspect) + (-0.029789 * Slope) + (-0.025381 * Elevation))
PIMA.Total.monoterpenic.alcohol.DM[PIMA.Total.monoterpenic.alcohol.DM < 0] <- NA
writeRaster(PIMA.Total.monoterpenic.alcohol.DM, filename="Data/Outputs/Phytochemical_Rasters/PIMA_Raw_TotalMonoterpenicAlcohol.tif", overwrite=TRUE)

summary(Total.monoterpenic.ester10)
PIMA.Total.monoterpenic.ester.DM <- (4.3659 + (3.2103 * AgeClss3) + (2.6578 * AgeClss4) + (2.1723 * AgeClss5) + (-1.3290 * HghtCls3) + (-0.9852 * HghtCls4) + (-0.6726 * HghtCls5) + (0.8741 * CrwnDns2) + (0.6890 * CrwnDns3) + (1.1612 * CrwnDns4) + (-0.0839 * Aspect) + (-0.4208 * Slope) + (-0.7280 * Elevation))
PIMA.Total.monoterpenic.ester.DM[PIMA.Total.monoterpenic.ester.DM < 0] <- NA
writeRaster(PIMA.Total.monoterpenic.ester.DM, filename="Data/Outputs/Phytochemical_Rasters/PIMA_Raw_TotalMonoterpenicEster.tif", overwrite=TRUE)

# Model average the top models within 2 Delta AIC
PIMA.Total.sesquiterpene.modavg <- model.avg(object = list(Total.sesquiterpene4, Total.sesquiterpene15, Total.sesquiterpene2, Total.sesquiterpene9))
summary(PIMA.Total.sesquiterpene.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
PIMA.Total.sesquiterpene.modavg.modavg.summary <- summary(PIMA.Total.sesquiterpene.modavg)$coefficients
write.csv(PIMA.Total.sesquiterpene.modavg.modavg.summary, "Deliverables/AIC_ModelResults/Phytochemical/PIMA_Raw/ModelAverages/PIMA_Total.sesquiterpene_ModelSummary.csv")
PIMA.Total.sesquiterpene.DM <-  (0.632280 + (-0.008237 * LandCover5) + (0.042030 * LandCover6) + (-0.032486 * EVI) + (-0.020363 * Aspect) + (-0.030234 * Slope) + (-0.095969 * Elevation) + (0.049659 * AgeClss3) + (-0.011931 * AgeClss4) + (0.027939 * AgeClss5) + (-0.006383 * HghtCls3) + (-0.015209 * HghtCls4) + (-0.013505 * HghtCls5) + ( -0.010091* CrwnDns2) + (-0.006089 * CrwnDns3) + (0.012353 * CrwnDns4))
writeRaster(PIMA.Total.sesquiterpene.DM, filename="Data/Outputs/Phytochemical_Rasters/PIMA_Raw_TotalSesquiterpene.tif", overwrite=TRUE)

# PIMA.Diversity
# Model average the top models within 2 Delta AIC
PIMA.Diversity.modavg <- model.avg(object = list(PIMA_Diversity_12, PIMA_Diversity_14, PIMA_Diversity_13))
summary(PIMA.Diversity.modavg)
# Summary of model averaging results
# Summary of the most parsimonious model
PIMA.Diversity.modavg.summary <- summary(PIMA.Diversity.modavg)$coefficients
write.csv(PIMA.Diversity.modavg.summary, "Deliverables/AIC_ModelResults/ModelAverages/PIMA_Diversity_ModelSummary.csv")
PIMA.Diversity.DM <- (2.2522397 + (0.0128808 * LandCover5) + (0.0194268 * LandCover6) + (-0.0130985 * AgeClss3) + (-0.0262323 * AgeClss4) + (-0.0156639 * AgeClss5) + (0.0144072 * HghtCls3) + (0.0103249 * HghtCls4) + (0.0184404 * HghtCls5) + (-0.0032717 * CrwnDns2) + (-0.0009204 * CrwnDns3) + (-0.0103720 * CrwnDns4) + (0.0019406 * EVI))
writeRaster(PIMA.Diversity.DM, filename="Data/Outputs/RasterOutput/All/PIMA_Diversity.tif", overwrite=TRUE)


###### Black spruce Biomass ######
# No models






##### Compare Raster and Data Stats ######
# Load Rasters as extract data
All_Rasters <- list.files("Data/Outputs/RasterOutput/All/", pattern = '.tif$', full.names=T)
# Stack rasters
RasterStack <- stack(All_Rasters)
# Get summary stats
RasStackSum <- summary(RasterStack)
# Make summary stats as a data frame
RasStack.df <- as.data.frame(RasStackSum)
# Tranpose data
RasStackTrans <- as.data.frame(t(RasStack.df))
# Extract rownames as a variable
RasStack <- rownames_to_column(RasStackTrans)
# Rename columns
colnames(RasStack)[colnames(RasStack)=="rowname"] <- "SpeciesTrait"
colnames(RasStack)[colnames(RasStack)=="Min."] <- "Min"
colnames(RasStack)[colnames(RasStack)=="1st Qu."] <- "Q_one"
colnames(RasStack)[colnames(RasStack)=="3rd Qu."] <- "Q_three"
colnames(RasStack)[colnames(RasStack)=="Max."] <- "Max"

# Change SpeciesTrait variables to something I can use when splitting strings
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "ABBA_Biomass_BornylAcetateMonoterpenicEster"] <- "ABBA_MonoterpenicEsterBM"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "ABBA_Biomass_Total_Monoterpene"] <- "ABBA_MonoterpeneBM"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "ABBA_Biomass_Total_Terpene"] <- "ABBA_TerpeneBM"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "ABBA_Raw_Total_Monoterpene"] <- "ABBA_MonoterpeneRaw"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "ABBA_Raw_Total_Sesquiterpene"] <- "ABBA_SesquiterpeneRaw"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "ABBA_Raw_Total_Terpene"] <- "ABBA_TerpeneRaw"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "PIMA_Raw_Total_terpene"] <- "PIMA_TerpeneRaw"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "PIMA_Raw_TotalMonoterpene"] <- "PIMA_MonoterpeneRaw"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "PIMA_Raw_TotalMonoterpenicAlcohol"] <- "PIMA_MonoterpenicAlcoholRaw"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "PIMA_Raw_TotalMonoterpenicEster"] <- "PIMA_MonoterpenicEsterRaw"
RasStack$SpeciesTrait[RasStack$SpeciesTrait == "PIMA_Raw_TotalSesquiterpene"] <- "PIMA_SesquiterpeneRaw"

# Duplicate SppTrait field
RasStack$Split <- RasStack$SpeciesTrait
# Split the split field
RasStackSplit <- separate(RasStack, Split, into = c("Species", "Trait"), sep = "_")
# Drop NA column
RasStack.data <- subset(RasStackSplit, select=c(SpeciesTrait, Species, Trait, Min, Max, Median, Q_one, Q_three))
str(RasStack.data)





# Load ES data
FoliarData <- read.csv("Data/Outputs/FoliarData/FoliarData.csv")
library(doBy)


# Carbon
Trait_C <- summaryBy(C ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_C$Trait <- "C"
Trait_C$SpeciesTrait <- paste(Trait_C$Species, Trait_C$Trait, sep="_")
colnames(Trait_C)[colnames(Trait_C)=="C.min"] <- "Min"
colnames(Trait_C)[colnames(Trait_C)=="C.max"] <- "Max"
colnames(Trait_C)[colnames(Trait_C)=="C.median"] <- "Median"
colnames(Trait_C)[colnames(Trait_C)=="C.Q_one"] <- "Q_one"
colnames(Trait_C)[colnames(Trait_C)=="C.Q_three"] <- "Q_three"


# Nitrogen
Trait_N <- summaryBy(N ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_N$Trait <- "N"
Trait_N$SpeciesTrait <- paste(Trait_N$Species,Trait_N$Trait, sep="_")
colnames(Trait_N)[colnames(Trait_N)=="N.min"] <- "Min"
colnames(Trait_N)[colnames(Trait_N)=="N.max"] <- "Max"
colnames(Trait_N)[colnames(Trait_N)=="N.median"] <- "Median"
colnames(Trait_N)[colnames(Trait_N)=="N.Q_one"] <- "Q_one"
colnames(Trait_N)[colnames(Trait_N)=="N.Q_three"] <- "Q_three"


# Phosphporus
Trait_P <- summaryBy(P ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_P$Trait <- "P"
Trait_P$SpeciesTrait <- paste(Trait_P$Species, Trait_P$Trait, sep="_")
colnames(Trait_P)[colnames(Trait_P)=="P.min"] <- "Min"
colnames(Trait_P)[colnames(Trait_P)=="P.max"] <- "Max"
colnames(Trait_P)[colnames(Trait_P)=="P.median"] <- "Median"
colnames(Trait_P)[colnames(Trait_P)=="P.Q_one"] <- "Q_one"
colnames(Trait_P)[colnames(Trait_P)=="P.Q_three"] <- "Q_three"


# Qty C
Trait_QtyC <- summaryBy(Qty_C ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_QtyC$Trait <- "QtyC"
Trait_QtyC$SpeciesTrait <- paste(Trait_QtyC$Species, Trait_QtyC$Trait, sep="_")
colnames(Trait_QtyC)[colnames(Trait_QtyC)=="Qty_C.min"] <- "Min"
colnames(Trait_QtyC)[colnames(Trait_QtyC)=="Qty_C.max"] <- "Max"
colnames(Trait_QtyC)[colnames(Trait_QtyC)=="Qty_C.median"] <- "Median"
colnames(Trait_QtyC)[colnames(Trait_QtyC)=="Qty_C.Q_one"] <- "Q_one"
colnames(Trait_QtyC)[colnames(Trait_QtyC)=="Qty_C.Q_three"] <- "Q_three"


# Qty N
Trait_QtyN <- summaryBy(Qty_N ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_QtyN$Trait <- "QtyN"
Trait_QtyN$SpeciesTrait <- paste(Trait_QtyN$Species, Trait_QtyN$Trait, sep="_")
colnames(Trait_QtyN)[colnames(Trait_QtyN)=="Qty_N.min"] <- "Min"
colnames(Trait_QtyN)[colnames(Trait_QtyN)=="Qty_N.max"] <- "Max"
colnames(Trait_QtyN)[colnames(Trait_QtyN)=="Qty_N.median"] <- "Median"
colnames(Trait_QtyN)[colnames(Trait_QtyN)=="Qty_N.Q_one"] <- "Q_one"
colnames(Trait_QtyN)[colnames(Trait_QtyN)=="Qty_N.Q_three"] <- "Q_three"


# Qty P
Trait_QtyP <- summaryBy(Qty_P ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_QtyP$Trait <- "QtyP"
Trait_QtyP$SpeciesTrait <- paste(Trait_QtyP$Species, Trait_QtyP$Trait, sep="_")
colnames(Trait_QtyP)[colnames(Trait_QtyP)=="Qty_P.min"] <- "Min"
colnames(Trait_QtyP)[colnames(Trait_QtyP)=="Qty_P.max"] <- "Max"
colnames(Trait_QtyP)[colnames(Trait_QtyP)=="Qty_P.median"] <- "Median"
colnames(Trait_QtyP)[colnames(Trait_QtyP)=="Qty_P.Q_one"] <- "Q_one"
colnames(Trait_QtyP)[colnames(Trait_QtyP)=="Qty_P.Q_three"] <- "Q_three"


# Qty C:N
Trait_CN <- summaryBy(CNRatio ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_CN$Trait <- "CN"
Trait_CN$SpeciesTrait <- paste(Trait_CN$Species, Trait_CN$Trait, sep="_")
colnames(Trait_CN)[colnames(Trait_CN)=="CNRatio.min"] <- "Min"
colnames(Trait_CN)[colnames(Trait_CN)=="CNRatio.max"] <- "Max"
colnames(Trait_CN)[colnames(Trait_CN)=="CNRatio.median"] <- "Median"
colnames(Trait_CN)[colnames(Trait_CN)=="CNRatio.Q_one"] <- "Q_one"
colnames(Trait_CN)[colnames(Trait_CN)=="CNRatio.Q_three"] <- "Q_three"


# Qty C:P
Trait_CP <- summaryBy(CPRatio ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_CP$Trait <- "CP"
Trait_CP$SpeciesTrait <- paste(Trait_CP$Species, Trait_CP$Trait, sep="_")
colnames(Trait_CP)[colnames(Trait_CP)=="CPRatio.min"] <- "Min"
colnames(Trait_CP)[colnames(Trait_CP)=="CPRatio.max"] <- "Max"
colnames(Trait_CP)[colnames(Trait_CP)=="CPRatio.median"] <- "Median"
colnames(Trait_CP)[colnames(Trait_CP)=="CPRatio.Q_one"] <- "Q_one"
colnames(Trait_CP)[colnames(Trait_CP)=="CPRatio.Q_three"] <- "Q_three"


# Qty N:P
Trait_NP <- summaryBy(NPRatio ~ Species, data = FoliarData, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_NP$Trait <- "NP"
Trait_NP$SpeciesTrait <- paste(Trait_NP$Species, Trait_NP$Trait, sep="_")
colnames(Trait_NP)[colnames(Trait_NP)=="NPRatio.min"] <- "Min"
colnames(Trait_NP)[colnames(Trait_NP)=="NPRatio.max"] <- "Max"
colnames(Trait_NP)[colnames(Trait_NP)=="NPRatio.median"] <- "Median"
colnames(Trait_NP)[colnames(Trait_NP)=="NPRatio.Q_one"] <- "Q_one"
colnames(Trait_NP)[colnames(Trait_NP)=="NPRatio.Q_three"] <- "Q_three"

# Combine ES data
E_P_Data <- rbind(Trait_C, Trait_N, Trait_P)
E_P_Data$TraitType <- "Elemental: percent"

E_Q_Data <- rbind(Trait_QtyC, Trait_QtyN, Trait_QtyP)
E_Q_Data$TraitType <- "Elemental: quantity"

S_Data <- rbind(Trait_CN, Trait_CP, Trait_NP)
S_Data$TraitType <- "Stoichiometric"

ES_Data <- rbind(E_P_Data, E_Q_Data, S_Data) 
View(ES_Data)

# Rinse repeat for phytochemical data 
# ABBA Raw
ABBA.PhytoRaw <- read.csv("Data/Outputs/Phytochemical/ABBA_Phytochemistry.csv")
# Populate with species
ABBA.PhytoRaw$Species <- "ABBA"
# Subset data
ABBA.PhytoRawSub <- subset(ABBA.PhytoRaw, select = c(Species, Total.Terpene, Total.Monoterpene, Total.Sesquiterpene))
# Change names
colnames(ABBA.PhytoRawSub)[colnames(ABBA.PhytoRawSub)=="Total.Terpene"] <- "TerpeneRaw"
colnames(ABBA.PhytoRawSub)[colnames(ABBA.PhytoRawSub)=="Total.Monoterpene"] <- "MonoterpeneRaw"
colnames(ABBA.PhytoRawSub)[colnames(ABBA.PhytoRawSub)=="Total.Sesquiterpene"] <- "SesquiterpeneRaw"

# ABBA Terpene Raw
Trait_ABBA_TerpeneRaw <- summaryBy(TerpeneRaw ~ Species, data = ABBA.PhytoRawSub, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_ABBA_TerpeneRaw$Trait <- "TerpeneRaw"
Trait_ABBA_TerpeneRaw$SpeciesTrait <- paste(Trait_ABBA_TerpeneRaw$Species, Trait_ABBA_TerpeneRaw$Trait, sep="_")
colnames(Trait_ABBA_TerpeneRaw)[colnames(Trait_ABBA_TerpeneRaw)=="TerpeneRaw.min"] <- "Min"
colnames(Trait_ABBA_TerpeneRaw)[colnames(Trait_ABBA_TerpeneRaw)=="TerpeneRaw.max"] <- "Max"
colnames(Trait_ABBA_TerpeneRaw)[colnames(Trait_ABBA_TerpeneRaw)=="TerpeneRaw.median"] <- "Median"
colnames(Trait_ABBA_TerpeneRaw)[colnames(Trait_ABBA_TerpeneRaw)=="TerpeneRaw.Q_one"] <- "Q_one"
colnames(Trait_ABBA_TerpeneRaw)[colnames(Trait_ABBA_TerpeneRaw)=="TerpeneRaw.Q_three"] <- "Q_three"


# ABBA Monoterpene Raw
Trait_ABBA_MonoterpeneRaw <- summaryBy(MonoterpeneRaw ~ Species, data = ABBA.PhytoRawSub, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_ABBA_MonoterpeneRaw$Trait <- "MonoterpeneRaw"
Trait_ABBA_MonoterpeneRaw$SpeciesTrait <- paste(Trait_ABBA_MonoterpeneRaw$Species, Trait_ABBA_MonoterpeneRaw$Trait, sep="_")
colnames(Trait_ABBA_MonoterpeneRaw)[colnames(Trait_ABBA_MonoterpeneRaw)=="MonoterpeneRaw.min"] <- "Min"
colnames(Trait_ABBA_MonoterpeneRaw)[colnames(Trait_ABBA_MonoterpeneRaw)=="MonoterpeneRaw.max"] <- "Max"
colnames(Trait_ABBA_MonoterpeneRaw)[colnames(Trait_ABBA_MonoterpeneRaw)=="MonoterpeneRaw.median"] <- "Median"
colnames(Trait_ABBA_MonoterpeneRaw)[colnames(Trait_ABBA_MonoterpeneRaw)=="MonoterpeneRaw.Q_one"] <- "Q_one"
colnames(Trait_ABBA_MonoterpeneRaw)[colnames(Trait_ABBA_MonoterpeneRaw)=="MonoterpeneRaw.Q_three"] <- "Q_three"


# ABBA Sesquiterpene Raw
Trait_ABBA_SesquiterpeneRaw <- summaryBy(SesquiterpeneRaw ~ Species, data = ABBA.PhytoRawSub, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_ABBA_SesquiterpeneRaw$Trait <- "SesquiterpeneRaw"
Trait_ABBA_SesquiterpeneRaw$SpeciesTrait <- paste(Trait_ABBA_SesquiterpeneRaw$Species, Trait_ABBA_SesquiterpeneRaw$Trait, sep="_")
colnames(Trait_ABBA_SesquiterpeneRaw)[colnames(Trait_ABBA_SesquiterpeneRaw)=="SesquiterpeneRaw.min"] <- "Min"
colnames(Trait_ABBA_SesquiterpeneRaw)[colnames(Trait_ABBA_SesquiterpeneRaw)=="SesquiterpeneRaw.max"] <- "Max"
colnames(Trait_ABBA_SesquiterpeneRaw)[colnames(Trait_ABBA_SesquiterpeneRaw)=="SesquiterpeneRaw.median"] <- "Median"
colnames(Trait_ABBA_SesquiterpeneRaw)[colnames(Trait_ABBA_SesquiterpeneRaw)=="SesquiterpeneRaw.Q_one"] <- "Q_one"
colnames(Trait_ABBA_SesquiterpeneRaw)[colnames(Trait_ABBA_SesquiterpeneRaw)=="SesquiterpeneRaw.Q_three"] <- "Q_three"



# ABBA Biomass
ABBA.PhytoBM <- read.csv("Data/Outputs/Phytochemical/ABBA_BiomassBasis_Phytochemistry.csv")
# Populate with species
ABBA.PhytoBM$Species <- "ABBA"
# Subset data
ABBA.PhytoBMSub <- subset(ABBA.PhytoBM, select = c(Species, Total.Terpene, Total.Monoterpene, Bornyl.acetate..Monoterpenic.ester.))
# Change names
colnames(ABBA.PhytoBMSub)[colnames(ABBA.PhytoBMSub)=="Total.Terpene"] <- "TerpeneBM"
colnames(ABBA.PhytoBMSub)[colnames(ABBA.PhytoBMSub)=="Total.Monoterpene"] <- "MonoterpeneBM"
colnames(ABBA.PhytoBMSub)[colnames(ABBA.PhytoBMSub)=="Bornyl.acetate..Monoterpenic.ester."] <- "MonoterpenicEsterBM"

# ABBA Terpene Biomass
Trait_ABBA_TerpeneBM <- summaryBy(TerpeneBM ~ Species, data = ABBA.PhytoBMSub, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_ABBA_TerpeneBM$Trait <- "TerpeneBM"
Trait_ABBA_TerpeneBM$SpeciesTrait <- paste(Trait_ABBA_TerpeneBM$Species, Trait_ABBA_TerpeneBM$Trait, sep="_")
colnames(Trait_ABBA_TerpeneBM)[colnames(Trait_ABBA_TerpeneBM)=="TerpeneBM.min"] <- "Min"
colnames(Trait_ABBA_TerpeneBM)[colnames(Trait_ABBA_TerpeneBM)=="TerpeneBM.max"] <- "Max"
colnames(Trait_ABBA_TerpeneBM)[colnames(Trait_ABBA_TerpeneBM)=="TerpeneBM.median"] <- "Median"
colnames(Trait_ABBA_TerpeneBM)[colnames(Trait_ABBA_TerpeneBM)=="TerpeneBM.Q_one"] <- "Q_one"
colnames(Trait_ABBA_TerpeneBM)[colnames(Trait_ABBA_TerpeneBM)=="TerpeneBM.Q_three"] <- "Q_three"

# ABBA Monoterpene Biomass
Trait_ABBA_MonoterpeneBM <- summaryBy(MonoterpeneBM ~ Species, data = ABBA.PhytoBMSub, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_ABBA_MonoterpeneBM$Trait <- "MonoterpeneBM"
Trait_ABBA_MonoterpeneBM$SpeciesTrait <- paste(Trait_ABBA_MonoterpeneBM$Species, Trait_ABBA_MonoterpeneBM$Trait, sep="_")
colnames(Trait_ABBA_MonoterpeneBM)[colnames(Trait_ABBA_MonoterpeneBM)=="MonoterpeneBM.min"] <- "Min"
colnames(Trait_ABBA_MonoterpeneBM)[colnames(Trait_ABBA_MonoterpeneBM)=="MonoterpeneBM.max"] <- "Max"
colnames(Trait_ABBA_MonoterpeneBM)[colnames(Trait_ABBA_MonoterpeneBM)=="MonoterpeneBM.median"] <- "Median"
colnames(Trait_ABBA_MonoterpeneBM)[colnames(Trait_ABBA_MonoterpeneBM)=="MonoterpeneBM.Q_one"] <- "Q_one"
colnames(Trait_ABBA_MonoterpeneBM)[colnames(Trait_ABBA_MonoterpeneBM)=="MonoterpeneBM.Q_three"] <- "Q_three"

# ABBA Monoterpenic Ester Biomass
Trait_ABBA_MonoterpenicEsterBM <- summaryBy(MonoterpenicEsterBM ~ Species, data = ABBA.PhytoBMSub, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_ABBA_MonoterpenicEsterBM$Trait <- "MonoterpenicEsterBM"
Trait_ABBA_MonoterpenicEsterBM$SpeciesTrait <- paste(Trait_ABBA_MonoterpenicEsterBM$Species, Trait_ABBA_MonoterpenicEsterBM$Trait, sep="_")
colnames(Trait_ABBA_MonoterpenicEsterBM)[colnames(Trait_ABBA_MonoterpenicEsterBM)=="MonoterpenicEsterBM.min"] <- "Min"
colnames(Trait_ABBA_MonoterpenicEsterBM)[colnames(Trait_ABBA_MonoterpenicEsterBM)=="MonoterpenicEsterBM.max"] <- "Max"
colnames(Trait_ABBA_MonoterpenicEsterBM)[colnames(Trait_ABBA_MonoterpenicEsterBM)=="MonoterpenicEsterBM.median"] <- "Median"
colnames(Trait_ABBA_MonoterpenicEsterBM)[colnames(Trait_ABBA_MonoterpenicEsterBM)=="MonoterpenicEsterBM.Q_one"] <- "Q_one"
colnames(Trait_ABBA_MonoterpenicEsterBM)[colnames(Trait_ABBA_MonoterpenicEsterBM)=="MonoterpenicEsterBM.Q_three"] <- "Q_three"


# PIMA Raw
PIMA.PhytoRaw <- read.csv("Data/Outputs/Phytochemical/PIMA_Phytochemistry.csv")
# Calculate diversity
PIMA.PhytoRaw$Diversity <- diversity(PIMA.PhytoRaw[2:36], index="shannon")
# Populate with species
PIMA.PhytoRaw$Species <- "PIMA"
# Subset data
PIMA.PhytoRaw <- subset(PIMA.PhytoRaw, select = c(Species, Total.terpene, Total.monoterpene, Total.monoterpenic.alcohol, Total.monoterpenic.ester, Total.sesquiterpene, Diversity))
# Change names
colnames(PIMA.PhytoRaw)[colnames(PIMA.PhytoRaw)=="Total.terpene"] <- "TerpeneRaw"
colnames(PIMA.PhytoRaw)[colnames(PIMA.PhytoRaw)=="Total.monoterpene"] <- "MonoterpeneRaw"
colnames(PIMA.PhytoRaw)[colnames(PIMA.PhytoRaw)=="Total.monoterpenic.alcohol"] <- "MonoterpenicAlcoholRaw"
colnames(PIMA.PhytoRaw)[colnames(PIMA.PhytoRaw)=="Total.monoterpenic.ester"] <- "MonoterpenicEsterRaw"
colnames(PIMA.PhytoRaw)[colnames(PIMA.PhytoRaw)=="Total.sesquiterpene"] <- "SesquiterpeneRaw"



# PIMA Terpene Raw
Trait_PIMA_TerpeneRaw <- summaryBy(TerpeneRaw ~ Species, data = PIMA.PhytoRaw, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_PIMA_TerpeneRaw$Trait <- "TerpeneRaw"
Trait_PIMA_TerpeneRaw$SpeciesTrait <- paste(Trait_PIMA_TerpeneRaw$Species, Trait_PIMA_TerpeneRaw$Trait, sep="_")
colnames(Trait_PIMA_TerpeneRaw)[colnames(Trait_PIMA_TerpeneRaw)=="TerpeneRaw.min"] <- "Min"
colnames(Trait_PIMA_TerpeneRaw)[colnames(Trait_PIMA_TerpeneRaw)=="TerpeneRaw.max"] <- "Max"
colnames(Trait_PIMA_TerpeneRaw)[colnames(Trait_PIMA_TerpeneRaw)=="TerpeneRaw.median"] <- "Median"
colnames(Trait_PIMA_TerpeneRaw)[colnames(Trait_PIMA_TerpeneRaw)=="TerpeneRaw.Q_one"] <- "Q_one"
colnames(Trait_PIMA_TerpeneRaw)[colnames(Trait_PIMA_TerpeneRaw)=="TerpeneRaw.Q_three"] <- "Q_three"


# PIMA Monoterpene Raw
Trait_PIMA_MonoterpeneRaw <- summaryBy(MonoterpeneRaw ~ Species, data = PIMA.PhytoRaw, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_PIMA_MonoterpeneRaw$Trait <- "MonoterpeneRaw"
Trait_PIMA_MonoterpeneRaw$SpeciesTrait <- paste(Trait_PIMA_MonoterpeneRaw$Species, Trait_PIMA_MonoterpeneRaw$Trait, sep="_")
colnames(Trait_PIMA_MonoterpeneRaw)[colnames(Trait_PIMA_MonoterpeneRaw)=="MonoterpeneRaw.min"] <- "Min"
colnames(Trait_PIMA_MonoterpeneRaw)[colnames(Trait_PIMA_MonoterpeneRaw)=="MonoterpeneRaw.max"] <- "Max"
colnames(Trait_PIMA_MonoterpeneRaw)[colnames(Trait_PIMA_MonoterpeneRaw)=="MonoterpeneRaw.median"] <- "Median"
colnames(Trait_PIMA_MonoterpeneRaw)[colnames(Trait_PIMA_MonoterpeneRaw)=="MonoterpeneRaw.Q_one"] <- "Q_one"
colnames(Trait_PIMA_MonoterpeneRaw)[colnames(Trait_PIMA_MonoterpeneRaw)=="MonoterpeneRaw.Q_three"] <- "Q_three"

# PIMA Monoterpenic Alcohol Raw
Trait_PIMA_MonoterpenicAlcoholRaw <- summaryBy(MonoterpenicAlcoholRaw ~ Species, data = PIMA.PhytoRaw, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_PIMA_MonoterpenicAlcoholRaw$Trait <- "MonoterpenicAlcoholRaw"
Trait_PIMA_MonoterpenicAlcoholRaw$SpeciesTrait <- paste(Trait_PIMA_MonoterpenicAlcoholRaw$Species, Trait_PIMA_MonoterpenicAlcoholRaw$Trait, sep="_")
colnames(Trait_PIMA_MonoterpenicAlcoholRaw)[colnames(Trait_PIMA_MonoterpenicAlcoholRaw)=="MonoterpenicAlcoholRaw.min"] <- "Min"
colnames(Trait_PIMA_MonoterpenicAlcoholRaw)[colnames(Trait_PIMA_MonoterpenicAlcoholRaw)=="MonoterpenicAlcoholRaw.max"] <- "Max"
colnames(Trait_PIMA_MonoterpenicAlcoholRaw)[colnames(Trait_PIMA_MonoterpenicAlcoholRaw)=="MonoterpenicAlcoholRaw.median"] <- "Median"
colnames(Trait_PIMA_MonoterpenicAlcoholRaw)[colnames(Trait_PIMA_MonoterpenicAlcoholRaw)=="MonoterpenicAlcoholRaw.Q_one"] <- "Q_one"
colnames(Trait_PIMA_MonoterpenicAlcoholRaw)[colnames(Trait_PIMA_MonoterpenicAlcoholRaw)=="MonoterpenicAlcoholRaw.Q_three"] <- "Q_three"



# PIMA Monoterpenic Ester Raw
Trait_PIMA_MonoterpenicEsterRaw <- summaryBy(MonoterpenicEsterRaw ~ Species, data = PIMA.PhytoRaw, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_PIMA_MonoterpenicEsterRaw$Trait <- "MonoterpenicEsterRaw"
Trait_PIMA_MonoterpenicEsterRaw$SpeciesTrait <- paste(Trait_PIMA_MonoterpenicEsterRaw$Species, Trait_PIMA_MonoterpenicEsterRaw$Trait, sep="_")
colnames(Trait_PIMA_MonoterpenicEsterRaw)[colnames(Trait_PIMA_MonoterpenicEsterRaw)=="MonoterpenicEsterRaw.min"] <- "Min"
colnames(Trait_PIMA_MonoterpenicEsterRaw)[colnames(Trait_PIMA_MonoterpenicEsterRaw)=="MonoterpenicEsterRaw.max"] <- "Max"
colnames(Trait_PIMA_MonoterpenicEsterRaw)[colnames(Trait_PIMA_MonoterpenicEsterRaw)=="MonoterpenicEsterRaw.median"] <- "Median"
colnames(Trait_PIMA_MonoterpenicEsterRaw)[colnames(Trait_PIMA_MonoterpenicEsterRaw)=="MonoterpenicEsterRaw.Q_one"] <- "Q_one"
colnames(Trait_PIMA_MonoterpenicEsterRaw)[colnames(Trait_PIMA_MonoterpenicEsterRaw)=="MonoterpenicEsterRaw.Q_three"] <- "Q_three"


# PIMA Sesquiterpene Raw
Trait_PIMA_SesquiterpeneRaw <- summaryBy(SesquiterpeneRaw ~ Species, data = PIMA.PhytoRaw, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_PIMA_SesquiterpeneRaw$Trait <- "SesquiterpeneRaw"
Trait_PIMA_SesquiterpeneRaw$SpeciesTrait <- paste(Trait_PIMA_SesquiterpeneRaw$Species, Trait_PIMA_SesquiterpeneRaw$Trait, sep="_")
colnames(Trait_PIMA_SesquiterpeneRaw)[colnames(Trait_PIMA_SesquiterpeneRaw)=="SesquiterpeneRaw.min"] <- "Min"
colnames(Trait_PIMA_SesquiterpeneRaw)[colnames(Trait_PIMA_SesquiterpeneRaw)=="SesquiterpeneRaw.max"] <- "Max"
colnames(Trait_PIMA_SesquiterpeneRaw)[colnames(Trait_PIMA_SesquiterpeneRaw)=="SesquiterpeneRaw.median"] <- "Median"
colnames(Trait_PIMA_SesquiterpeneRaw)[colnames(Trait_PIMA_SesquiterpeneRaw)=="SesquiterpeneRaw.Q_one"] <- "Q_one"
colnames(Trait_PIMA_SesquiterpeneRaw)[colnames(Trait_PIMA_SesquiterpeneRaw)=="SesquiterpeneRaw.Q_three"] <- "Q_three"


# PIMA Diversity
Trait_PIMA_Diversity <- summaryBy(Diversity ~ Species, data = PIMA.PhytoRaw, FUN = c(min, max, median, function(x) quantile(x, c(.25, .75))), fun.names = c("min", "max", "median", "Q_one", "Q_three"))
Trait_PIMA_Diversity$Trait <- "Diversity"
Trait_PIMA_Diversity$SpeciesTrait <- paste(Trait_PIMA_Diversity$Species, Trait_PIMA_Diversity$Trait, sep="_")
colnames(Trait_PIMA_Diversity)[colnames(Trait_PIMA_Diversity)=="Diversity.min"] <- "Min"
colnames(Trait_PIMA_Diversity)[colnames(Trait_PIMA_Diversity)=="Diversity.max"] <- "Max"
colnames(Trait_PIMA_Diversity)[colnames(Trait_PIMA_Diversity)=="Diversity.median"] <- "Median"
colnames(Trait_PIMA_Diversity)[colnames(Trait_PIMA_Diversity)=="Diversity.Q_one"] <- "Q_one"
colnames(Trait_PIMA_Diversity)[colnames(Trait_PIMA_Diversity)=="Diversity.Q_three"] <- "Q_three"


# Combine Phyto data
P_Data <- rbind(Trait_ABBA_TerpeneRaw, Trait_ABBA_MonoterpeneRaw, Trait_ABBA_SesquiterpeneRaw, Trait_ABBA_TerpeneBM , Trait_ABBA_MonoterpeneBM, Trait_ABBA_MonoterpenicEsterBM, Trait_PIMA_TerpeneRaw, Trait_PIMA_MonoterpeneRaw, Trait_PIMA_MonoterpenicAlcoholRaw, Trait_PIMA_MonoterpenicEsterRaw, Trait_PIMA_SesquiterpeneRaw, Trait_PIMA_Diversity)
P_Data$TraitType <- "Phytochemical"

# Combine ES and P Data
ESP_Data <- rbind(ES_Data, P_Data)

# Add field to identify "observed data"
ESP_Data$Data <- "Observed"
str(ESP_Data)
ESP_Data_final <- subset(ESP_Data, select=c(Data, TraitType, SpeciesTrait, Species, Trait, Min, Max, Median, Q_one, Q_three))

# Manipulate raster/predicted data to mirror the observed dataset
RasStack.data$Data <- "Predicted"
# Export predict data and populate with fields and values in oberserved dataset
# write.csv(RasStack.data, "Deliverables/Obs_Predicted_DataCompare/RasterData.csv")
# RasterData <- read.csv("Deliverables/Obs_Predicted_DataCompare/RasterData_Updated.csv")

#Combine predicted and oberved data together
Obs_Pred_Data <- rbind(RasterData, ESP_Data_final)
# Export final dataset
write.csv(Obs_Pred_Data, "Deliverables/Obs_Predicted_DataCompare/Obs_Prediction_Data.csv") # add field for determining if obs and predicted exist - i.e., BEPA Qty C, N, and P - exist in observed but not predicted
Obs_Pred_Data <- read.csv("Deliverables/Obs_Predicted_DataCompare/Obs_Prediction_Data_Final.csv", stringsAsFactors = F)
View(Obs_Pred_Data)
# Change variable names
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "QtyC"] <- "Qty C"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "QtyN"] <- "Qty N"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "QtyP"] <- "Qty P"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "CN"] <- "CN ratio"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "CP"] <- "CP ratio"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "NP"] <- "NP ratio"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "TerpeneRaw"] <- "Terpene (raw)"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "TerpeneBM"] <- "Terpene (bm)"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "MonoterpeneRaw"] <- "Monoterpene (raw)"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "MonoterpeneBM"] <- "Monoterpene (bm)"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "MonoterpenicEsterBM"] <- "Monoterpenic ester (bm)"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "SesquiterpeneRaw"] <- "Sesquiterpene (raw)"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "MonoterpenicAlcoholRaw"] <- "Monoterpenic alcohol (raw)"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "MonoterpenicEsterRaw"] <- "Monoterpenic ester (raw)"
Obs_Pred_Data$Trait[Obs_Pred_Data$Trait == "Diversity"] <- "Phytochemical diversity (raw)"



Obs_Pred_Data$Trait <- factor(Obs_Pred_Data$Trait, levels = c("C", "N", "P", "Qty C", "Qty N", "Qty P", "CN ratio", "CP ratio", "NP ratio", "Terpene (raw)", "Terpene (bm)", "Monoterpene (raw)", "Monoterpene (bm)", "Monoterpenic alcohol (raw)", "Monoterpenic ester (raw)", "Monoterpenic ester (bm)", "Sesquiterpene (raw)", "Phytochemical diversity (raw)"))

Obs_Pred_Data_Y <- subset(Obs_Pred_Data, Obs_Pred_Data$Include == "Y")

# Make figures
# Create figure
png("Figures/Obs_Predicted_Compare/Obs_Predicted_Compare.png", width = 12, height = 16, units = "in", res = 600) 
ggplot(Obs_Pred_Data_Y, aes(x=Species, ymin=Min, lower = Q_one, middle = Median, upper = Q_three, ymax=Max, group=interaction(Species, Data), colour=Data)) + geom_boxplot(stat="identity") + facet_wrap(~Trait, scales="free", ncol=3, drop=TRUE) + theme_classic() + scale_colour_manual(values = c("black", "darkblue")) + theme(legend.text = element_text(size=11), legend.title=element_blank(), strip.text.x = element_text(size = 11), axis.text.x = element_text(size=11), axis.text.y = element_text(size=11), axis.title.x = element_blank())
dev.off()
